@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2025 Zabbix SIA
+** Copyright (C) 2001-2022 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -20,8 +20,6 @@
 #ifndef ZABBIX_PROXY_H
 #define ZABBIX_PROXY_H
 
-#include "zbxjson.h"
-#include "comms.h"
 #include "dbcache.h"
 
 #define ZBX_PROXYMODE_ACTIVE	0
@@ -44,10 +42,9 @@ int	check_access_passive_proxy(zbx_socket_t *sock, int send_response, const char
 void	update_proxy_lastaccess(const zbx_uint64_t hostid, time_t last_access);
 
 int	get_proxyconfig_data(zbx_uint64_t proxy_hostid, struct zbx_json *j, char **error);
-int	process_proxyconfig(struct zbx_json_parse *jp_data);
+int	process_proxyconfig(struct zbx_json_parse *jp_data, struct zbx_json_parse *jp_kvs_paths);
 
-int	get_host_availability_data(struct zbx_json *json, int *ts);
-int	process_host_availability(struct zbx_json_parse *jp, char **error);
+int	get_interface_availability_data(struct zbx_json *json, int *ts);
 
 int	proxy_get_hist_data(struct zbx_json *j, zbx_uint64_t *lastid, int *more);
 int	proxy_get_dhis_data(struct zbx_json *j, zbx_uint64_t *lastid, int *more);
@@ -58,8 +55,8 @@ void	proxy_set_areg_lastid(const zbx_uint64_t lastid);
 
 void	calc_timestamp(const char *line, int *timestamp, const char *format);
 
-int	process_history_data(zbx_history_recv_item_t *items, zbx_agent_value_t *values, int *errcodes,
-		size_t values_num, zbx_proxy_suppress_t *nodata_win);
+int	process_history_data(DC_ITEM *items, zbx_agent_value_t *values, int *errcodes, size_t values_num,
+		zbx_proxy_suppress_t *nodata_win);
 
 int	lld_process_discovery_rule(zbx_uint64_t lld_ruleid, const char *value, char **error);
 
