@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2025 Zabbix SIA
+** Copyright (C) 2001-2022 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -157,6 +157,10 @@
 #	include <fcntl.h>
 #endif
 
+#ifdef HAVE_KNLIST_H
+#	include <knlist.h>
+#endif
+
 #ifdef HAVE_KSTAT_H
 #	include <kstat.h>
 #endif
@@ -180,6 +184,10 @@
 #	include <mach/mach_host.h>
 #endif
 
+#ifdef HAVE_MTENT_H
+#	include <mtent.h>
+#endif
+
 #ifdef HAVE_NETDB_H
 #	include <netdb.h>
 #endif
@@ -347,6 +355,11 @@
 #	include <pcre.h>
 #endif
 
+#ifdef HAVE_PCRE2_H
+#	define PCRE2_CODE_UNIT_WIDTH 8
+#	include <pcre2.h>
+#endif
+
 #ifdef HAVE_VM_VM_PARAM_H
 #	include <vm/vm_param.h>
 #endif
