@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2025 Zabbix SIA
+** Copyright (C) 2001-2022 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -20,7 +20,6 @@
 #ifndef ZABBIX_ZBXIPCSERVICE_H
 #define ZABBIX_ZBXIPCSERVICE_H
 
-#include "common.h"
 #include "zbxalgo.h"
 
 #define ZBX_IPC_SOCKET_BUFFER_SIZE	4096
@@ -95,7 +94,7 @@ zbx_ipc_async_socket_t;
 int	zbx_ipc_service_init_env(const char *path, char **error);
 void	zbx_ipc_service_free_env(void);
 int	zbx_ipc_service_start(zbx_ipc_service_t *service, const char *service_name, char **error);
-int	zbx_ipc_service_recv(zbx_ipc_service_t *service, int timeout, zbx_ipc_client_t **client,
+int	zbx_ipc_service_recv(zbx_ipc_service_t *service, const zbx_timespec_t *timeout, zbx_ipc_client_t **client,
 		zbx_ipc_message_t **message);
 void	zbx_ipc_service_close(zbx_ipc_service_t *service);
 
@@ -107,12 +106,15 @@ void			zbx_ipc_client_release(zbx_ipc_client_t *client);
 int			zbx_ipc_client_connected(zbx_ipc_client_t *client);
 zbx_uint64_t		zbx_ipc_client_id(const zbx_ipc_client_t *client);
 zbx_ipc_client_t	*zbx_ipc_client_by_id(const zbx_ipc_service_t *service, zbx_uint64_t id);
+void	zbx_ipc_client_set_userdata(zbx_ipc_client_t *client, void *userdata);
+void	*zbx_ipc_client_get_userdata(zbx_ipc_client_t *client);
 
 int	zbx_ipc_socket_open(zbx_ipc_socket_t *csocket, const char *service_name, int timeout, char **error);
 void	zbx_ipc_socket_close(zbx_ipc_socket_t *csocket);
 int	zbx_ipc_socket_write(zbx_ipc_socket_t *csocket, zbx_uint32_t code, const unsigned char *data,
 		zbx_uint32_t size);
 int	zbx_ipc_socket_read(zbx_ipc_socket_t *csocket, zbx_ipc_message_t *message);
+int	zbx_ipc_socket_connected(const zbx_ipc_socket_t *csocket);
 
 int	zbx_ipc_async_socket_open(zbx_ipc_async_socket_t *asocket, const char *service_name, int timeout, char **error);
 void	zbx_ipc_async_socket_close(zbx_ipc_async_socket_t *asocket);
@@ -121,6 +123,7 @@ int	zbx_ipc_async_socket_send(zbx_ipc_async_socket_t *asocket, zbx_uint32_t code
 int	zbx_ipc_async_socket_recv(zbx_ipc_async_socket_t *asocket, int timeout, zbx_ipc_message_t **message);
 int	zbx_ipc_async_socket_flush(zbx_ipc_async_socket_t *asocket, int timeout);
 int	zbx_ipc_async_socket_check_unsent(zbx_ipc_async_socket_t *asocket);
+int	zbx_ipc_async_socket_connected(zbx_ipc_async_socket_t *asocket);
 int	zbx_ipc_async_exchange(const char *service_name, zbx_uint32_t code, int timeout, const unsigned char *data,
 		zbx_uint32_t size, unsigned char **out, char **error);
 
