@@ -3,7 +3,7 @@
 
 /*
 ** Zabbix
-** Copyright (C) 2001-2025 Zabbix SIA
+** Copyright (C) 2001-2022 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -25,7 +25,7 @@ package keyaccess
 import (
 	"testing"
 
-	"zabbix.com/pkg/conf"
+	"git.zabbix.com/ap/plugin-support/conf"
 	"zabbix.com/pkg/itemutil"
 )
 
