@@ -26,13 +26,13 @@ import (
 )
 
 const (
-	ZABBIX_REVDATE          = "25 July 2022"
+	ZABBIX_REVDATE          = "29 August 2022"
 	ZABBIX_VERSION_MAJOR    = 6
 	ZABBIX_VERSION_MINOR    = 0
-	ZABBIX_VERSION_PATCH    = 7
+	ZABBIX_VERSION_PATCH    = 8
 	ZABBIX_VERSION_RC       = ""
 	ZABBIX_VERSION_RC_NUM   = "2400"
-	ZABBIX_VERSION_REVISION = "442920c8f69"
+	ZABBIX_VERSION_REVISION = "c7c3044a4a2"
 	copyrightMessage        = "Copyright (C) 2022 Zabbix SIA\n" +
 		"License GPLv2+: GNU GPL version 2 or later <http://gnu.org/licenses/gpl.html>.\n" +
 		"This is free software: you are free to change and redistribute it according to\n" +
