@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2025 Zabbix SIA
+** Copyright (C) 2001-2022 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -20,6 +20,7 @@
 package ceph
 
 import (
+	"io/ioutil"
 	"log"
 	"os"
 	"strings"
@@ -31,15 +32,15 @@ var fixtures map[command][]byte
 const cmdBroken command = "broken"
 
 func TestMain(m *testing.M) {
+	var err error
+
 	fixtures = make(map[command][]byte)
 
 	for _, cmd := range []command{
 		cmdDf, cmdPgDump, cmdOSDCrushRuleDump, cmdOSDCrushTree, cmdOSDDump, cmdHealth, cmdStatus,
 	} {
-		var err error
-		fixtures[cmd], err = os.ReadFile(
-			"testdata/" + strings.ReplaceAll(string(cmd), " ", "_") + ".json",
-		)
+		fixtures[cmd], err = ioutil.ReadFile("testdata/" +
+			strings.ReplaceAll(string(cmd), " ", "_") + ".json")
 		if err != nil {
 			log.Fatal(err)
 		}
