@@ -3,7 +3,7 @@
 
 /*
 ** Zabbix
-** Copyright (C) 2001-2025 Zabbix SIA
+** Copyright (C) 2001-2022 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -27,7 +27,7 @@ import (
 	"reflect"
 	"testing"
 
-	"zabbix.com/pkg/std"
+	"git.zabbix.com/ap/plugin-support/std"
 )
 
 var testSets = []testSet{
@@ -87,6 +87,30 @@ var testSets = []testSet{
 		},
 		"/proc/sys/fs/file-max",
 		"",
+	}, {
+		"testKernel08_file-nr",
+		[]testCase{
+			{1, "openfiles_no_params", "kernel.openfiles", []string{}, false, uint64(18446744073709551615), reflect.Uint64},
+			{2, "openfiles_empty_pram_value", "kernel.openfiles", []string{""}, true, uint64(18446744073709551615), reflect.Uint64},
+			{3, "openfiles_with_params", "kernel.openfiles", []string{"param"}, true, uint64(18446744073709551615), reflect.Uint64},
+			{4, "wrong_key", "wrong.key", []string{}, true, uint64(18446744073709551615), reflect.Uint64},
+		},
+		"/proc/sys/fs/file-nr",
+		"18446744073709551615\n",
+	}, {
+		"testKernel09_file-nr_no_new_line",
+		[]testCase{
+			{1, "openfiles_no_params", "kernel.openfiles", []string{}, true, uint64(18446744073709551615), reflect.Uint64},
+		},
+		"/proc/sys/fs/file-nr",
+		"18446744073709551616",
+	}, {
+		"testKernel10_file-nr_empty_file",
+		[]testCase{
+			{1, "openfiles_no_params", "kernel.openfiles", []string{}, true, uint64(18446744073709551615), reflect.Uint64},
+		},
+		"/proc/sys/fs/file-nr",
+		"",
 	},
 }
 
