@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2025 Zabbix SIA
+** Copyright (C) 2001-2022 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -24,8 +24,9 @@ import (
 	_ "zabbix.com/plugins/docker"
 	_ "zabbix.com/plugins/log"
 	_ "zabbix.com/plugins/memcached"
-	_ "zabbix.com/plugins/mongodb"
+	_ "zabbix.com/plugins/modbus"
 	_ "zabbix.com/plugins/mysql"
+	_ "zabbix.com/plugins/net/dns"
 	_ "zabbix.com/plugins/net/tcp"
 	_ "zabbix.com/plugins/oracle"
 	_ "zabbix.com/plugins/postgres"
@@ -38,4 +39,5 @@ import (
 	_ "zabbix.com/plugins/web/page"
 	_ "zabbix.com/plugins/zabbix/async"
 	_ "zabbix.com/plugins/zabbix/stats"
+	_ "zabbix.com/plugins/zabbix/sync"
 )
