@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2025 Zabbix SIA
+** Copyright (C) 2001-2022 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -23,7 +23,8 @@ import (
 	_ "zabbix.com/plugins/ceph"
 	_ "zabbix.com/plugins/log"
 	_ "zabbix.com/plugins/memcached"
-	_ "zabbix.com/plugins/mongodb"
+	_ "zabbix.com/plugins/modbus"
+	_ "zabbix.com/plugins/mqtt"
 	_ "zabbix.com/plugins/mysql"
 	_ "zabbix.com/plugins/net/dns"
 	_ "zabbix.com/plugins/net/netif"
@@ -54,4 +55,5 @@ import (
 	_ "zabbix.com/plugins/windows/wmi"
 	_ "zabbix.com/plugins/zabbix/async"
 	_ "zabbix.com/plugins/zabbix/stats"
+	_ "zabbix.com/plugins/zabbix/sync"
 )
