@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2025 Zabbix SIA
+** Copyright (C) 2001-2022 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -25,14 +25,13 @@ import (
 	"net/url"
 	"time"
 
-	"zabbix.com/pkg/metric"
+	"git.zabbix.com/ap/plugin-support/uri"
+	"git.zabbix.com/ap/plugin-support/zbxerr"
 	"zabbix.com/pkg/tlsconfig"
-	"zabbix.com/pkg/uri"
-	"zabbix.com/pkg/zbxerr"
 
 	"github.com/omeid/go-yarn"
 
-	"zabbix.com/pkg/plugin"
+	"git.zabbix.com/ap/plugin-support/plugin"
 )
 
 const (
@@ -53,12 +52,7 @@ var impl Plugin
 
 // Export implements the Exporter interface.
 func (p *Plugin) Export(key string, rawParams []string, _ plugin.ContextProvider) (result interface{}, err error) {
-	params, extraParams, hc, err := metrics[key].EvalParams(rawParams, p.options.Sessions)
-	if err != nil {
-		return nil, err
-	}
-
-	err = metric.SetDefaults(params, hc, p.options.Default)
+	params, extraParams, err := metrics[key].EvalParams(rawParams, p.options.Sessions)
 	if err != nil {
 		return nil, err
 	}
