@@ -3,7 +3,7 @@
 
 /*
 ** Zabbix
-** Copyright (C) 2001-2025 Zabbix SIA
+** Copyright (C) 2001-2022 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -27,7 +27,8 @@ import (
 	"fmt"
 	"os"
 	"time"
-	"zabbix.com/pkg/log"
+
+	"git.zabbix.com/ap/plugin-support/log"
 )
 
 var sharedConn *PGConn
