@@ -3,7 +3,7 @@
 
 /*
 ** Zabbix
-** Copyright (C) 2001-2025 Zabbix SIA
+** Copyright (C) 2001-2022 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -37,8 +37,8 @@ import (
 	"sync"
 	"time"
 
-	"zabbix.com/pkg/log"
-	"zabbix.com/pkg/plugin"
+	"git.zabbix.com/ap/plugin-support/log"
+	"git.zabbix.com/ap/plugin-support/plugin"
 	"zabbix.com/pkg/procfs"
 )
 
@@ -402,7 +402,6 @@ func (p *Plugin) Export(key string, params []string, ctx plugin.ContextProvider)
 		ticks *= 1e12
 		ticks /= uint64(tail.timestamp.Sub(head.timestamp))
 
-		log.Tracef("Calling C function \"sysconf()\"")
 		return math.Round(float64(ticks)/float64(C.sysconf(C._SC_CLK_TCK))) / 10, nil
 	}
 	stats := &cpuUtilStats{accessed: now, history: make([]cpuUtilData, maxHistory)}
