@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2025 Zabbix SIA
+** Copyright (C) 2001-2022 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -21,12 +21,12 @@ package smart
 
 import (
 	"encoding/json"
-	"regexp"
+	"fmt"
 	"strings"
 
-	"zabbix.com/pkg/conf"
-	"zabbix.com/pkg/plugin"
-	"zabbix.com/pkg/zbxerr"
+	"git.zabbix.com/ap/plugin-support/conf"
+	"git.zabbix.com/ap/plugin-support/plugin"
+	"git.zabbix.com/ap/plugin-support/zbxerr"
 )
 
 const (
@@ -42,19 +42,17 @@ const (
 	attributeDiscovery = "smart.attribute.discovery"
 )
 
-var pathRegex = regexp.MustCompile(`^(?:\s*-|'*"*\s*-)`)
-
 // Options -
 type Options struct {
-	Timeout int    `conf:"optional,range=1:30"`
-	Path    string `conf:"optional"`
+	plugin.SystemOptions `conf:"optional,name=System"`
+	Timeout              int    `conf:"optional,range=1:30"`
+	Path                 string `conf:"optional"`
 }
 
 // Plugin -
 type Plugin struct {
 	plugin.Base
 	options Options
-	ctl     smartCtl
 }
 
 var impl Plugin
@@ -68,8 +66,6 @@ func (p *Plugin) Configure(global *plugin.GlobalOptions, options interface{}) {
 	if p.options.Timeout == 0 {
 		p.options.Timeout = global.Timeout
 	}
-
-	p.ctl = newSmartCtl(p.options.Path, p.options.Timeout)
 }
 
 // Validate -
@@ -79,15 +75,17 @@ func (p *Plugin) Validate(options interface{}) error {
 }
 
 // Export -
-func (p *Plugin) Export(key string, params []string, _ plugin.ContextProvider) (any, error) {
-	var err error
+func (p *Plugin) Export(key string, params []string, ctx plugin.ContextProvider) (result interface{}, err error) {
+	if len(params) > 0 && key != diskGet {
+		return nil, zbxerr.ErrorTooManyParameters
+	}
 
-	err = p.validateExport(key, params)
-	if err != nil {
-		return nil, zbxerr.New("export validation failed").Wrap(err)
+	if err = p.checkVersion(); err != nil {
+		return
 	}
 
 	var jsonArray []byte
+
 	switch key {
 	case diskDiscovery:
 		jsonArray, err = p.diskDiscovery()
@@ -156,13 +154,13 @@ func (p *Plugin) diskGet(params []string) ([]byte, error) {
 }
 
 func (p *Plugin) diskGetSingle(path, raidType string) ([]byte, error) {
-	args := []string{"-a", path, "-j"}
+	executable := path
 
 	if raidType != "" {
-		args = []string{"-a", path, "-d", raidType, "-j"}
+		executable = fmt.Sprintf("%s -d %s", executable, raidType)
 	}
 
-	device, err := p.ctl.execute(args...)
+	device, err := p.executeSingle(executable)
 	if err != nil {
 		return nil, err
 	}
@@ -273,7 +271,7 @@ func setSingleDiskFields(dev []byte) (out map[string]interface{}, err error) {
 		out["power_on_time"] = sd.HealthLog.PowerOnTime
 		out["critical_warning"] = sd.HealthLog.CriticalWarning
 		out["media_errors"] = sd.HealthLog.MediaErrors
-		out["percentage_used"] = sd.HealthLog.PercentageUsed
+		out["percentage_used"] = sd.HealthLog.Percentage_used
 	} else {
 		out["temperature"] = sd.Temperature.Current
 		out["power_on_time"] = sd.PowerOnTime.Hours
@@ -436,33 +434,3 @@ func init() {
 		"smart.attribute.discovery", "Returns JSON array of smart device attributes.",
 	)
 }
-
-// validateExport function validates key, export params and version.
-func (p *Plugin) validateExport(key string, params []string) error {
-	err := validateParams(key, params)
-	if err != nil {
-		return err
-	}
-
-	return p.checkVersion()
-}
-
-// validateParams validates the key's params quantity aspect.
-func validateParams(key string, params []string) error {
-	// No params - nothing to validate.
-	if len(params) == all {
-		return nil
-	}
-
-	// The params can only be for a specific function.
-	if key != diskGet {
-		return zbxerr.ErrorTooManyParameters
-	}
-
-	//Validates the param disk path in the context of an input sanitization.
-	if pathRegex.MatchString(params[0]) {
-		return zbxerr.New("invalid disk descriptor format")
-	}
-
-	return nil
-}
