@@ -3,7 +3,7 @@
 
 /*
 ** Zabbix
-** Copyright (C) 2001-2025 Zabbix SIA
+** Copyright (C) 2001-2022 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -24,7 +24,6 @@ package smart
 
 import (
 	"fmt"
-	"os/exec"
 	"time"
 
 	"zabbix.com/pkg/zbxcmd"
@@ -32,26 +31,23 @@ import (
 
 func (p *Plugin) executeSmartctl(args string, strict bool) ([]byte, error) {
 	path := "smartctl"
+
 	if p.options.Path != "" {
 		path = p.options.Path
 	}
 
 	var out string
-	var err error
 
-	_, err = exec.LookPath(path)
-	if err != nil {
-		return nil, err
-	}
+	var err error
 
 	executable := fmt.Sprintf("%s %s", path, args)
 
 	p.Tracef("executing smartctl command: %s", executable)
 
 	if strict {
-		out, err = zbxcmd.ExecuteStrict(executable, time.Second*time.Duration(p.options.Timeout))
+		out, err = zbxcmd.ExecuteStrict(executable, time.Second*time.Duration(p.options.Timeout), "")
 	} else {
-		out, err = zbxcmd.Execute(executable, time.Second*time.Duration(p.options.Timeout))
+		out, err = zbxcmd.Execute(executable, time.Second*time.Duration(p.options.Timeout), "")
 	}
 
 	p.Tracef("command %s smartctl raw response: %s", executable, out)
