@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2025 Zabbix SIA
+** Copyright (C) 2001-2022 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -31,8 +31,7 @@ import (
 	"strconv"
 	"strings"
 
-	"zabbix.com/pkg/plugin"
-	"zabbix.com/pkg/log"
+	"git.zabbix.com/ap/plugin-support/plugin"
 )
 
 // Plugin -
@@ -133,12 +132,10 @@ func (p *Plugin) addCpu(index int) {
 }
 
 func numCPUConf() int {
-	log.Tracef("Calling C function \"sysconf()\"")
 	return int(C.sysconf(C._SC_NPROCESSORS_CONF))
 }
 
 func numCPUOnline() int {
-	log.Tracef("Calling C function \"sysconf()\"")
 	return int(C.sysconf(C._SC_NPROCESSORS_ONLN))
 }
 
