@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2025 Zabbix SIA
+** Copyright (C) 2001-2022 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -24,9 +24,9 @@ import (
 	"strings"
 	"time"
 
-	"zabbix.com/pkg/plugin"
+	"git.zabbix.com/ap/plugin-support/plugin"
+	"git.zabbix.com/ap/plugin-support/zbxerr"
 	"zabbix.com/pkg/zbxcmd"
-	"zabbix.com/pkg/zbxerr"
 )
 
 const (
@@ -52,7 +52,8 @@ type Plugin struct {
 
 // Options -
 type Options struct {
-	Timeout int
+	plugin.SystemOptions `conf:"optional,name=System"`
+	Timeout              int
 }
 
 var impl Plugin
@@ -270,7 +271,7 @@ func (p *Plugin) exportDevices(params []string) (result interface{}, err error)
 		return
 	}
 
-	return zbxcmd.ExecuteStrict(cmd, time.Second*time.Duration(p.options.Timeout))
+	return zbxcmd.ExecuteStrict(cmd, time.Second*time.Duration(p.options.Timeout), "")
 }
 
 func getDeviceCmd(params []string) (string, error) {
