@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2025 Zabbix SIA
+** Copyright (C) 2001-2022 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -69,7 +69,8 @@ func (p *Plugin) getDiscovery() (out string, err error) {
 			if stat.Mode()&os.ModeType == os.ModeDevice {
 				dev := &devRecord{Name: entry.Name()}
 				if sysfs {
-					rdev := stat.Sys().(*syscall.Stat_t).Rdev
+					//nolint:unconvert
+					rdev := uint64(stat.Sys().(*syscall.Stat_t).Rdev)
 					dirname := fmt.Sprintf("%s%d:%d/", sysBlkdevLocation, unix.Major(rdev), unix.Minor(rdev))
 
 					if lstat, tmperr := os.Lstat(devname); tmperr == nil {
@@ -145,7 +146,8 @@ func (p *Plugin) getDeviceName(name string) (devName string, err error) {
 		if minor, err = strconv.ParseUint(fields[1], 10, 32); err != nil {
 			return
 		}
-		rdev := stat.Sys().(*syscall.Stat_t).Rdev
+		//nolint:unconvert
+		rdev := uint64(stat.Sys().(*syscall.Stat_t).Rdev)
 		if uint64(unix.Major(rdev)) == major && uint64(unix.Minor(rdev)) == minor {
 			return fields[2], nil
 		}
@@ -190,7 +192,8 @@ func (p *Plugin) scanDeviceStats(name string, buf *bytes.Buffer) (devstats *devS
 		}
 		var stat os.FileInfo
 		if stat, err = os.Stat(name); err == nil {
-			rdev = stat.Sys().(*syscall.Stat_t).Rdev
+			//nolint:unconvert
+			rdev = uint64(stat.Sys().(*syscall.Stat_t).Rdev)
 		}
 	}
 
