@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2025 Zabbix SIA
+** Copyright (C) 2001-2022 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -25,8 +25,28 @@ import (
 	"fmt"
 	"io"
 	"time"
+
+	"git.zabbix.com/ap/plugin-support/std"
+	"git.zabbix.com/ap/plugin-support/zbxerr"
 )
 
+func md5sum(file std.File, start time.Time, timeout int) (result interface{}, err error) {
+	var bnum int64
+	bnum = 16 * 1024
+	buf := make([]byte, bnum)
+
+	hash := md5.New()
+
+	for bnum > 0 {
+		bnum, _ = io.CopyBuffer(hash, file, buf)
+		if time.Since(start) > time.Duration(timeout)*time.Second {
+			return nil, errors.New("Timeout while processing item.")
+		}
+	}
+
+	return fmt.Sprintf("%x", hash.Sum(nil)), nil
+}
+
 func (p *Plugin) exportMd5sum(params []string) (result interface{}, err error) {
 	if len(params) > 1 {
 		return nil, errors.New("Too many parameters.")
@@ -39,23 +59,9 @@ func (p *Plugin) exportMd5sum(params []string) (result interface{}, err error) {
 
 	file, err := stdOs.Open(params[0])
 	if err != nil {
-		return nil, fmt.Errorf("Cannot open file: %s", err)
+		return nil, zbxerr.New("Cannot open file").Wrap(err)
 	}
 	defer file.Close()
 
-	var bnum int64
-	bnum = 16 * 1024
-	buf := make([]byte, bnum)
-
-	hash := md5.New()
-
-	for bnum > 0 {
-		bnum, _ = io.CopyBuffer(hash, file, buf)
-		if time.Since(start) > time.Duration(p.options.Timeout)*time.Second {
-			return nil, errors.New("Timeout while processing item")
-		}
-	}
-
-	return fmt.Sprintf("%x", hash.Sum(nil)), nil
-
+	return md5sum(file, start, p.options.Timeout)
 }
