@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2025 Zabbix SIA
+** Copyright (C) 2001-2022 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -23,7 +23,7 @@ import (
 	"encoding/json"
 	"errors"
 
-	"zabbix.com/pkg/plugin"
+	"git.zabbix.com/ap/plugin-support/plugin"
 )
 
 const (
@@ -47,19 +47,21 @@ type FsStats struct {
 }
 
 type FsInfo struct {
-	FsName    *string  `json:"{#FSNAME},omitempty"`
-	FsType    *string  `json:"{#FSTYPE},omitempty"`
-	DriveType *string  `json:"{#FSDRIVETYPE},omitempty"`
-	Bytes     *FsStats `json:"bytes,omitempty"`
-	Inodes    *FsStats `json:"inodes,omitempty"`
+	FsName     *string  `json:"{#FSNAME},omitempty"`
+	FsType     *string  `json:"{#FSTYPE},omitempty"`
+	DriveLabel *string  `json:"{#FSLABEL},omitempty"`
+	DriveType  *string  `json:"{#FSDRIVETYPE},omitempty"`
+	Bytes      *FsStats `json:"bytes,omitempty"`
+	Inodes     *FsStats `json:"inodes,omitempty"`
 }
 
 type FsInfoNew struct {
-	FsName    *string  `json:"fsname,omitempty"`
-	FsType    *string  `json:"fstype,omitempty"`
-	DriveType *string  `json:"fsdrivetype,omitempty"`
-	Bytes     *FsStats `json:"bytes,omitempty"`
-	Inodes    *FsStats `json:"inodes,omitempty"`
+	FsName     *string  `json:"fsname,omitempty"`
+	FsType     *string  `json:"fstype,omitempty"`
+	DriveLabel *string  `json:"fslabel,omitempty"`
+	DriveType  *string  `json:"fsdrivetype,omitempty"`
+	Bytes      *FsStats `json:"bytes,omitempty"`
+	Inodes     *FsStats `json:"inodes,omitempty"`
 }
 
 type Plugin struct {
@@ -123,6 +125,7 @@ func (p *Plugin) export(params []string, getStats func(string) (*FsStats, error)
 	}
 
 	fsCaller := p.newFSCaller(getStats, 1)
+	defer fsCaller.close()
 
 	var stats *FsStats
 	if stats, err = fsCaller.run(params[0]); err != nil {
