@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2025 Zabbix SIA
+** Copyright (C) 2001-2022 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -22,8 +22,8 @@ package memory
 import (
 	"errors"
 
+	"git.zabbix.com/ap/plugin-support/zbxerr"
 	"zabbix.com/pkg/procfs"
-	"zabbix.com/pkg/zbxerr"
 )
 
 func (p *Plugin) exportVMMemorySize(mode string) (result interface{}, err error) {
