@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2025 Zabbix SIA
+** Copyright (C) 2001-2022 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -20,6 +20,8 @@
 #ifndef ZABBIX_TLS_H
 #define ZABBIX_TLS_H
 
+#include "config.h"
+
 #if defined(HAVE_GNUTLS) || defined(HAVE_OPENSSL)
 
 #if defined(HAVE_GNUTLS)
@@ -31,7 +33,7 @@
 #	include <openssl/rand.h>
 #endif
 
-#if defined(HAVE_OPENSSL) && OPENSSL_VERSION_NUMBER < 0x1010000fL
+#if defined(HAVE_OPENSSL) && OPENSSL_VERSION_NUMBER < 0x1010000fL || defined(LIBRESSL_VERSION_NUMBER)
 #	if !defined(LIBRESSL_VERSION_NUMBER)
 #		define OPENSSL_INIT_LOAD_SSL_STRINGS			0
 #		define OPENSSL_INIT_LOAD_CRYPTO_STRINGS		0
