@@ -78,7 +78,6 @@ static int		db_auto_increment;
 static MYSQL			*conn = NULL;
 static zbx_uint32_t		ZBX_MYSQL_SVERSION = ZBX_DBVERSION_UNDEFINED;
 static int			ZBX_MARIADB_SFORK = OFF;
-static char			*ZBX_CHARSET = NULL;
 #elif defined(HAVE_ORACLE)
 #include "zbxalgo.h"
 
@@ -315,9 +314,12 @@ static DB_RESULT	zbx_db_select(const char *fmt, ...)
 }
 
 #if defined(HAVE_MYSQL)
-static int	is_recoverable_mysql_error(void)
+static int	is_recoverable_mysql_error(int err_no)
 {
-	switch (mysql_errno(conn))
+	if (0 == err_no)
+		err_no = (int)mysql_errno(conn);
+
+	switch (err_no)
 	{
 		case CR_CONN_HOST_ERROR:
 		case CR_SERVER_GONE_ERROR:
@@ -381,12 +383,12 @@ int	zbx_db_connect(char *host, char *user, char *password, char *dbname, char *d
 {
 	int		ret = ZBX_DB_OK, last_txn_error, last_txn_level;
 #if defined(HAVE_MYSQL)
-	const char	*charset;
 #if LIBMYSQL_VERSION_ID >= 80000	/* my_bool type is removed in MySQL 8.0 */
 	bool		mysql_reconnect = 1;
 #else
 	my_bool		mysql_reconnect = 1;
 #endif
+	int		err_no = 0;
 #elif defined(HAVE_ORACLE)
 	char		*connect = NULL;
 	sword		err = OCI_SUCCESS;
@@ -560,7 +562,8 @@ int	zbx_db_connect(char *host, char *user, char *password, char *dbname, char *d
 			NULL == mysql_real_connect(conn, host, user, password, dbname, port, dbsocket,
 				CLIENT_MULTI_STATEMENTS))
 	{
-		zbx_db_errlog(ERR_Z3001, mysql_errno(conn), mysql_error(conn), dbname);
+		err_no = (int)mysql_errno(conn);
+		zbx_db_errlog(ERR_Z3001, err_no, mysql_error(conn), dbname);
 		ret = ZBX_DB_FAIL;
 	}
 
@@ -573,24 +576,33 @@ int	zbx_db_connect(char *host, char *user, char *password, char *dbname, char *d
 	if (ZBX_DB_OK == ret && 0 != mysql_options(conn, MYSQL_OPT_RECONNECT, &mysql_reconnect))
 		zabbix_log(LOG_LEVEL_WARNING, "Cannot set MySQL reconnect option.");
 
-	charset = NULL == ZBX_CHARSET ? "utf8" : ZBX_CHARSET;
-	/* in contrast to "set names utf8" results of this call will survive auto-reconnects */
-	if (ZBX_DB_OK == ret && 0 != mysql_set_character_set(conn, charset))
-		zabbix_log(LOG_LEVEL_WARNING, "cannot set MySQL character set to \"%s\"", charset);
+	if (ZBX_DB_OK == ret)
+	{
+		/* in contrast to "set names utf8" results of this call will survive auto-reconnects */
+		/* utf8mb3 is deprecated and it's superset utf8mb4 should be used instead if available */
+		if (0 != mysql_set_character_set(conn, ZBX_SUPPORTED_DB_CHARACTER_SET_UTF8MB4) &&
+				0 != mysql_set_character_set(conn, ZBX_SUPPORTED_DB_CHARACTER_SET_UTF8) &&
+				0 != mysql_set_character_set(conn, ZBX_SUPPORTED_DB_CHARACTER_SET_UTF8MB3))
+		{
+			zabbix_log(LOG_LEVEL_WARNING, "cannot set MySQL character set");
+		}
+	}
 
 	if (ZBX_DB_OK == ret && 0 != mysql_autocommit(conn, 1))
 	{
-		zbx_db_errlog(ERR_Z3001, mysql_errno(conn), mysql_error(conn), dbname);
+		err_no = (int)mysql_errno(conn);
+		zbx_db_errlog(ERR_Z3001, err_no, mysql_error(conn), dbname);
 		ret = ZBX_DB_FAIL;
 	}
 
 	if (ZBX_DB_OK == ret && 0 != mysql_select_db(conn, dbname))
 	{
-		zbx_db_errlog(ERR_Z3001, mysql_errno(conn), mysql_error(conn), dbname);
+		err_no = (int)mysql_errno(conn);
+		zbx_db_errlog(ERR_Z3001, err_no, mysql_error(conn), dbname);
 		ret = ZBX_DB_FAIL;
 	}
 
-	if (ZBX_DB_FAIL == ret && SUCCEED == is_recoverable_mysql_error())
+	if (ZBX_DB_FAIL == ret && SUCCEED == is_recoverable_mysql_error(err_no))
 		ret = ZBX_DB_DOWN;
 
 #elif defined(HAVE_ORACLE)
@@ -1421,9 +1433,9 @@ out:
  ******************************************************************************/
 int	zbx_db_vexecute(const char *fmt, va_list args)
 {
-	char	*sql = NULL;
-	int	ret = ZBX_DB_OK;
-	double	sec = 0;
+	char		*sql = NULL;
+	int		ret = ZBX_DB_OK;
+	double		sec = 0;
 #if defined(HAVE_MYSQL)
 #elif defined(HAVE_ORACLE)
 	sword		err = OCI_SUCCESS;
@@ -1462,13 +1474,15 @@ int	zbx_db_vexecute(const char *fmt, va_list args)
 	else
 	{
 		zbx_err_codes_t	errcode;
+		int		err_no;
 
 		if (0 != mysql_query(conn, sql))
 		{
-			errcode = (ER_DUP_ENTRY == mysql_errno(conn) ? ERR_Z3008 : ERR_Z3005);
-			zbx_db_errlog(errcode, mysql_errno(conn), mysql_error(conn), sql);
+			err_no = (int)mysql_errno(conn);
+			errcode = (ER_DUP_ENTRY == err_no ? ERR_Z3008 : ERR_Z3005);
+			zbx_db_errlog(errcode, err_no, mysql_error(conn), sql);
 
-			ret = (SUCCEED == is_recoverable_mysql_error() ? ZBX_DB_DOWN : ZBX_DB_FAIL);
+			ret = (SUCCEED == is_recoverable_mysql_error(err_no) ? ZBX_DB_DOWN : ZBX_DB_FAIL);
 		}
 		else
 		{
@@ -1487,10 +1501,11 @@ int	zbx_db_vexecute(const char *fmt, va_list args)
 				/* more results? 0 = yes (keep looping), -1 = no, >0 = error */
 				if (0 < (status = mysql_next_result(conn)))
 				{
-					errcode = (ER_DUP_ENTRY == mysql_errno(conn) ? ERR_Z3008 : ERR_Z3005);
-					zbx_db_errlog(errcode, mysql_errno(conn), mysql_error(conn), sql);
+					err_no = (int)mysql_errno(conn);
+					errcode = (ER_DUP_ENTRY == err_no ? ERR_Z3008 : ERR_Z3005);
+					zbx_db_errlog(errcode, err_no, mysql_error(conn), sql);
 
-					ret = (SUCCEED == is_recoverable_mysql_error() ? ZBX_DB_DOWN : ZBX_DB_FAIL);
+					ret = (SUCCEED == is_recoverable_mysql_error(err_no) ? ZBX_DB_DOWN : ZBX_DB_FAIL);
 				}
 			}
 			while (0 == status);
@@ -1643,10 +1658,13 @@ DB_RESULT	zbx_db_vselect(const char *fmt, va_list args)
 	{
 		if (0 != mysql_query(conn, sql) || NULL == (result->result = mysql_store_result(conn)))
 		{
-			zbx_db_errlog(ERR_Z3005, mysql_errno(conn), mysql_error(conn), sql);
+			int err_no;
+
+			err_no = (int)mysql_errno(conn);
+			zbx_db_errlog(ERR_Z3005, err_no, mysql_error(conn), sql);
 
 			DBfree_result(result);
-			result = (SUCCEED == is_recoverable_mysql_error() ? (DB_RESULT)ZBX_DB_DOWN : NULL);
+			result = (SUCCEED == is_recoverable_mysql_error(err_no) ? (DB_RESULT)ZBX_DB_DOWN : NULL);
 		}
 	}
 #elif defined(HAVE_ORACLE)
@@ -2987,10 +3005,3 @@ int	zbx_tsdb_get_compression_availability(void)
 	return ZBX_TIMESCALE_COMPRESSION_AVAILABLE;
 }
 #endif
-
-#if defined(HAVE_MYSQL)
-void zbx_db_set_character_set(const char *char_set)
-{
-	ZBX_CHARSET = zbx_strdup(ZBX_CHARSET, char_set);
-}
-#endif
