@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2025 Zabbix SIA
+** Copyright (C) 2001-2022 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -16,17 +16,14 @@
 ** along with this program; if not, write to the Free Software
 ** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 **/
+
+#include "dbconfig.h"
+
 #include "common.h"
 #include "log.h"
 #include "zbxalgo.h"
 #include "dbcache.h"
-#include "mutexs.h"
-
-#define ZBX_DBCONFIG_IMPL
-#include "dbconfig.h"
-
 #include "dbsync.h"
-#include "zbxserver.h"
 
 extern int		CONFIG_TIMER_FORKS;
 
@@ -45,8 +42,6 @@ typedef struct
 zbx_host_event_maintenance_t;
 
 /******************************************************************************
- *                                                                            *
- * Function: DCsync_maintenances                                              *
  *                                                                            *
  * Purpose: Updates maintenances in configuration cache                       *
  *                                                                            *
@@ -125,8 +120,6 @@ void	DCsync_maintenances(zbx_dbsync_t *sync)
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: dc_compare_maintenance_tags                                      *
  *                                                                            *
  * Purpose: compare maintenance tags by tag name for sorting                  *
  *                                                                            *
@@ -140,8 +133,6 @@ static int	dc_compare_maintenance_tags(const void *d1, const void *d2)
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: DCsync_maintenance_tags                                          *
  *                                                                            *
  * Purpose: Updates maintenance tags in configuration cache                   *
  *                                                                            *
@@ -245,8 +236,6 @@ void	DCsync_maintenance_tags(zbx_dbsync_t *sync)
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: DCsync_maintenance_periods                                       *
  *                                                                            *
  * Purpose: Updates maintenance period in configuration cache                 *
  *                                                                            *
@@ -337,8 +326,6 @@ void	DCsync_maintenance_periods(zbx_dbsync_t *sync)
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: DCsync_maintenance_groups                                        *
  *                                                                            *
  * Purpose: Updates maintenance groups in configuration cache                 *
  *                                                                            *
@@ -410,8 +397,6 @@ void	DCsync_maintenance_groups(zbx_dbsync_t *sync)
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: DCsync_maintenance_hosts                                         *
  *                                                                            *
  * Purpose: Updates maintenance hosts in configuration cache                  *
  *                                                                            *
@@ -500,9 +485,7 @@ void	DCsync_maintenance_hosts(zbx_dbsync_t *sync)
 
 /******************************************************************************
  *                                                                            *
- * Function: dc_substract_time                                                *
- *                                                                            *
- * Purpose: substract two local times with DST correction                     *
+ * Purpose: subtract two local times with DST correction                      *
  *                                                                            *
  * Parameter: minuend       - [IN] the minuend time                           *
  *            subtrahend    - [IN] the subtrahend time (may be negative)      *
@@ -511,7 +494,7 @@ void	DCsync_maintenance_hosts(zbx_dbsync_t *sync)
  * Return value: the resulting time difference in seconds                     *
  *                                                                            *
  ******************************************************************************/
-static time_t dc_substract_time(time_t minuend, int subtrahend, struct tm *tm)
+static time_t dc_subtract_time(time_t minuend, int subtrahend, struct tm *tm)
 {
 	time_t	diff, offset_min, offset_diff;
 
@@ -524,8 +507,6 @@ static time_t dc_substract_time(time_t minuend, int subtrahend, struct tm *tm)
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: dc_calculate_maintenance_period                                  *
  *                                                                            *
  * Purpose: calculate start time for the specified maintenance period         *
  *                                                                            *
@@ -565,11 +546,11 @@ static int	dc_calculate_maintenance_period(const zbx_dc_maintenance_t *maintenan
 				return FAIL;
 
 			tm = *localtime(&active_since);
-			active_since = dc_substract_time(active_since,
+			active_since = dc_subtract_time(active_since,
 					tm.tm_hour * SEC_PER_HOUR + tm.tm_min * SEC_PER_MIN + tm.tm_sec, &tm);
 
 			day = (start_date - active_since) / SEC_PER_DAY;
-			start_date = dc_substract_time(start_date, SEC_PER_DAY * (day % period->every), &tm);
+			start_date = dc_subtract_time(start_date, SEC_PER_DAY * (day % period->every), &tm);
 			break;
 		case TIMEPERIOD_TYPE_WEEKLY:
 			if (start_date < active_since)
@@ -577,10 +558,10 @@ static int	dc_calculate_maintenance_period(const zbx_dc_maintenance_t *maintenan
 
 			tm = *localtime(&active_since);
 			wday = (0 == tm.tm_wday ? 7 : tm.tm_wday) - 1;
-			active_since = dc_substract_time(active_since, wday * SEC_PER_DAY +
+			active_since = dc_subtract_time(active_since, wday * SEC_PER_DAY +
 					tm.tm_hour * SEC_PER_HOUR + tm.tm_min * SEC_PER_MIN + tm.tm_sec, &tm);
 
-			for (; start_date >= active_since; start_date = dc_substract_time(start_date, SEC_PER_DAY, &tm))
+			for (; start_date >= active_since; start_date = dc_subtract_time(start_date, SEC_PER_DAY, &tm))
 			{
 				/* check for every x week(s) */
 				week = (start_date - active_since) / SEC_PER_WEEK;
@@ -597,7 +578,7 @@ static int	dc_calculate_maintenance_period(const zbx_dc_maintenance_t *maintenan
 			}
 			break;
 		case TIMEPERIOD_TYPE_MONTHLY:
-			for (; start_date >= active_since; start_date = dc_substract_time(start_date, SEC_PER_DAY, &tm))
+			for (; start_date >= active_since; start_date = dc_subtract_time(start_date, SEC_PER_DAY, &tm))
 			{
 				/* check for month */
 				tm = *localtime(&start_date);
@@ -650,8 +631,6 @@ static int	dc_calculate_maintenance_period(const zbx_dc_maintenance_t *maintenan
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: dc_check_maintenance_period                                      *
  *                                                                            *
  * Purpose: calculates start time for the specified maintenance period and    *
  *          checks if we are inside the maintenance period                    *
@@ -675,8 +654,8 @@ static int	dc_check_maintenance_period(const zbx_dc_maintenance_t *maintenance,
 
 	tm = *localtime(&now);
 	seconds = tm.tm_hour * SEC_PER_HOUR + tm.tm_min * SEC_PER_MIN + tm.tm_sec;
-	period_start = dc_substract_time(now, seconds, &tm);
-	period_start = dc_substract_time(period_start, -period->start_time, &tm);
+	period_start = dc_subtract_time(now, seconds, &tm);
+	period_start = dc_subtract_time(period_start, -period->start_time, &tm);
 
 	tm = *localtime(&period_start);
 
@@ -687,7 +666,7 @@ static int	dc_check_maintenance_period(const zbx_dc_maintenance_t *maintenance,
 	}
 
 	if (now < period_start)
-		period_start = dc_substract_time(period_start, SEC_PER_DAY, &tm);
+		period_start = dc_subtract_time(period_start, SEC_PER_DAY, &tm);
 
 	rc = dc_calculate_maintenance_period(maintenance, period, period_start, &period_start, &period_end);
 
@@ -702,8 +681,6 @@ out:
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: zbx_dc_maintenance_set_update_flags                              *
  *                                                                            *
  * Purpose: sets maintenance update flags for all timers                      *
  *                                                                            *
@@ -723,8 +700,6 @@ void	zbx_dc_maintenance_set_update_flags(void)
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: zbx_dc_maintenance_reset_update_flag                             *
  *                                                                            *
  * Purpose: resets maintenance update flags for the specified timer           *
  *                                                                            *
@@ -750,8 +725,6 @@ void	zbx_dc_maintenance_reset_update_flag(int timer)
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: zbx_dc_maintenance_check_update_flag                             *
  *                                                                            *
  * Purpose: checks if the maintenance update flag is set for the specified    *
  *          timer                                                             *
@@ -782,8 +755,6 @@ int	zbx_dc_maintenance_check_update_flag(int timer)
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: zbx_dc_maintenance_check_update_flags                            *
  *                                                                            *
  * Purpose: checks if at least one maintenance update flag is set             *
  *                                                                            *
@@ -814,8 +785,6 @@ out:
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: zbx_dc_update_maintenances                                       *
  *                                                                            *
  * Purpose: update maintenance state depending on maintenance periods         *
  *                                                                            *
@@ -929,8 +898,6 @@ int	zbx_dc_update_maintenances(void)
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: dc_assign_maintenance_to_host                                    *
  *                                                                            *
  * Purpose: assign maintenance to a host, host can only be in one maintenance *
  *                                                                            *
@@ -959,8 +926,6 @@ static void	dc_assign_maintenance_to_host(zbx_hashset_t *host_maintenances, zbx_
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: dc_assign_event_maintenance_to_host                              *
  *                                                                            *
  * Purpose: assign maintenance to a host that event belongs to, events can be *
  *          in multiple maintenances at a time                                *
@@ -994,8 +959,6 @@ typedef void	(*assign_maintenance_to_host_f)(zbx_hashset_t *host_maintenances,
 		zbx_dc_maintenance_t *maintenance, zbx_uint64_t hostid);
 
 /******************************************************************************
- *                                                                            *
- * Function: dc_get_host_maintenances_by_ids                                  *
  *                                                                            *
  * Purpose: get hosts and their maintenances                                  *
  *                                                                            *
@@ -1059,8 +1022,6 @@ static void	dc_get_host_maintenances_by_ids(const zbx_vector_uint64_t *maintenan
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: dc_get_host_maintenance_updates                                  *
  *                                                                            *
  * Purpose: gets maintenance updates for all hosts                            *
  *                                                                            *
@@ -1129,8 +1090,6 @@ static void	dc_get_host_maintenance_updates(zbx_hashset_t *host_maintenances, zb
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: zbx_dc_flush_host_maintenance_updates                            *
  *                                                                            *
  * Purpose: flush host maintenance updates to configuration cache             *
  *                                                                            *
@@ -1189,8 +1148,6 @@ void	zbx_dc_flush_host_maintenance_updates(const zbx_vector_ptr_t *updates)
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: zbx_dc_get_host_maintenance_updates                              *
  *                                                                            *
  * Purpose: calculates required host maintenance updates based on specified   *
  *          maintenances                                                      *
@@ -1231,8 +1188,6 @@ void	zbx_dc_get_host_maintenance_updates(const zbx_vector_uint64_t *maintenancei
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: dc_maintenance_tag_match                                         *
  *                                                                            *
  * Purpose: perform maintenance tag comparison using maintenance tag operator *
  *                                                                            *
@@ -1252,8 +1207,6 @@ static int	dc_maintenance_tag_value_match(const zbx_dc_maintenance_tag_t *mt, co
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: dc_maintenance_match_tag_range                                   *
  *                                                                            *
  * Purpose: matches tags with [*mt_pos] maintenance tag name                  *
  *                                                                            *
@@ -1348,8 +1301,6 @@ static int	dc_maintenance_match_tag_range(const zbx_vector_ptr_t *mtags, const z
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: dc_maintenance_match_tags_or                                     *
  *                                                                            *
  * Purpose: matches maintenance and event tags using OR eval type             *
  *                                                                            *
@@ -1374,8 +1325,6 @@ static int	dc_maintenance_match_tags_or(const zbx_dc_maintenance_t *maintenance,
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: dc_maintenance_match_tags_andor                                  *
  *                                                                            *
  * Purpose: matches maintenance and event tags using AND/OR eval type         *
  *                                                                            *
@@ -1403,8 +1352,6 @@ static int	dc_maintenance_match_tags_andor(const zbx_dc_maintenance_t *maintenan
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: dc_maintenance_match_tags                                        *
  *                                                                            *
  * Purpose: check if the tags must be processed by the specified maintenance  *
  *                                                                            *
@@ -1440,8 +1387,6 @@ static int	dc_maintenance_match_tags(const zbx_dc_maintenance_t *maintenance, co
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: dc_compare_tags                                                  *
  *                                                                            *
  * Purpose: compare maintenance tags by tag name for sorting                  *
  *                                                                            *
@@ -1460,8 +1405,6 @@ static void	host_event_maintenance_clean(zbx_host_event_maintenance_t *host_even
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: zbx_dc_get_event_maintenances                                    *
  *                                                                            *
  * Purpose: get maintenance data for events                                   *
  *                                                                            *
@@ -1532,8 +1475,15 @@ int	zbx_dc_get_event_maintenances(zbx_vector_ptr_t *event_queries, const zbx_vec
 			{
 				continue;
 			}
-			get_functionids(&query->functionids, trigger->expression);
-			get_functionids(&query->functionids, trigger->recovery_expression);
+
+			zbx_get_serialized_expression_functionids(trigger->expression, trigger->expression_bin,
+					&query->functionids);
+
+			if (TRIGGER_RECOVERY_MODE_RECOVERY_EXPRESSION == trigger->recovery_mode)
+			{
+				zbx_get_serialized_expression_functionids(trigger->recovery_expression,
+						trigger->recovery_expression_bin, &query->functionids);
+			}
 		}
 
 		for (j = 0; j < query->functionids.values_num; j++)
@@ -1612,8 +1562,6 @@ unlock:
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: zbx_event_suppress_query_free                                    *
  *                                                                            *
  * Purpose: free event suppress query structure                               *
  *                                                                            *
@@ -1628,8 +1576,6 @@ void	zbx_event_suppress_query_free(zbx_event_suppress_query_t *query)
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: zbx_dc_get_running_maintenanceids                                *
  *                                                                            *
  * Purpose: get identifiers of the running maintenances                       *
  *                                                                            *
