@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2025 Zabbix SIA
+** Copyright (C) 2001-2022 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -19,7 +19,6 @@
 
 #include "common.h"
 #include "db.h"
-#include "sysinfo.h"
 #include "dbupgrade.h"
 #include "log.h"
 #include "sysinfo.h"
@@ -43,11 +42,9 @@ static int	DBmodify_proxy_table_id_field(const char *table_name)
 }
 
 /*********************************************************************************
- *                                                                               *
- * Function: parse_db_monitor_item_params                                        *
  *                                                                               *
  * Purpose: parse database monitor item params string "user=<user> password=     *
- *          <passsword> DSN=<dsn> sql=<sql>" into parameter values.              *
+ *          <password> DSN=<dsn> sql=<sql>" into parameter values.               *
  *                                                                               *
  * Parameters:  params     - [IN] the params string                              *
  *              dsn        - [OUT] the ODBC DSN output buffer                    *
@@ -1668,8 +1665,6 @@ static int	DBpatch_2010194(void)
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: DBpatch_2010195_replace_key_param_cb                             *
  *                                                                            *
  * Comments: auxiliary function for DBpatch_2010195()                         *
  *                                                                            *
