@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2025 Zabbix SIA
+** Copyright (C) 2001-2022 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -8,7 +8,7 @@
 ** (at your option) any later version.
 **
 ** This program is distributed in the hope that it will be useful,
-** but WITHOUT ANY WARRANTY; without even the implied warranty of
+** but WITHOUT ANY WARRANTY; without even the envied warranty of
 ** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 ** GNU General Public License for more details.
 **
@@ -17,18 +17,19 @@
 ** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 **/
 
-#include "common.h"
 #include "log.h"
-#include "zbxjson.h"
 #include "zbxembed.h"
-#include "embed.h"
+
 #include "httprequest.h"
 #include "zabbix.h"
 #include "global.h"
-
-#include "duktape.h"
+#include "console.h"
+#include "xml.h"
+#include "embed.h"
 
 #define ZBX_ES_MEMORY_LIMIT	(1024 * 1024 * 64)
+#define ZBX_ES_TIMEOUT		10
+
 #define ZBX_ES_STACK_LIMIT	1000
 
 /* maximum number of consequent runtime errors after which it's treated as fatal error */
@@ -38,8 +39,6 @@
 #define ZBX_ES_SCRIPT_FOOTER	"\n}"
 
 /******************************************************************************
- *                                                                            *
- * Function: es_handle_error                                                  *
  *                                                                            *
  * Purpose: fatal error handler                                               *
  *                                                                            *
@@ -125,7 +124,7 @@ static void	es_free(void *udata, void *ptr)
  * Purpose: decodes 3-byte utf-8 sequence                                     *
  *                                                                            *
  * Parameters: ptr - [IN] pointer to the 3 byte sequence                      *
- *             out - [OUT] decoded value                                      *
+ *             out - [OUT] the decoded value                                  *
  *                                                                            *
  * Return value: SUCCEED                                                      *
  *               FAIL                                                         *
@@ -242,23 +241,6 @@ fail:
 }
 
 /******************************************************************************
- *                                                                            *
- * Purpose: push result string on duktape value stack                         *
- *                                                                            *
- * Comments: The string might be modified by this function.                   *
- *                                                                            *
- ******************************************************************************/
-void	es_push_result_string(duk_context *ctx, char *str, size_t size)
-{
-	if (NULL != str)
-		zbx_replace_invalid_utf8(str);
-
-	duk_push_lstring(ctx, str, size);
-}
-
-/******************************************************************************
- *                                                                            *
- * Function: zbx_es_check_timeout                                             *
  *                                                                            *
  * Purpose: timeout checking callback                                         *
  *                                                                            *
@@ -274,8 +256,6 @@ int	zbx_es_check_timeout(void *udata)
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: zbx_es_init                                                      *
  *                                                                            *
  * Purpose: initializes embedded scripting engine                             *
  *                                                                            *
@@ -286,8 +266,6 @@ void	zbx_es_init(zbx_es_t *es)
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: zbx_es_destroy                                                   *
  *                                                                            *
  * Purpose: destroys embedded scripting engine                                *
  *                                                                            *
@@ -303,8 +281,6 @@ void	zbx_es_destroy(zbx_es_t *es)
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: zbx_es_init_env                                                  *
  *                                                                            *
  * Purpose: initializes embedded scripting engine environment                 *
  *                                                                            *
@@ -339,6 +315,9 @@ int	zbx_es_init_env(zbx_es_t *es, char **error)
 	/* initialize Zabbix object */
 	zbx_es_init_zabbix(es, error);
 
+	/* initialize console object */
+	zbx_es_init_console(es, error);
+
 	/* remove Duktape object */
 	duk_push_global_object(es->env->ctx);
 	duk_del_prop_string(es->env->ctx, -1, "Duktape");
@@ -348,16 +327,21 @@ int	zbx_es_init_env(zbx_es_t *es, char **error)
 
 	/* put environment object to be accessible from duktape C calls */
 	duk_push_global_stash(es->env->ctx);
-
-	duk_push_string(es->env->ctx, "\xff""\xff""zbx_env");
 	duk_push_pointer(es->env->ctx, (void *)es->env);
-	duk_def_prop(es->env->ctx, -3, DUK_DEFPROP_HAVE_VALUE | DUK_DEFPROP_CLEAR_WRITABLE | DUK_DEFPROP_HAVE_ENUMERABLE |
-			DUK_DEFPROP_HAVE_CONFIGURABLE);
+	if (1 != duk_put_prop_string(es->env->ctx, -2, "\xff""\xff""zbx_env"))
+	{
+		*error = zbx_strdup(*error, duk_safe_to_string(es->env->ctx, -1));
+		duk_pop(es->env->ctx);
+		return FAIL;
+	}
 
-	/* initialize CurlHttpRequest prototype */
+	/* initialize HttpRequest and CurlHttpRequest prototypes */
 	if (FAIL == zbx_es_init_httprequest(es, error))
 		goto out;
 
+	if (FAIL == zbx_es_init_xml(es, error))
+		goto out;
+
 	es->env->timeout = ZBX_ES_TIMEOUT;
 	ret = SUCCEED;
 out:
@@ -375,8 +359,6 @@ out:
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: zbx_es_destroy_env                                               *
  *                                                                            *
  * Purpose: destroys initialized embedded scripting engine environment        *
  *                                                                            *
@@ -414,8 +396,6 @@ out:
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: zbx_es_ready                                                     *
  *                                                                            *
  * Purpose: checks if the scripting engine environment is initialized         *
  *                                                                            *
@@ -431,8 +411,6 @@ int	zbx_es_is_env_initialized(zbx_es_t *es)
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: zbx_es_fatal_error                                               *
  *                                                                            *
  * Purpose: checks if fatal error has occurred                                *
  *                                                                            *
@@ -456,8 +434,6 @@ int	zbx_es_fatal_error(zbx_es_t *es)
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: zbx_es_compile                                                   *
  *                                                                            *
  * Purpose: compiles script into bytecode                                     *
  *                                                                            *
@@ -470,7 +446,7 @@ int	zbx_es_fatal_error(zbx_es_t *es)
  * Return value: SUCCEED                                                      *
  *               FAIL                                                         *
  *                                                                            *
- * Comments: The this function allocates the bytecode array, which must be    *
+ * Comments: this function allocates the bytecode array, which must be        *
  *           freed by the caller after being used.                            *
  *                                                                            *
  ******************************************************************************/
@@ -540,18 +516,16 @@ out:
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: zbx_es_execute                                                   *
  *                                                                            *
  * Purpose: executes script                                                   *
  *                                                                            *
- * Parameters: es     - [IN] the embedded scripting engine                    *
- *             script - [IN] the script to execute                            *
- *             code   - [IN] the precompiled bytecode                         *
- *             size   - [IN] the size of precompiled bytecode                 *
- *             param  - [IN] the parameter to pass to the script              *
- *             output - [OUT] the result value                                *
- *             error  - [OUT] the error message                               *
+ * Parameters: es         - [IN] the embedded scripting engine                *
+ *             script     - [IN] the script to execute                        *
+ *             code       - [IN] the precompiled bytecode                     *
+ *             size       - [IN] the size of precompiled bytecode             *
+ *             param      - [IN] the parameter to pass to the script          *
+ *             script_ret - [OUT] the result value                            *
+ *             error      - [OUT] the error message                           *
  *                                                                            *
  * Return value: SUCCEED                                                      *
  *               FAIL                                                         *
@@ -562,8 +536,8 @@ out:
  *           bytecode parameters.                                             *
  *                                                                            *
  ******************************************************************************/
-int	zbx_es_execute(zbx_es_t *es, const char *script, const char *code, int size, const char *param, char **output,
-	char **error)
+int	zbx_es_execute(zbx_es_t *es, const char *script, const char *code, int size, const char *param,
+	char **script_ret, char **error)
 {
 	void		*buffer;
 	volatile int	ret = FAIL;
@@ -571,8 +545,6 @@ int	zbx_es_execute(zbx_es_t *es, const char *script, const char *code, int size,
 	zabbix_log(LOG_LEVEL_DEBUG, "In %s() param:%s", __func__, param);
 
 	zbx_timespec(&es->env->start_time);
-	es->env->http_req_objects = 0;
-	es->env->logged_msgs = 0;
 
 	if (NULL != es->env->json)
 	{
@@ -624,24 +596,50 @@ int	zbx_es_execute(zbx_es_t *es, const char *script, const char *code, int size,
 		goto out;
 	}
 
-	if (0 == duk_check_type(es->env->ctx, -1, DUK_TYPE_UNDEFINED))
+	if (NULL != script_ret || SUCCEED == ZBX_CHECK_LOG_LEVEL(LOG_LEVEL_DEBUG))
 	{
-		if (0 != duk_check_type(es->env->ctx, -1, DUK_TYPE_NULL))
+		if (0 == duk_check_type(es->env->ctx, -1, DUK_TYPE_UNDEFINED))
 		{
-			ret = SUCCEED;
-			*output = NULL;
-			zabbix_log(LOG_LEVEL_DEBUG, "%s() output: null", __func__);
+			if (0 != duk_check_type(es->env->ctx, -1, DUK_TYPE_NULL))
+			{
+				ret = SUCCEED;
+
+				if (NULL != script_ret)
+					*script_ret = NULL;
+
+				zabbix_log(LOG_LEVEL_DEBUG, "%s() output: null", __func__);
+			}
+			else
+			{
+				char	*output = NULL;
+
+				if (SUCCEED != (ret = es_duktape_string_decode(
+						duk_safe_to_string(es->env->ctx, -1), &output)))
+				{
+					*error = zbx_strdup(*error, "could not convert return value to utf8");
+				}
+				else
+					zabbix_log(LOG_LEVEL_DEBUG, "%s() output:'%s'", __func__, output);
+
+				if (SUCCEED == ret && NULL != script_ret)
+					*script_ret = output;
+				else
+					zbx_free(output);
+			}
 		}
 		else
 		{
-			if (SUCCEED != (ret = es_duktape_string_decode(duk_safe_to_string(es->env->ctx, -1), output)))
-				*error = zbx_strdup(*error, "could not convert return value to utf8");
+			if (NULL == script_ret)
+			{
+				zabbix_log(LOG_LEVEL_DEBUG, "%s(): undefined return value", __func__);
+				ret = SUCCEED;
+			}
 			else
-				zabbix_log(LOG_LEVEL_DEBUG, "%s() output:'%s'", __func__, *output);
+				*error = zbx_strdup(*error, "undefined return value");
 		}
 	}
 	else
-		*error = zbx_strdup(*error, "undefined return value");
+		ret = SUCCEED;
 
 	duk_pop(es->env->ctx);
 	es->env->rt_error_num = 0;
@@ -658,8 +656,6 @@ out:
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: zbx_es_set_timeout                                               *
  *                                                                            *
  * Purpose: sets script execution timeout                                     *
  *                                                                            *
@@ -698,6 +694,79 @@ void	zbx_es_debug_disable(zbx_es_t *es)
 	zbx_free(es->env->json);
 }
 
+/******************************************************************************
+ *                                                                            *
+ * Purpose: executes command (script in form of a text)                       *
+ *                                                                            *
+ * Parameters: command       - [IN] the command in form of a text             *
+ *             param         - [IN] the script parameters                     *
+ *             timeout       - [IN] the timeout for the execution (seconds)   *
+ *             result        - [OUT] the result of an execution               *
+ *             error         - [OUT] the error message                        *
+ *             max_error_len - [IN] the maximum length of an error            *
+ *             debug         - [OUT] the debug data (optional)                *
+ *                                                                            *
+ * Return value: SUCCEED                                                      *
+ *               FAIL                                                         *
+ *                                                                            *
+ ******************************************************************************/
+int	zbx_es_execute_command(const char *command, const char *param, int timeout, char **result,
+		char *error, size_t max_error_len, char **debug)
+{
+	int		size, ret = SUCCEED;
+	char		*code = NULL, *errmsg = NULL;
+	zbx_es_t	es;
+
+	zabbix_log(LOG_LEVEL_DEBUG, "In %s()", __func__);
+
+	zbx_es_init(&es);
+	if (FAIL == zbx_es_init_env(&es, &errmsg))
+	{
+		zbx_snprintf(error, max_error_len, "cannot initialize scripting environment: %s", errmsg);
+		zbx_free(errmsg);
+		ret = FAIL;
+		goto failure;
+	}
+
+	if (NULL != debug)
+		zbx_es_debug_enable(&es);
+
+	if (FAIL == zbx_es_compile(&es, command, &code, &size, &errmsg))
+	{
+		zbx_snprintf(error, max_error_len, "cannot compile script: %s", errmsg);
+		zbx_free(errmsg);
+		ret = FAIL;
+		goto out;
+	}
+
+	if (0 != timeout)
+		zbx_es_set_timeout(&es, timeout);
+
+	if (FAIL == zbx_es_execute(&es, NULL, code, size, param, result, &errmsg))
+	{
+		zbx_snprintf(error, max_error_len, "cannot execute script: %s", errmsg);
+		zbx_free(errmsg);
+		ret = FAIL;
+		goto out;
+	}
+out:
+	if (NULL != debug)
+		*debug = zbx_strdup(NULL, zbx_es_debug_info(&es));
+
+	if (FAIL == zbx_es_destroy_env(&es, &errmsg))
+	{
+		zabbix_log(LOG_LEVEL_WARNING, "cannot destroy embedded scripting engine environment: %s", errmsg);
+		zbx_free(errmsg);
+	}
+
+	zbx_free(code);
+	zbx_free(errmsg);
+failure:
+	zabbix_log(LOG_LEVEL_DEBUG, "End of %s():%s", __func__, zbx_result_string(ret));
+
+	return ret;
+}
+
 zbx_es_env_t	*zbx_es_get_env(duk_context *ctx)
 {
 	zbx_es_env_t	*env;
