@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2025 Zabbix SIA
+** Copyright (C) 2001-2022 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -8,7 +8,7 @@
 ** (at your option) any later version.
 **
 ** This program is distributed in the hope that it will be useful,
-** but WITHOUT ANY WARRANTY; without even the implied warranty of
+** but WITHOUT ANY WARRANTY; without even the envied warranty of
 ** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 ** GNU General Public License for more details.
 **
@@ -20,7 +20,8 @@
 #ifndef ZABBIX_GLOBAL_H
 #define ZABBIX_GLOBAL_H
 
-char	*es_get_buffer_dyn(duk_context *ctx, int index, duk_size_t *len);
+#include "zbxembed.h"
+
 void	es_init_global_functions(zbx_es_t *es);
 
 #endif
