@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2025 Zabbix SIA
+** Copyright (C) 2001-2022 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -8,7 +8,7 @@
 ** (at your option) any later version.
 **
 ** This program is distributed in the hope that it will be useful,
-** but WITHOUT ANY WARRANTY; without even the implied warranty of
+** but WITHOUT ANY WARRANTY; without even the envied warranty of
 ** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 ** GNU General Public License for more details.
 **
@@ -17,15 +17,14 @@
 ** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 **/
 
+#include "httprequest.h"
+
 #include "common.h"
-#include "log.h"
 #include "zbxjson.h"
 #include "zbxhttp.h"
-#include "zbxembed.h"
-#include "httprequest.h"
 #include "embed.h"
 #include "duktape.h"
-#include "global.h"
+#include "zbxalgo.h"
 
 #ifdef HAVE_LIBCURL
 
@@ -52,7 +51,6 @@ typedef struct
 	size_t			headers_in_alloc;
 	size_t			headers_in_offset;
 	unsigned char		custom_header;
-	size_t			headers_sz;
 }
 zbx_es_httprequest_t;
 
@@ -89,8 +87,6 @@ static size_t	curl_header_cb(void *ptr, size_t size, size_t nmemb, void *userdat
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: es_httprequest                                                   *
  *                                                                            *
  * Purpose: return backing C structure embedded in CurlHttpRequest object     *
  *                                                                            *
@@ -108,8 +104,6 @@ static zbx_es_httprequest_t *es_httprequest(duk_context *ctx)
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: es_httprequest_dtor                                              *
  *                                                                            *
  * Purpose: CurlHttpRequest destructor                                        *
  *                                                                            *
@@ -119,16 +113,9 @@ static duk_ret_t	es_httprequest_dtor(duk_context *ctx)
 	zbx_es_httprequest_t	*request;
 
 	duk_get_prop_string(ctx, 0, "\xff""\xff""d");
-
-	if (NULL != (request = (zbx_es_httprequest_t *)duk_to_pointer(ctx, -1)))
+	request = (zbx_es_httprequest_t *)duk_to_pointer(ctx, -1);
+	if (NULL != request)
 	{
-		zbx_es_env_t	*env;
-
-		if (NULL == (env = zbx_es_get_env(ctx)))
-			return duk_error(ctx, DUK_RET_TYPE_ERROR, "cannot access internal environment");
-
-		env->http_req_objects--;
-
 		if (NULL != request->headers)
 			curl_slist_free_all(request->headers);
 		if (NULL != request->handle)
@@ -145,29 +132,19 @@ static duk_ret_t	es_httprequest_dtor(duk_context *ctx)
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: es_httprequest_ctor                                              *
  *                                                                            *
  * Purpose: CurlHttpRequest constructor                                       *
  *                                                                            *
  ******************************************************************************/
 static duk_ret_t	es_httprequest_ctor(duk_context *ctx)
 {
-#define MAX_HTTPREQUEST_OBJECT_COUNT	10
 	zbx_es_httprequest_t	*request;
 	CURLcode		err;
-	zbx_es_env_t		*env;
 	int			err_index = -1;
 
 	if (!duk_is_constructor_call(ctx))
 		return DUK_RET_TYPE_ERROR;
 
-	if (NULL == (env = zbx_es_get_env(ctx)))
-		return duk_error(ctx, DUK_RET_TYPE_ERROR, "cannot access internal environment");
-
-	if (MAX_HTTPREQUEST_OBJECT_COUNT == env->http_req_objects)
-		return duk_error(ctx, DUK_RET_EVAL_ERROR, "maximum count of HttpRequest objects was reached");
-
 	duk_push_this(ctx);
 
 	request = (zbx_es_httprequest_t *)zbx_malloc(NULL, sizeof(zbx_es_httprequest_t));
@@ -190,10 +167,8 @@ static duk_ret_t	es_httprequest_ctor(duk_context *ctx)
 	ZBX_CURL_SETOPT(ctx, request->handle, CURLOPT_HEADERDATA, request, err);
 	ZBX_CURL_SETOPT(ctx, request->handle, CURLOPT_INTERFACE, CONFIG_SOURCE_IP, err);
 
-	duk_push_string(ctx, "\xff""\xff""d");
 	duk_push_pointer(ctx, request);
-	duk_def_prop(ctx, -3, DUK_DEFPROP_HAVE_VALUE | DUK_DEFPROP_CLEAR_WRITABLE | DUK_DEFPROP_HAVE_ENUMERABLE |
-			DUK_DEFPROP_HAVE_CONFIGURABLE);
+	duk_put_prop_string(ctx, -2, "\xff""\xff""d");
 
 	duk_push_c_function(ctx, es_httprequest_dtor, 1);
 	duk_set_finalizer(ctx, -2);
@@ -207,51 +182,33 @@ out:
 		return duk_throw(ctx);
 	}
 
-	env->http_req_objects++;
-
 	return 0;
-#undef MAX_HTTPREQUEST_OBJECT_COUNT
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: es_httprequest_add_header                                        *
  *                                                                            *
  * Purpose: CurlHttpRequest.SetHeader method                                  *
  *                                                                            *
  ******************************************************************************/
 static duk_ret_t	es_httprequest_add_header(duk_context *ctx)
 {
-#define ZBX_ES_MAX_HEADERS_SIZE	ZBX_KIBIBYTE * 128
 	zbx_es_httprequest_t	*request;
 	CURLcode		err;
 	char			*utf8 = NULL;
 	int			err_index = -1;
-	size_t			header_sz;
 
 	if (NULL == (request = es_httprequest(ctx)))
 		return duk_error(ctx, DUK_RET_EVAL_ERROR, "internal scripting error: null object");
 
-	if (SUCCEED != es_duktape_string_decode(duk_safe_to_string(ctx, 0), &utf8))
+	if (SUCCEED != es_duktape_string_decode(duk_to_string(ctx, 0), &utf8))
 	{
 		err_index = duk_push_error_object(ctx, DUK_RET_TYPE_ERROR, "cannot convert header to utf8");
 		goto out;
 	}
 
-	header_sz = strlen(utf8);
-
-	if (ZBX_ES_MAX_HEADERS_SIZE < request->headers_sz + header_sz)
-	{
-		err_index = duk_push_error_object(ctx, DUK_RET_TYPE_ERROR, "headers exceeded maximum size of "
-				ZBX_FS_UI64 " bytes.", ZBX_ES_MAX_HEADERS_SIZE);
-
-		goto out;
-	}
-
 	request->headers = curl_slist_append(request->headers, utf8);
 	ZBX_CURL_SETOPT(ctx, request->handle, CURLOPT_HTTPHEADER, request->headers, err);
 	request->custom_header = 1;
-	request->headers_sz += header_sz + 1;
 out:
 	zbx_free(utf8);
 
@@ -259,12 +216,9 @@ out:
 		return duk_throw(ctx);
 
 	return 0;
-#undef ZBX_ES_MAX_HEADERS_SIZE
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: es_httprequest_clear_header                                      *
  *                                                                            *
  * Purpose: CurlHttpRequest.ClearHeader method                                *
  *                                                                            *
@@ -279,14 +233,11 @@ static duk_ret_t	es_httprequest_clear_header(duk_context *ctx)
 	curl_slist_free_all(request->headers);
 	request->headers = NULL;
 	request->custom_header = 0;
-	request->headers_sz = 0;
 
 	return 0;
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: es_httprequest_query                                             *
  *                                                                            *
  * Purpose: CurlHttpRequest HTTP request implementation                       *
  *                                                                            *
@@ -302,7 +253,6 @@ static duk_ret_t	es_httprequest_query(duk_context *ctx, const char *http_request
 	int			err_index = -1;
 	zbx_es_env_t		*env;
 	zbx_uint64_t		timeout_ms, elapsed_ms;
-	duk_size_t		contents_len = 0;
 
 	if (NULL == (env = zbx_es_get_env(ctx)))
 		return duk_error(ctx, DUK_RET_TYPE_ERROR, "cannot access internal environment");
@@ -316,7 +266,7 @@ static duk_ret_t	es_httprequest_query(duk_context *ctx, const char *http_request
 		goto out;
 	}
 
-	if (SUCCEED != es_duktape_string_decode(duk_safe_to_string(ctx, 0), &url))
+	if (SUCCEED != es_duktape_string_decode(duk_to_string(ctx, 0), &url))
 	{
 		err_index = duk_push_error_object(ctx, DUK_RET_TYPE_ERROR, "cannot convert URL to utf8");
 		goto out;
@@ -324,9 +274,10 @@ static duk_ret_t	es_httprequest_query(duk_context *ctx, const char *http_request
 
 	if (0 == duk_is_null_or_undefined(ctx, 1))
 	{
-		if (NULL == (contents = es_get_buffer_dyn(ctx, 1, &contents_len)))
+		if (SUCCEED != es_duktape_string_decode(duk_to_string(ctx, 1), &contents))
 		{
-			err_index = duk_push_error_object(ctx, DUK_RET_TYPE_ERROR, "cannot obtain second parameter");
+			err_index = duk_push_error_object(ctx, DUK_RET_TYPE_ERROR,
+					"cannot convert request contents to utf8");
 			goto out;
 		}
 	}
@@ -347,10 +298,9 @@ static duk_ret_t	es_httprequest_query(duk_context *ctx, const char *http_request
 		{
 			curl_slist_free_all(request->headers);
 			request->headers = NULL;
-			request->headers_sz = 0;
 		}
 
-		if (NULL != contents && DUK_TYPE_STRING == duk_get_type(ctx, 1))
+		if (NULL != contents)
 		{
 			if (SUCCEED == zbx_json_open(contents, &jp))
 				request->headers = curl_slist_append(NULL, "Content-Type: application/json");
@@ -363,12 +313,7 @@ static duk_ret_t	es_httprequest_query(duk_context *ctx, const char *http_request
 	ZBX_CURL_SETOPT(ctx, request->handle, CURLOPT_CUSTOMREQUEST, http_request, err);
 	ZBX_CURL_SETOPT(ctx, request->handle, CURLOPT_TIMEOUT_MS, timeout_ms - elapsed_ms, err);
 	ZBX_CURL_SETOPT(ctx, request->handle, CURLOPT_POSTFIELDS, ZBX_NULL2EMPTY_STR(contents), err);
-	ZBX_CURL_SETOPT(ctx, request->handle, CURLOPT_POSTFIELDSIZE, (long)contents_len, err);
 	ZBX_CURL_SETOPT(ctx, request->handle, ZBX_CURLOPT_ACCEPT_ENCODING, "", err);
-#if LIBCURL_VERSION_NUM >= 0x071304
-	/* CURLOPT_PROTOCOLS is supported starting with version 7.19.4 (0x071304) */
-	ZBX_CURL_SETOPT(ctx, request->handle, CURLOPT_PROTOCOLS, CURLPROTO_HTTP | CURLPROTO_HTTPS, err);
-#endif
 
 	request->data_offset = 0;
 	request->headers_in_offset = 0;
@@ -386,16 +331,14 @@ out:
 	if (-1 != err_index)
 		return duk_throw(ctx);
 
-	es_push_result_string(ctx, request->data, request->data_offset);
+	duk_push_lstring(ctx, request->data, request->data_offset);
 
 	return 1;
 }
 
 /******************************************************************************
  *                                                                            *
- * Function: es_httprequest_get                                               *
- *                                                                            *
- * Purpose: CurlHttpRequest.Get method                                        *
+ * Purpose: HttpRequest.Get / CurlHttpRequest.Get method                      *
  *                                                                            *
  ******************************************************************************/
 static duk_ret_t	es_httprequest_get(duk_context *ctx)
@@ -405,9 +348,7 @@ static duk_ret_t	es_httprequest_get(duk_context *ctx)
 
 /******************************************************************************
  *                                                                            *
- * Function: es_httprequest_put                                               *
- *                                                                            *
- * Purpose: CurlHttpRequest.Put method                                        *
+ * Purpose: HttpRequest.Put / CurlHttpRequest.Put method                      *
  *                                                                            *
  ******************************************************************************/
 static duk_ret_t	es_httprequest_put(duk_context *ctx)
@@ -417,9 +358,7 @@ static duk_ret_t	es_httprequest_put(duk_context *ctx)
 
 /******************************************************************************
  *                                                                            *
- * Function: es_httprequest_post                                              *
- *                                                                            *
- * Purpose: CurlHttpRequest.Post method                                       *
+ * Purpose: HttpRequest.Post / CurlHttpRequest.Post method                    *
  *                                                                            *
  ******************************************************************************/
 static duk_ret_t	es_httprequest_post(duk_context *ctx)
@@ -429,9 +368,7 @@ static duk_ret_t	es_httprequest_post(duk_context *ctx)
 
 /******************************************************************************
  *                                                                            *
- * Function: es_httprequest_delete                                            *
- *                                                                            *
- * Purpose: CurlHttpRequest.Delete method                                     *
+ * Purpose: HttpRequest.Delete / CurlHttpRequest.Delete method                *
  *                                                                            *
  ******************************************************************************/
 static duk_ret_t	es_httprequest_delete(duk_context *ctx)
@@ -441,7 +378,73 @@ static duk_ret_t	es_httprequest_delete(duk_context *ctx)
 
 /******************************************************************************
  *                                                                            *
- * Function: es_httprequest_set_proxy                                         *
+ * Purpose: HttpRequest.head method                                           *
+ *                                                                            *
+ ******************************************************************************/
+static duk_ret_t	es_httprequest_head(duk_context *ctx)
+{
+	return es_httprequest_query(ctx, "HEAD");
+}
+
+/******************************************************************************
+ *                                                                            *
+ * Purpose: HttpRequest.patch method                                          *
+ *                                                                            *
+ ******************************************************************************/
+static duk_ret_t	es_httprequest_patch(duk_context *ctx)
+{
+	return es_httprequest_query(ctx, "PATCH");
+}
+
+/******************************************************************************
+ *                                                                            *
+ * Purpose: HttpRequest.options method                                        *
+ *                                                                            *
+ ******************************************************************************/
+static duk_ret_t	es_httprequest_options(duk_context *ctx)
+{
+	return es_httprequest_query(ctx, "OPTIONS");
+}
+
+/******************************************************************************
+ *                                                                            *
+ * Purpose: HttpRequest.trace method                                          *
+ *                                                                            *
+ ******************************************************************************/
+static duk_ret_t	es_httprequest_trace(duk_context *ctx)
+{
+	return es_httprequest_query(ctx, "TRACE");
+}
+
+/******************************************************************************
+ *                                                                            *
+ * Purpose: HttpRequest.connect method                                        *
+ *                                                                            *
+ ******************************************************************************/
+static duk_ret_t	es_httprequest_connect(duk_context *ctx)
+{
+	return es_httprequest_query(ctx, "CONNECT");
+}
+
+/******************************************************************************
+ *                                                                            *
+ * Purpose: HttpRequest.customRequest method                                  *
+ *                                                                            *
+ ******************************************************************************/
+static duk_ret_t	es_httprequest_customrequest(duk_context *ctx)
+{
+	const char	*method;
+
+	if (0 != duk_is_null_or_undefined(ctx, 0))
+		return duk_error(ctx, DUK_RET_EVAL_ERROR, "HTTP method cannot be undefined or null");
+
+	method = duk_to_string(ctx, 0);
+	duk_remove(ctx, 0);
+
+	return es_httprequest_query(ctx, method);
+}
+
+/******************************************************************************
  *                                                                            *
  * Purpose: CurlHttpRequest.SetProxy method                                   *
  *                                                                            *
@@ -455,7 +458,7 @@ static duk_ret_t	es_httprequest_set_proxy(duk_context *ctx)
 	if (NULL == (request = es_httprequest(ctx)))
 		return duk_error(ctx, DUK_RET_EVAL_ERROR, "internal scripting error: null object");
 
-	ZBX_CURL_SETOPT(ctx, request->handle, CURLOPT_PROXY, duk_safe_to_string(ctx, 0), err);
+	ZBX_CURL_SETOPT(ctx, request->handle, CURLOPT_PROXY, duk_to_string(ctx, 0), err);
 out:
 	if (-1 != err_index)
 		return duk_throw(ctx);
@@ -464,8 +467,6 @@ out:
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: es_httprequest_status                                            *
  *                                                                            *
  * Purpose: CurlHttpRequest.Status method                                     *
  *                                                                            *
@@ -489,7 +490,29 @@ static duk_ret_t	es_httprequest_status(duk_context *ctx)
 
 /******************************************************************************
  *                                                                            *
- * Function: es_obj_put_http_header                                           *
+ * Purpose: retrieves value of a header                                       *
+ *                                                                            *
+ * Parameters: header    - [IN] the http header to extract value from         *
+ *             value_out - [OUT] the value                                    *
+ *                                                                            *
+ ******************************************************************************/
+static int	parse_header(char *header, char **value_out)
+{
+	char *value;
+
+	if (NULL == (value = strchr(header, ':')))
+		return FAIL;
+
+	*value++ = '\0';
+	while (' ' == *value || '\t' == *value)
+		value++;
+
+	*value_out = value;
+
+	return SUCCEED;
+}
+
+/******************************************************************************
  *                                                                            *
  * Purpose: puts http header <field>: <value> as object property/value        *
  *                                                                            *
@@ -502,14 +525,10 @@ static void	es_put_header(duk_context *ctx, int idx, char *header)
 {
 	char	*value;
 
-	if (NULL == (value = strchr(header, ':')))
+	if (FAIL == parse_header(header, &value))
 		return;
 
-	*value++ = '\0';
-	while (' ' == *value || '\t' == *value)
-		value++;
-
-	es_push_result_string(ctx, value, strlen(value));
+	duk_push_string(ctx, value);
 
 	/* duk_put_prop_string() throws error on failure, no need to check return code */
 	(void)duk_put_prop_string(ctx, idx, header);
@@ -517,26 +536,23 @@ static void	es_put_header(duk_context *ctx, int idx, char *header)
 
 /******************************************************************************
  *                                                                            *
- * Function: es_httprequest_get_headers                                       *
+ * Purpose: retrieve headers from request in form of strings                  *
  *                                                                            *
- * Purpose: CurlHttpRequest.GetHeaders method                                 *
+ * Parameters: ctx     - [IN] the duktape context                             *
+ *             request - [IN] the request to retrieve headers from            *
  *                                                                            *
  ******************************************************************************/
-static duk_ret_t	es_httprequest_get_headers(duk_context *ctx)
+static duk_ret_t	get_headers_as_strings(duk_context *ctx, zbx_es_httprequest_t *request)
 {
-	zbx_es_httprequest_t	*request;
-	duk_idx_t		idx;
 	char			*ptr, *header;
-
-	if (NULL == (request = es_httprequest(ctx)))
-		return duk_error(ctx, DUK_RET_EVAL_ERROR, "internal scripting error: null object");
+	duk_idx_t		idx;
 
 	idx = duk_push_object(ctx);
 
 	if (0 == request->headers_in_offset)
 		return 1;
 
-	for (ptr = request->headers_in; NULL != (header = zbx_http_get_header(&ptr)); )
+	for (ptr = request->headers_in; NULL != (header = zbx_http_parse_header(&ptr)); )
 	{
 		es_put_header(ctx, idx, header);
 		zbx_free(header);
@@ -545,9 +561,128 @@ static duk_ret_t	es_httprequest_get_headers(duk_context *ctx)
 	return 1;
 }
 
+typedef struct
+{
+	char			*name;
+	zbx_vector_str_t	values;
+}
+zbx_cached_header_t;
+
+static void	cached_headers_free(zbx_cached_header_t *header)
+{
+	zbx_vector_str_clear_ext(&header->values, zbx_str_free);
+	zbx_vector_str_destroy(&header->values);
+	zbx_free(header->name);
+	zbx_free(header);
+}
+
 /******************************************************************************
  *                                                                            *
- * Function: es_httprequest_set_httpauth                                      *
+ * Purpose: retrieve headers from request in form of arrays                   *
+ *                                                                            *
+ * Parameters: ctx     - [IN] the duktape context                             *
+ *             request - [IN] the request to retrieve headers from            *
+ *                                                                            *
+ ******************************************************************************/
+static duk_ret_t	get_headers_as_arrays(duk_context *ctx, zbx_es_httprequest_t *request)
+{
+	char			*ptr, *header;
+	zbx_vector_ptr_t	headers;
+	duk_idx_t		idx;
+	int			i, j;
+
+	zbx_vector_ptr_create(&headers);
+
+	idx = duk_push_object(ctx);
+
+	if (0 == request->headers_in_offset)
+		goto out;
+
+	for (ptr = request->headers_in; NULL != (header = zbx_http_parse_header(&ptr)); )
+	{
+		char			*value;
+		zbx_cached_header_t	*existing_header = NULL;
+
+		if (FAIL == parse_header(header, &value))
+		{
+			zbx_free(header);
+			continue;
+		}
+
+		for (j = 0; j < headers.values_num; j++)
+		{
+			zbx_cached_header_t *h = (zbx_cached_header_t*)headers.values[j];
+
+			if (0 == strcmp(header, h->name))
+			{
+				existing_header = h;
+				zbx_vector_str_append(&existing_header->values, zbx_strdup(NULL, value));
+				zbx_free(header);
+
+				break;
+			}
+		}
+
+		if (NULL == existing_header)
+		{
+			zbx_cached_header_t	*cached_header;
+
+			cached_header = zbx_malloc(NULL, sizeof(zbx_cached_header_t));
+
+			cached_header->name = header;
+			zbx_vector_str_create(&cached_header->values);
+			zbx_vector_str_append(&cached_header->values, zbx_strdup(NULL, value));
+			zbx_vector_ptr_append(&headers, cached_header);
+		}
+	}
+
+	for (i = 0; i < headers.values_num; i++) {
+		zbx_cached_header_t	*h = (zbx_cached_header_t*)headers.values[i];
+		duk_idx_t		arr_idx;
+
+		arr_idx = duk_push_array(ctx);
+
+		for (j = 0; j < h->values.values_num; j++)
+		{
+			duk_push_string(ctx, h->values.values[j]);
+			duk_put_prop_index(ctx, arr_idx, (duk_uarridx_t)j);
+		}
+
+		(void)duk_put_prop_string(ctx, idx, h->name);
+	}
+
+out:
+	zbx_vector_ptr_clear_ext(&headers, (zbx_mem_free_func_t)cached_headers_free);
+	zbx_vector_ptr_destroy(&headers);
+	return 1;
+}
+
+/******************************************************************************
+ *                                                                            *
+ * Purpose: HttpRequest.getHeaders / CurlHttpRequest.GetHeaders method        *
+ *                                                                            *
+ ******************************************************************************/
+static duk_ret_t	es_httprequest_get_headers(duk_context *ctx)
+{
+	zbx_es_httprequest_t	*request;
+
+	if (NULL == (request = es_httprequest(ctx)))
+		return duk_error(ctx, DUK_RET_EVAL_ERROR, "internal scripting error: null object");
+
+	if (0 == duk_is_null_or_undefined(ctx, 0))
+	{
+		duk_bool_t	as_array;
+
+		as_array = duk_to_boolean(ctx, 0);
+
+		if (0 != as_array)
+			return get_headers_as_arrays(ctx, request);
+	}
+
+	return get_headers_as_strings(ctx, request);
+}
+
+/******************************************************************************
  *                                                                            *
  * Purpose: CurlHttpRequest.SetHttpAuth method                                *
  *                                                                            *
@@ -569,7 +704,7 @@ static duk_ret_t	es_httprequest_set_httpauth(duk_context *ctx)
 
 	if (0 == duk_is_null_or_undefined(ctx, 1))
 	{
-		if (SUCCEED != es_duktape_string_decode(duk_safe_to_string(ctx, 1), &username))
+		if (SUCCEED != es_duktape_string_decode(duk_to_string(ctx, 1), &username))
 		{
 			err_index = duk_push_error_object(ctx, DUK_RET_TYPE_ERROR, "cannot convert username to utf8");
 			goto out;
@@ -578,7 +713,7 @@ static duk_ret_t	es_httprequest_set_httpauth(duk_context *ctx)
 
 	if (0 == duk_is_null_or_undefined(ctx, 2))
 	{
-		if (SUCCEED != es_duktape_string_decode(duk_safe_to_string(ctx, 2), &password))
+		if (SUCCEED != es_duktape_string_decode(duk_to_string(ctx, 2), &password))
 		{
 			err_index = duk_push_error_object(ctx, DUK_RET_TYPE_ERROR, "cannot convert username to utf8");
 			goto out;
@@ -592,6 +727,7 @@ static duk_ret_t	es_httprequest_set_httpauth(duk_context *ctx)
 
 	if (NULL != password)
 		ZBX_CURL_SETOPT(ctx, request->handle, CURLOPT_PASSWORD, password, err);
+
 out:
 	zbx_free(password);
 	zbx_free(username);
@@ -602,7 +738,7 @@ out:
 	return 0;
 }
 
-static const duk_function_list_entry	httprequest_methods[] = {
+static const duk_function_list_entry	curlhttprequest_methods[] = {
 	{"AddHeader", es_httprequest_add_header, 1},
 	{"ClearHeader", es_httprequest_clear_header, 0},
 	{"Get", es_httprequest_get, 2},
@@ -611,11 +747,31 @@ static const duk_function_list_entry	httprequest_methods[] = {
 	{"Delete", es_httprequest_delete, 2},
 	{"Status", es_httprequest_status, 0},
 	{"SetProxy", es_httprequest_set_proxy, 1},
-	{"GetHeaders", es_httprequest_get_headers, 0},
+	{"GetHeaders", es_httprequest_get_headers, 1},
 	{"SetHttpAuth", es_httprequest_set_httpauth, 3},
 	{NULL, NULL, 0}
 };
 
+static const duk_function_list_entry	httprequest_methods[] = {
+	{"addHeader", es_httprequest_add_header, 1},
+	{"clearHeader", es_httprequest_clear_header, 0},
+	{"get", es_httprequest_get, 2},
+	{"put", es_httprequest_put, 2},
+	{"post", es_httprequest_post, 2},
+	{"delete", es_httprequest_delete, 2},
+	{"head", es_httprequest_head, 2},
+	{"patch", es_httprequest_patch, 2},
+	{"options", es_httprequest_options, 2},
+	{"trace", es_httprequest_trace, 2},
+	{"connect", es_httprequest_connect, 2},
+	{"getStatus", es_httprequest_status, 0},
+	{"setProxy", es_httprequest_set_proxy, 1},
+	{"getHeaders", es_httprequest_get_headers, 1},
+	{"setHttpAuth", es_httprequest_set_httpauth, 3},
+	{"customRequest", es_httprequest_customrequest, 3},
+	{NULL, NULL, 0}
+};
+
 #else
 
 static duk_ret_t	es_httprequest_ctor(duk_context *ctx)
@@ -629,19 +785,22 @@ static duk_ret_t	es_httprequest_ctor(duk_context *ctx)
 static const duk_function_list_entry	httprequest_methods[] = {
 	{NULL, NULL, 0}
 };
+
+static const duk_function_list_entry	*curlhttprequest_methods = httprequest_methods;
 #endif
 
-static int	es_httprequest_create_prototype(duk_context *ctx)
+static int	es_httprequest_create_prototype(duk_context *ctx, const char *obj_name,
+		const duk_function_list_entry *methods)
 {
 	duk_push_c_function(ctx, es_httprequest_ctor, 0);
 	duk_push_object(ctx);
 
-	duk_put_function_list(ctx, -1, httprequest_methods);
+	duk_put_function_list(ctx, -1, methods);
 
 	if (1 != duk_put_prop_string(ctx, -2, "prototype"))
 		return FAIL;
 
-	if (1 != duk_put_global_string(ctx, "CurlHttpRequest"))
+	if (1 != duk_put_global_string(ctx, obj_name))
 		return FAIL;
 
 	return SUCCEED;
@@ -655,7 +814,8 @@ int	zbx_es_init_httprequest(zbx_es_t *es, char **error)
 		return FAIL;
 	}
 
-	if (FAIL == es_httprequest_create_prototype(es->env->ctx))
+	if (FAIL == es_httprequest_create_prototype(es->env->ctx, "CurlHttpRequest", curlhttprequest_methods) ||
+			FAIL == es_httprequest_create_prototype(es->env->ctx, "HttpRequest", httprequest_methods))
 	{
 		*error = zbx_strdup(*error, duk_safe_to_string(es->env->ctx, -1));
 		duk_pop(es->env->ctx);
