@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2025 Zabbix SIA
+** Copyright (C) 2001-2022 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -9,7 +9,7 @@
 **
 ** This program is distributed in the hope that it will be useful,
 ** but WITHOUT ANY WARRANTY; without even the implied warranty of
-** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 ** GNU General Public License for more details.
 **
 ** You should have received a copy of the GNU General Public License
@@ -17,13 +17,11 @@
 ** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 **/
 
-#include "common.h"
 #include "punycode.h"
+
 #include "zbxhttp.h"
 
 /******************************************************************************
- *                                                                            *
- * Function: punycode_adapt                                                   *
  *                                                                            *
  * Purpose: after each delta is encoded or decoded, bias should be set for    *
  *          the next delta (should be adapted)                                *
@@ -51,8 +49,6 @@ static zbx_uint32_t	punycode_adapt(zbx_uint32_t delta, int count, int divisor)
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: punycode_encode_digit                                            *
  *                                                                            *
  * Purpose: encodes punycode digit into ansi character [a-z0-9]               *
  *                                                                            *
@@ -74,9 +70,7 @@ static char	punycode_encode_digit(int digit)
 
 /******************************************************************************
  *                                                                            *
- * Function: punycode_encode_codepoints                                       *
- *                                                                            *
- * Purpose: encodes array of unicode codepoints into into punycode (RFC 3492) *
+ * Purpose: encodes array of unicode codepoints into punycode (RFC 3492)      *
  *                                                                            *
  * Parameters: codepoints      - [IN] codepoints to encode                    *
  *             count           - [IN] codepoint count                         *
@@ -180,8 +174,6 @@ out:
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: punycode_encode_part                                             *
  *                                                                            *
  * Purpose: encodes unicode domain name part into punycode (RFC 3492)         *
  *          domain is being split in parts by punycode_encode by using        *
@@ -234,8 +226,6 @@ static int	punycode_encode_part(zbx_uint32_t *codepoints, zbx_uint32_t count, ch
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: zbx_http_punycode_encode                                         *
  *                                                                            *
  * Purpose: encodes unicode domain names into punycode (RFC 3492)             *
  *                                                                            *
@@ -310,8 +300,6 @@ out:
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: zbx_http_punycode_encode_url                                     *
  *                                                                            *
  * Purpose: encodes unicode domain name in URL into punycode                  *
  *                                                                            *
@@ -366,4 +354,3 @@ int	zbx_http_punycode_encode_url(char **url)
 
 	return SUCCEED;
 }
-
