@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2025 Zabbix SIA
+** Copyright (C) 2001-2022 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -17,22 +17,18 @@
 ** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 **/
 
-#include "common.h"
+#include "json.h"
+
 #include "zbxjson.h"
 #include "json_parser.h"
-#include "json.h"
 #include "jsonpath.h"
 
 /******************************************************************************
- *                                                                            *
- * Function: zbx_json_strerror                                                *
  *                                                                            *
  * Purpose: return string describing json error                               *
  *                                                                            *
  * Return value: pointer to the null terminated string                        *
  *                                                                            *
- * Author: Eugene Grigorjev                                                   *
- *                                                                            *
  ******************************************************************************/
 #define ZBX_JSON_MAX_STRERROR	255
 
@@ -66,13 +62,6 @@ void	zbx_set_json_strerror(const char *fmt, ...)
 	va_end(args);
 }
 
-/******************************************************************************
- *                                                                            *
- * Function: __zbx_json_realloc                                               *
- *                                                                            *
- * Author: Alexander Vladishev                                                *
- *                                                                            *
- ******************************************************************************/
 static void	__zbx_json_realloc(struct zbx_json *j, size_t need)
 {
 	int	realloc = 0;
@@ -212,8 +201,6 @@ static size_t	__zbx_json_stringsize(const char *string, zbx_json_type_t type)
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: zbx_num2hex                                                      *
  *                                                                            *
  * Purpose: convert parameter c (0-15) to hexadecimal value ('0'-'f')         *
  *                                                                            *
@@ -223,8 +210,6 @@ static size_t	__zbx_json_stringsize(const char *string, zbx_json_type_t type)
  * Return value:                                                              *
  *      '0'-'f'                                                               *
  *                                                                            *
- * Author: Alexander Vladishev                                                *
- *                                                                            *
  ******************************************************************************/
 static char	zbx_num2hex(unsigned char c)
 {
@@ -492,13 +477,7 @@ int	zbx_json_close(struct zbx_json *j)
 
 /******************************************************************************
  *                                                                            *
- * Function: __zbx_json_type                                                  *
- *                                                                            *
- * Purpose: return type of pointed value                                      *
- *                                                                            *
- * Return value: type of pointed value                                        *
- *                                                                            *
- * Author: Alexander Vladishev                                                *
+ * Return value: type of input value                                          *
  *                                                                            *
  ******************************************************************************/
 static zbx_json_type_t	__zbx_json_type(const char *p)
@@ -525,15 +504,9 @@ static zbx_json_type_t	__zbx_json_type(const char *p)
 
 /******************************************************************************
  *                                                                            *
- * Function: __zbx_json_rbracket                                              *
- *                                                                            *
- * Purpose: return position of right bracket                                  *
- *                                                                            *
- * Return value: position of right bracket                                    *
+ * Return value: position of the right bracket                                *
  *               NULL - an error occurred                                     *
  *                                                                            *
- * Author: Alexander Vladishev                                                *
- *                                                                            *
  ******************************************************************************/
 static const char	*__zbx_json_rbracket(const char *p)
 {
@@ -584,8 +557,6 @@ static const char	*__zbx_json_rbracket(const char *p)
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: zbx_json_open                                                    *
  *                                                                            *
  * Purpose: open json buffer and check for brackets                           *
  *                                                                            *
@@ -628,8 +599,6 @@ int	zbx_json_open(const char *buffer, struct zbx_json_parse *jp)
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: zbx_json_next                                                    *
  *                                                                            *
  * Purpose: locate next pair or element                                       *
  *                                                                            *
@@ -638,8 +607,6 @@ int	zbx_json_open(const char *buffer, struct zbx_json_parse *jp)
  *      {"name",...    or  "array":["name", ... ,1,null]                      *
  * p =   ^                                         ^                          *
  *                                                                            *
- * Author: Alexander Vladishev                                                *
- *                                                                            *
  ******************************************************************************/
 const char	*zbx_json_next(const struct zbx_json_parse *jp, const char *p)
 {
@@ -697,8 +664,6 @@ const char	*zbx_json_next(const struct zbx_json_parse *jp, const char *p)
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: zbx_is_valid_json_hex                                            *
  *                                                                            *
  * Purpose: check if a 4 character sequence is a valid hex number 0000 - FFFF *
  *                                                                            *
@@ -722,8 +687,6 @@ static int	zbx_is_valid_json_hex(const char *p)
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: zbx_hex2num                                                      *
  *                                                                            *
  * Purpose: convert hexit c ('0'-'9''a'-'f''A'-'F') to number (0-15)          *
  *                                                                            *
@@ -733,8 +696,6 @@ static int	zbx_is_valid_json_hex(const char *p)
  * Return value:                                                              *
  *      0-15                                                                  *
  *                                                                            *
- * Author: Alexander Vladishev                                                *
- *                                                                            *
  ******************************************************************************/
 static unsigned int	zbx_hex2num(char c)
 {
@@ -751,8 +712,6 @@ static unsigned int	zbx_hex2num(char c)
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: zbx_json_decode_character                                        *
  *                                                                            *
  * Purpose: decodes JSON escape character into UTF-8                          *
  *                                                                            *
@@ -870,8 +829,6 @@ static unsigned int	zbx_json_decode_character(const char **p, unsigned char *byt
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: zbx_json_copy_string                                             *
  *                                                                            *
  * Purpose: copies json name/string value by omitting leading/trailing " and  *
  *          converting escape sequences                                       *
@@ -895,11 +852,11 @@ static const char	*zbx_json_copy_string(const char *p, char *out, size_t size)
 
 	while ('\0' != *p)
 	{
+		unsigned int	nbytes, i;
+		unsigned char	uc[4];	/* decoded Unicode character takes 1-4 bytes in UTF-8 */
+
 		switch (*p)
 		{
-			unsigned int	nbytes, i;
-			unsigned char	uc[4];	/* decoded Unicode character takes 1-4 bytes in UTF-8 */
-
 			case '\\':
 				++p;
 				if (0 == (nbytes = zbx_json_decode_character(&p, uc)))
@@ -927,8 +884,6 @@ static const char	*zbx_json_copy_string(const char *p, char *out, size_t size)
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: zbx_json_copy_value                                              *
  *                                                                            *
  * Purpose: copies unquoted (numeric, boolean) json value                     *
  *                                                                            *
@@ -1046,8 +1001,6 @@ const char	*zbx_json_pair_next(const struct zbx_json_parse *jp, const char *p, c
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: zbx_json_pair_by_name                                            *
  *                                                                            *
  * Purpose: find pair by name and return pointer to value                     *
  *                                                                            *
@@ -1055,8 +1008,6 @@ const char	*zbx_json_pair_next(const struct zbx_json_parse *jp, const char *p, c
  *        {"name":["a","b",...]}                                              *
  *                ^ - returned pointer                                        *
  *                                                                            *
- * Author: Alexander Vladishev                                                *
- *                                                                            *
  ******************************************************************************/
 const char	*zbx_json_pair_by_name(const struct zbx_json_parse *jp, const char *name)
 {
@@ -1072,13 +1023,6 @@ const char	*zbx_json_pair_by_name(const struct zbx_json_parse *jp, const char *n
 	return NULL;
 }
 
-/******************************************************************************
- *                                                                            *
- * Function: zbx_json_next_value                                              *
- *                                                                            *
- * Author: Alexander Vladishev                                                *
- *                                                                            *
- ******************************************************************************/
 const char	*zbx_json_next_value(const struct zbx_json_parse *jp, const char *p, char *string, size_t len,
 		zbx_json_type_t *type)
 {
@@ -1088,11 +1032,6 @@ const char	*zbx_json_next_value(const struct zbx_json_parse *jp, const char *p,
 	return zbx_json_decodevalue(p, string, len, type);
 }
 
-/******************************************************************************
- *                                                                            *
- * Function: zbx_json_next_value_dyn                                          *
- *                                                                            *
- ******************************************************************************/
 const char	*zbx_json_next_value_dyn(const struct zbx_json_parse *jp, const char *p, char **string,
 		size_t *string_alloc, zbx_json_type_t *type)
 {
@@ -1103,15 +1042,11 @@ const char	*zbx_json_next_value_dyn(const struct zbx_json_parse *jp, const char
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: zbx_json_value_by_name                                           *
  *                                                                            *
  * Purpose: return value by pair name                                         *
  *                                                                            *
  * Return value: SUCCEED - if value successfully parsed, FAIL - otherwise     *
  *                                                                            *
- * Author: Alexander Vladishev                                                *
- *                                                                            *
  ******************************************************************************/
 int	zbx_json_value_by_name(const struct zbx_json_parse *jp, const char *name, char *string, size_t len,
 		zbx_json_type_t *type)
@@ -1128,15 +1063,11 @@ int	zbx_json_value_by_name(const struct zbx_json_parse *jp, const char *name, ch
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: zbx_json_value_by_name_dyn                                       *
  *                                                                            *
  * Purpose: return value by pair name                                         *
  *                                                                            *
  * Return value: SUCCEED - if value successfully parsed, FAIL - otherwise     *
  *                                                                            *
- * Author: Alexander Vladishev                                                *
- *                                                                            *
  ******************************************************************************/
 int	zbx_json_value_by_name_dyn(const struct zbx_json_parse *jp, const char *name, char **string,
 		size_t *string_alloc, zbx_json_type_t *type)
@@ -1153,14 +1084,10 @@ int	zbx_json_value_by_name_dyn(const struct zbx_json_parse *jp, const char *name
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: zbx_json_brackets_open                                           *
  *                                                                            *
  * Return value: SUCCESS - processed successfully                             *
  *               FAIL - an error occurred                                     *
  *                                                                            *
- * Author: Alexander Vladishev                                                *
- *                                                                            *
  ******************************************************************************/
 int	zbx_json_brackets_open(const char *p, struct zbx_json_parse *jp)
 {
@@ -1178,14 +1105,10 @@ int	zbx_json_brackets_open(const char *p, struct zbx_json_parse *jp)
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: zbx_json_brackets_by_name                                        *
  *                                                                            *
  * Return value: SUCCESS - processed successfully                             *
  *               FAIL - an error occurred                                     *
  *                                                                            *
- * Author: Alexander Vladishev                                                *
- *                                                                            *
  ******************************************************************************/
 int	zbx_json_brackets_by_name(const struct zbx_json_parse *jp, const char *name, struct zbx_json_parse *out)
 {
@@ -1201,14 +1124,10 @@ int	zbx_json_brackets_by_name(const struct zbx_json_parse *jp, const char *name,
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: zbx_json_object_is_empty                                         *
  *                                                                            *
  * Return value: SUCCESS - if object is empty                                 *
  *               FAIL - if object contains data                               *
  *                                                                            *
- * Author: Alexander Vladishev                                                *
- *                                                                            *
  ******************************************************************************/
 int	zbx_json_object_is_empty(const struct zbx_json_parse *jp)
 {
@@ -1216,13 +1135,9 @@ int	zbx_json_object_is_empty(const struct zbx_json_parse *jp)
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: zbx_json_count                                                   *
  *                                                                            *
  * Return value: number of elements in zbx_json_parse object                  *
  *                                                                            *
- * Author: Alexander Vladishev                                                *
- *                                                                            *
  ******************************************************************************/
 int	zbx_json_count(const struct zbx_json_parse *jp)
 {
@@ -1235,23 +1150,38 @@ int	zbx_json_count(const struct zbx_json_parse *jp)
 	return num;
 }
 
-int	json_open_path(const struct zbx_json_parse *jp, const zbx_jsonpath_t *jsonpath, struct zbx_json_parse *out)
+/******************************************************************************
+ *                                                                            *
+ * Purpose: opens an object by definite json path                             *
+ *                                                                            *
+ * Return value: SUCCESS - processed successfully                             *
+ *               FAIL - an error occurred                                     *
+ *                                                                            *
+ * Comments: Only direct path to single object in dot or bracket notation     *
+ *           is supported.                                                    *
+ *                                                                            *
+ ******************************************************************************/
+int	zbx_json_open_path(const struct zbx_json_parse *jp, const char *path, struct zbx_json_parse *out)
 {
 	int			i, ret = FAIL;
 	struct zbx_json_parse	object;
+	zbx_jsonpath_t		jsonpath;
 
 	object = *jp;
 
-	if (0 == jsonpath->definite)
+	if (FAIL == zbx_jsonpath_compile(path, &jsonpath))
+		return FAIL;
+
+	if (0 == jsonpath.definite)
 	{
 		zbx_set_json_strerror("cannot use indefinite path when opening sub element");
 		goto out;
 	}
 
-	for (i = 0; i < jsonpath->segments_num; i++)
+	for (i = 0; i < jsonpath.segments_num; i++)
 	{
 		const char		*p;
-		zbx_jsonpath_segment_t	*segment = &jsonpath->segments[i];
+		zbx_jsonpath_segment_t	*segment = &jsonpath.segments[i];
 
 		if (ZBX_JSONPATH_SEGMENT_MATCH_LIST != segment->type)
 		{
@@ -1295,33 +1225,11 @@ int	json_open_path(const struct zbx_json_parse *jp, const zbx_jsonpath_t *jsonpa
 	*out = object;
 	ret = SUCCEED;
 out:
-	return ret;
-}
-
-/******************************************************************************
- *                                                                            *
- * Function: zbx_json_open_path                                               *
- *                                                                            *
- * Purpose: opens an object by definite json path                             *
- *                                                                            *
- * Return value: SUCCESS - processed successfully                             *
- *               FAIL - an error occurred                                     *
- *                                                                            *
- * Comments: Only direct path to single object in dot or bracket notation     *
- *           is supported.                                                    *
- *                                                                            *
- ******************************************************************************/
-int	zbx_json_open_path(const struct zbx_json_parse *jp, const char *path, struct zbx_json_parse *out)
-{
-	zbx_jsonpath_t		jsonpath;
-	int			ret;
-
-	if (FAIL == zbx_jsonpath_compile(path, &jsonpath))
-		return FAIL;
-
-	ret = json_open_path(jp, &jsonpath, out);
-
 	zbx_jsonpath_clear(&jsonpath);
-
 	return ret;
 }
+
+zbx_json_type_t	zbx_json_valuetype(const char *p)
+{
+	return __zbx_json_type(p);
+}
