@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2025 Zabbix SIA
+** Copyright (C) 2001-2022 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -17,6 +17,8 @@
 ** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 **/
 
+#include "selfmon.h"
+
 #include "zbxself.h"
 #include "common.h"
 
@@ -44,7 +46,7 @@ typedef struct
 	/* the current process state (see ZBX_PROCESS_STATE_* defines) */
 	unsigned char	state;
 }
-zxb_stat_process_cache_t;
+zbx_stat_process_cache_t;
 
 /* process state statistics */
 typedef struct
@@ -59,7 +61,7 @@ typedef struct
 	zbx_uint64_t			counter_used[ZBX_PROCESS_STATE_COUNT];
 
 	/* the process state cache */
-	zxb_stat_process_cache_t	cache;
+	zbx_stat_process_cache_t	cache;
 }
 zbx_stat_process_t;
 
@@ -86,7 +88,6 @@ static int			shm_id;
 static zbx_mutex_t	sm_lock = ZBX_MUTEX_NULL;
 #endif
 
-extern char	*CONFIG_FILE;
 extern int	CONFIG_POLLER_FORKS;
 extern int	CONFIG_UNREACHABLE_POLLER_FORKS;
 extern int	CONFIG_IPMIPOLLER_FORKS;
@@ -118,13 +119,16 @@ extern int	CONFIG_PREPROCESSOR_FORKS;
 extern int	CONFIG_LLDMANAGER_FORKS;
 extern int	CONFIG_LLDWORKER_FORKS;
 extern int	CONFIG_ALERTDB_FORKS;
+extern int	CONFIG_HISTORYPOLLER_FORKS;
+extern int	CONFIG_AVAILMAN_FORKS;
+extern int	CONFIG_SERVICEMAN_FORKS;
+extern int	CONFIG_TRIGGERHOUSEKEEPER_FORKS;
+extern int	CONFIG_ODBCPOLLER_FORKS;
 
-extern unsigned char	process_type;
-extern int		process_num;
+extern ZBX_THREAD_LOCAL unsigned char	process_type;
+extern ZBX_THREAD_LOCAL int		process_num;
 
 /******************************************************************************
- *                                                                            *
- * Function: get_process_type_forks                                           *
  *                                                                            *
  * Purpose: Returns number of processes depending on process type             *
  *                                                                            *
@@ -132,8 +136,6 @@ extern int		process_num;
  *                                                                            *
  * Return value: number of processes                                          *
  *                                                                            *
- * Author: Alexander Vladishev                                                *
- *                                                                            *
  ******************************************************************************/
 int	get_process_type_forks(unsigned char proc_type)
 {
@@ -201,22 +203,27 @@ int	get_process_type_forks(unsigned char proc_type)
 			return CONFIG_LLDWORKER_FORKS;
 		case ZBX_PROCESS_TYPE_ALERTSYNCER:
 			return CONFIG_ALERTDB_FORKS;
+		case ZBX_PROCESS_TYPE_HISTORYPOLLER:
+			return CONFIG_HISTORYPOLLER_FORKS;
+		case ZBX_PROCESS_TYPE_AVAILMAN:
+			return CONFIG_AVAILMAN_FORKS;
+		case ZBX_PROCESS_TYPE_SERVICEMAN:
+			return CONFIG_SERVICEMAN_FORKS;
+		case ZBX_PROCESS_TYPE_TRIGGERHOUSEKEEPER:
+			return CONFIG_TRIGGERHOUSEKEEPER_FORKS;
+		case ZBX_PROCESS_TYPE_ODBCPOLLER:
+			return CONFIG_ODBCPOLLER_FORKS;
 	}
 
-	THIS_SHOULD_NEVER_HAPPEN;
-	exit(EXIT_FAILURE);
+	return get_component_process_type_forks(proc_type);
 }
 
 #ifndef _WINDOWS
 /******************************************************************************
- *                                                                            *
- * Function: init_selfmon_collector                                           *
  *                                                                            *
  * Purpose: Initialize structures and prepare state                           *
  *          for self-monitoring collector                                     *
  *                                                                            *
- * Author: Alexander Vladishev                                                *
- *                                                                            *
  ******************************************************************************/
 int	init_selfmon_collector(char **error)
 {
@@ -282,13 +289,9 @@ out:
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: free_selfmon_collector                                           *
  *                                                                            *
  * Purpose: Free memory allocated for self-monitoring collector               *
  *                                                                            *
- * Author: Alexander Vladishev                                                *
- *                                                                            *
  ******************************************************************************/
 void	free_selfmon_collector(void)
 {
@@ -299,14 +302,9 @@ void	free_selfmon_collector(void)
 
 	LOCK_SM;
 
+	(void)shmdt(collector);
 	collector = NULL;
 
-	if (-1 == shmctl(shm_id, IPC_RMID, 0))
-	{
-		zabbix_log(LOG_LEVEL_WARNING, "cannot remove shared memory for self-monitoring collector: %s",
-				zbx_strerror(errno));
-	}
-
 	UNLOCK_SM;
 
 	zbx_mutex_destroy(&sm_lock);
@@ -315,13 +313,9 @@ void	free_selfmon_collector(void)
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: update_selfmon_counter                                           *
  *                                                                            *
  * Parameters: state - [IN] new process state; ZBX_PROCESS_STATE_*            *
  *                                                                            *
- * Author: Alexander Vladishev                                                *
- *                                                                            *
  ******************************************************************************/
 void	update_selfmon_counter(unsigned char state)
 {
@@ -385,13 +379,6 @@ void	update_selfmon_counter(unsigned char state)
 	process->cache.ticks = ticks;
 }
 
-/******************************************************************************
- *                                                                            *
- * Function: collect_selfmon_stats                                            *
- *                                                                            *
- * Author: Alexander Vladishev                                                *
- *                                                                            *
- ******************************************************************************/
 void	collect_selfmon_stats(void)
 {
 	zbx_stat_process_t	*process;
@@ -467,8 +454,6 @@ out:
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: get_selfmon_stats                                                *
  *                                                                            *
  * Purpose: calculate statistics for selected process                         *
  *                                                                            *
@@ -480,8 +465,6 @@ out:
  *             value        - [OUT] a pointer to a variable that receives     *
  *                                  requested statistics                      *
  *                                                                            *
- * Author: Alexander Vladishev                                                *
- *                                                                            *
  ******************************************************************************/
 void	get_selfmon_stats(unsigned char proc_type, unsigned char aggr_func, int proc_num, unsigned char state,
 		double *value)
@@ -566,8 +549,6 @@ unlock:
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: zbx_get_all_process_stats                                        *
  *                                                                            *
  * Purpose: retrieves internal metrics of all running processes based on      *
  *          process type                                                      *
@@ -669,15 +650,11 @@ unlock:
 static int	sleep_remains;
 
 /******************************************************************************
- *                                                                            *
- * Function: zbx_sleep_loop                                                   *
  *                                                                            *
  * Purpose: sleeping process                                                  *
  *                                                                            *
  * Parameters: sleeptime - [IN] required sleeptime, in seconds                *
  *                                                                            *
- * Author: Alexander Vladishev                                                *
- *                                                                            *
  ******************************************************************************/
 void	zbx_sleep_loop(int sleeptime)
 {
@@ -697,21 +674,6 @@ void	zbx_sleep_loop(int sleeptime)
 	update_selfmon_counter(ZBX_PROCESS_STATE_BUSY);
 }
 
-void	zbx_sleep_forever(void)
-{
-	sleep_remains = 1;
-
-	update_selfmon_counter(ZBX_PROCESS_STATE_IDLE);
-
-	do
-	{
-		sleep(1);
-	}
-	while (0 != sleep_remains);
-
-	update_selfmon_counter(ZBX_PROCESS_STATE_BUSY);
-}
-
 void	zbx_wakeup(void)
 {
 	sleep_remains = 0;
