@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2025 Zabbix SIA
+** Copyright (C) 2001-2022 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -17,14 +17,12 @@
 ** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 **/
 
+#include "dns.h"
+
 #include "common.h"
 #include "sysinfo.h"
-
 #include "comms.h"
 #include "log.h"
-#include "cfg.h"
-
-#include "dns.h"
 #include "zbxalgo.h"
 
 #if defined(_WINDOWS) || defined(__MINGW32__)
@@ -638,8 +636,7 @@ static int	dns_query(AGENT_REQUEST *request, AGENT_RESULT *result, int short_ans
 	{
 		if (NULL == (name = get_name(answer.buffer, msg_end, &msg_ptr)))
 		{
-			SET_MSG_RESULT(result, zbx_strdup(NULL,
-					"Cannot decode DNS response: cannot expand domain name."));
+			SET_MSG_RESULT(result, zbx_strdup(NULL, "Cannot decode DNS response."));
 			ret = SYSINFO_RET_FAIL;
 			goto clean;
 		}
@@ -652,13 +649,6 @@ static int	dns_query(AGENT_REQUEST *request, AGENT_RESULT *result, int short_ans
 		GETSHORT(q_len, msg_ptr);
 		offset += zbx_snprintf(buffer + offset, sizeof(buffer) - offset, " %-8s", decode_type(q_type));
 
-		if (msg_ptr + q_len > msg_end)
-		{
-			SET_MSG_RESULT(result, zbx_strdup(NULL, "Cannot decode DNS response: record overflow."));
-			ret = SYSINFO_RET_FAIL;
-			goto clean;
-		}
-
 		switch (q_type)
 		{
 			case T_A:
@@ -703,40 +693,8 @@ static int	dns_query(AGENT_REQUEST *request, AGENT_RESULT *result, int short_ans
 			case T_PTR:
 				if (NULL == (name = get_name(answer.buffer, msg_end, &msg_ptr)))
 				{
-#define ERR_MSG_PREFIX	"Cannot decode DNS response: cannot expand "
-					const char	*err_msg = NULL;
-
-					switch (q_type)
-					{
-						case T_NS:
-							err_msg = ERR_MSG_PREFIX "name server name.";
-							break;
-						case T_CNAME:
-							err_msg = ERR_MSG_PREFIX "canonical name.";
-							break;
-						case T_MB:
-							err_msg = ERR_MSG_PREFIX "mailbox name.";
-							break;
-						case T_MD:
-							err_msg = ERR_MSG_PREFIX "mail destination name.";
-							break;
-						case T_MF:
-							err_msg = ERR_MSG_PREFIX "mail forwarder name.";
-							break;
-						case T_MG:
-							err_msg = ERR_MSG_PREFIX "mail group name.";
-							break;
-						case T_MR:
-							err_msg = ERR_MSG_PREFIX "renamed mailbox name.";
-							break;
-						case T_PTR:
-							err_msg = ERR_MSG_PREFIX "PTR name.";
-							break;
-					}
-
-					SET_MSG_RESULT(result, zbx_strdup(NULL, err_msg));
+					SET_MSG_RESULT(result, zbx_strdup(NULL, "Cannot decode DNS response."));
 					return SYSINFO_RET_FAIL;
-#undef ERR_MSG_PREFIX
 				}
 				offset += zbx_snprintf(buffer + offset, sizeof(buffer) - offset, " %s", name);
 				break;
@@ -746,8 +704,7 @@ static int	dns_query(AGENT_REQUEST *request, AGENT_RESULT *result, int short_ans
 
 				if (NULL == (name = get_name(answer.buffer, msg_end, &msg_ptr)))	/* exchange */
 				{
-					SET_MSG_RESULT(result, zbx_strdup(NULL, "Cannot decode DNS response:"
-							" cannot expand mail exchange name."));
+					SET_MSG_RESULT(result, zbx_strdup(NULL, "Cannot decode DNS response."));
 					return SYSINFO_RET_FAIL;
 				}
 				offset += zbx_snprintf(buffer + offset, sizeof(buffer) - offset, " %s", name);
@@ -756,16 +713,14 @@ static int	dns_query(AGENT_REQUEST *request, AGENT_RESULT *result, int short_ans
 			case T_SOA:
 				if (NULL == (name = get_name(answer.buffer, msg_end, &msg_ptr)))	/* source host */
 				{
-					SET_MSG_RESULT(result, zbx_strdup(NULL, "Cannot decode DNS response:"
-							" cannot expand source nameserver name."));
+					SET_MSG_RESULT(result, zbx_strdup(NULL, "Cannot decode DNS response."));
 					return SYSINFO_RET_FAIL;
 				}
 				offset += zbx_snprintf(buffer + offset, sizeof(buffer) - offset, " %s", name);
 
 				if (NULL == (name = get_name(answer.buffer, msg_end, &msg_ptr)))	/* administrator */
 				{
-					SET_MSG_RESULT(result, zbx_strdup(NULL, "Cannot decode DNS response:"
-							" cannot expand administrator mailbox name."));
+					SET_MSG_RESULT(result, zbx_strdup(NULL, "Cannot decode DNS response."));
 					return SYSINFO_RET_FAIL;
 				}
 				offset += zbx_snprintf(buffer + offset, sizeof(buffer) - offset, " %s", name);
@@ -793,8 +748,7 @@ static int	dns_query(AGENT_REQUEST *request, AGENT_RESULT *result, int short_ans
 			case T_WKS:
 				if (INT32SZ + 1 > q_len)
 				{
-					SET_MSG_RESULT(result, zbx_strdup(NULL, "Cannot decode DNS response:"
-							" malformed WKS resource record."));
+					SET_MSG_RESULT(result, zbx_strdup(NULL, "Cannot decode DNS response."));
 					return SYSINFO_RET_FAIL;
 				}
 
@@ -860,16 +814,14 @@ static int	dns_query(AGENT_REQUEST *request, AGENT_RESULT *result, int short_ans
 			case T_MINFO:
 				if (NULL == (name = get_name(answer.buffer, msg_end, &msg_ptr)))	/* mailbox responsible for mailing lists */
 				{
-					SET_MSG_RESULT(result, zbx_strdup(NULL, "Cannot decode DNS response:"
-							" cannot expand mailbox responsible for mailing lists."));
+					SET_MSG_RESULT(result, zbx_strdup(NULL, "Cannot decode DNS response."));
 					return SYSINFO_RET_FAIL;
 				}
 				offset += zbx_snprintf(buffer + offset, sizeof(buffer) - offset, " %s", name);
 
 				if (NULL == (name = get_name(answer.buffer, msg_end, &msg_ptr)))	/* mailbox for error messages */
 				{
-					SET_MSG_RESULT(result, zbx_strdup(NULL, "Cannot decode DNS response:"
-							" cannot expand mailbox for error messages."));
+					SET_MSG_RESULT(result, zbx_strdup(NULL, "Cannot decode DNS response."));
 					return SYSINFO_RET_FAIL;
 				}
 				offset += zbx_snprintf(buffer + offset, sizeof(buffer) - offset, " %s", name);
@@ -900,8 +852,7 @@ static int	dns_query(AGENT_REQUEST *request, AGENT_RESULT *result, int short_ans
 
 				if (NULL == (name = get_name(answer.buffer, msg_end, &msg_ptr)))	/* target */
 				{
-					SET_MSG_RESULT(result, zbx_strdup(NULL, "Cannot decode DNS response:"
-							" cannot expand service target hostname."));
+					SET_MSG_RESULT(result, zbx_strdup(NULL, "Cannot decode DNS response."));
 					return SYSINFO_RET_FAIL;
 				}
 				offset += zbx_snprintf(buffer + offset, sizeof(buffer) - offset, " %s", name);
