@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2025 Zabbix SIA
+** Copyright (C) 2001-2022 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -20,7 +20,8 @@
 #ifndef ZABBIX_SYSINFO_COMMON_DNS_H
 #define ZABBIX_SYSINFO_COMMON_DNS_H
 
-#include "sysinfo.h"
+#include "module.h"
+#include "config.h"
 
 #if defined(HAVE_RES_QUERY) || defined(_WINDOWS) || defined(__MINGW32__)
 
