@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2025 Zabbix SIA
+** Copyright (C) 2001-2022 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -20,7 +20,7 @@
 #ifndef ZABBIX_SYSINFO_COMMON_HTTP_H
 #define ZABBIX_SYSINFO_COMMON_HTTP_H
 
-#include "sysinfo.h"
+#include "module.h"
 
 extern char	*CONFIG_SOURCE_IP;
 
