@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2025 Zabbix SIA
+** Copyright (C) 2001-2022 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -19,7 +19,7 @@
 
 #include "common.h"
 #include "sysinfo.h"
-#include "../common/common.h"
+#include "../common/zbxsysinfo_common.h"
 #include "log.h"
 
 static struct ifmibdata	ifmd;
