@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2025 Zabbix SIA
+** Copyright (C) 2001-2022 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -17,6 +17,8 @@
 ** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 **/
 
+#include "simple.h"
+
 #include "common.h"
 #include "sysinfo.h"
 #include "comms.h"
@@ -25,7 +27,6 @@
 #include "telnet.h"
 #include "../common/net.h"
 #include "ntp.h"
-#include "simple.h"
 
 #ifdef HAVE_LDAP
 #	include <ldap.h>
@@ -190,17 +191,6 @@ static int	check_https(const char *host, unsigned short port, int timeout, int *
 		goto clean;
 	}
 
-#if LIBCURL_VERSION_NUM >= 0x071304
-	/* CURLOPT_PROTOCOLS is supported starting with version 7.19.4 (0x071304) */
-	if (CURLE_OK != (err = curl_easy_setopt(easyhandle, opt = CURLOPT_PROTOCOLS,
-			CURLPROTO_HTTP | CURLPROTO_HTTPS)))
-	{
-		zabbix_log(LOG_LEVEL_DEBUG, "%s: could not set cURL option [%d]: %s",
-				__func__, (int)opt, curl_easy_strerror(err));
-		goto clean;
-	}
-#endif
-
 	if (NULL != CONFIG_SOURCE_IP)
 	{
 		if (CURLE_OK != (err = curl_easy_setopt(easyhandle, opt = CURLOPT_INTERFACE, CONFIG_SOURCE_IP)))
@@ -239,10 +229,15 @@ static int	check_telnet(const char *host, unsigned short port, int timeout, int
 		ioctlsocket(s.socket, FIONBIO, &argp);	/* non-zero value sets the socket to non-blocking */
 #else
 		flags = fcntl(s.socket, F_GETFL);
-		if (0 == (flags & O_NONBLOCK))
-			fcntl(s.socket, F_SETFL, flags | O_NONBLOCK);
-#endif
+		if (-1 == flags)
+			zabbix_log(LOG_LEVEL_DEBUG, " error in getting the status flag: %s", zbx_strerror(errno));
 
+		if (0 == (flags & O_NONBLOCK) && (-1 == fcntl(s.socket, F_SETFL, flags | O_NONBLOCK)))
+		{
+			zabbix_log(LOG_LEVEL_DEBUG, " error in setting the status flag: %s",
+				zbx_strerror(errno));
+		}
+#endif
 		if (SUCCEED == telnet_test_login(s.socket))
 			*value_int = 1;
 		else
@@ -251,7 +246,9 @@ static int	check_telnet(const char *host, unsigned short port, int timeout, int
 		zbx_tcp_close(&s);
 	}
 	else
+	{
 		zabbix_log(LOG_LEVEL_DEBUG, "%s error: %s", __func__, zbx_socket_strerror());
+	}
 
 	return SYSINFO_RET_OK;
 }
