@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2025 Zabbix SIA
+** Copyright (C) 2001-2022 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -17,23 +17,25 @@
 ** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 **/
 
-#include "common.h"
-#include "module.h"
 #include "sysinfo.h"
+
 #include "log.h"
-#include "cfg.h"
 #include "alias.h"
 #include "threads.h"
+#if !defined(_WINDOWS) && !defined(__MINGW32__)
 #include "sighandler.h"
+#endif
 #include "zbxalgo.h"
 #include "zbxregexp.h"
 
+extern int	CONFIG_TIMEOUT;
+
 #ifdef WITH_AGENT_METRICS
 #	include "agent/agent.h"
 #endif
 
 #ifdef WITH_COMMON_METRICS
-#	include "common/common.h"
+	#include "common/zbxsysinfo_common.h"
 #endif
 
 #ifdef WITH_HTTP_METRICS
@@ -73,8 +75,6 @@ static int	compare_key_access_rules(const void *rule_a, const void *rule_b);
 static int	parse_key_access_rule(char *pattern, zbx_key_access_rule_t *rule);
 
 /******************************************************************************
- *                                                                            *
- * Function: parse_command_dyn                                                *
  *                                                                            *
  * Purpose: parses item key and splits it into command and parameters         *
  *                                                                            *
@@ -114,7 +114,6 @@ static int	parse_command_dyn(const char *command, char **cmd, char **param)
 	return ZBX_COMMAND_WITH_PARAMS;
 }
 
-
 static int	add_to_metrics(ZBX_METRIC **metrics, ZBX_METRIC *metric, char *error, size_t max_error_len)
 {
 	int		i = 0;
@@ -141,8 +140,6 @@ static int	add_to_metrics(ZBX_METRIC **metrics, ZBX_METRIC *metric, char *error,
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: add_metric                                                       *
  *                                                                            *
  * Purpose: registers a new item key into the system                          *
  *                                                                            *
@@ -153,8 +150,6 @@ int	add_metric(ZBX_METRIC *metric, char *error, size_t max_error_len)
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: add_metric_local                                                 *
  *                                                                            *
  * Purpose: registers a new item key as local into the system                 *
  *                                                                            *
@@ -198,6 +193,69 @@ int	add_user_parameter(const char *itemkey, char *command, char *error, size_t m
 
 	return ret;
 }
+
+void	remove_user_parameters(void)
+{
+	int	i, usr = -1;
+
+	if (NULL == commands)
+		return;
+
+	for (i = 0; NULL != commands[i].key; i++)
+	{
+		if (0 != (CF_USERPARAMETER & commands[i].flags))
+		{
+			zbx_free(commands[i].key);
+			zbx_free(commands[i].test_param);
+
+			if (0 > usr)
+				usr = i;
+		}
+	}
+
+	if (0 < usr)
+	{
+		commands = (ZBX_METRIC *)zbx_realloc(commands, ((unsigned int)usr + 1) * sizeof(ZBX_METRIC));
+		memset(&commands[usr], 0, sizeof(ZBX_METRIC));
+	}
+	else if (0 == usr)
+	{
+		zbx_free(commands);
+	}
+}
+
+void	get_metrics_copy(ZBX_METRIC **metrics)
+{
+	unsigned int	i;
+
+	if (NULL == commands)
+	{
+		*metrics = NULL;
+		return;
+	}
+
+	for (i = 0; NULL != commands[i].key; i++)
+		;
+
+	*metrics = (ZBX_METRIC *)zbx_malloc(*metrics, sizeof(ZBX_METRIC) * (i + 1));
+
+	for (i = 0; NULL != commands[i].key; i++)
+	{
+		(*metrics)[i].key = zbx_strdup(NULL, commands[i].key);
+		(*metrics)[i].flags = commands[i].flags;
+		(*metrics)[i].function = commands[i].function;
+		(*metrics)[i].test_param = (NULL == commands[i].test_param ?
+				NULL : zbx_strdup(NULL, commands[i].test_param));
+	}
+
+	memset(&(*metrics)[i], 0, sizeof(ZBX_METRIC));
+}
+
+void	set_metrics(ZBX_METRIC *metrics)
+{
+	free_metrics_ext(&commands);
+	commands = metrics;
+}
 #endif
 
 void	init_metrics(void)
@@ -285,40 +343,30 @@ void	init_metrics(void)
 #endif
 }
 
+void	free_metrics_ext(ZBX_METRIC **metrics)
+{
+	if (NULL != *metrics)
+	{
+		int	i;
+
+		for (i = 0; NULL != (*metrics)[i].key; i++)
+		{
+			zbx_free((*metrics)[i].key);
+			zbx_free((*metrics)[i].test_param);
+		}
+
+		zbx_free(*metrics);
+	}
+}
+
 void	free_metrics(void)
 {
-	if (NULL != commands)
-	{
-		int	i;
-
-		for (i = 0; NULL != commands[i].key; i++)
-		{
-			zbx_free(commands[i].key);
-			zbx_free(commands[i].test_param);
-		}
-
-		zbx_free(commands);
-	}
-
-	if (NULL != commands_local)
-	{
-		int	i;
-
-		for (i = 0; NULL != commands_local[i].key; i++)
-		{
-			zbx_free(commands_local[i].key);
-			zbx_free(commands_local[i].test_param);
-		}
-
-		zbx_free(commands_local);
-	}
-
+	free_metrics_ext(&commands);
+	free_metrics_ext(&commands_local);
 	free_key_access_rules();
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: init_key_access_rules                                            *
  *                                                                            *
  * Purpose: initializes key access rule list                                  *
  *                                                                            *
@@ -329,8 +377,6 @@ void	init_key_access_rules(void)
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: zbx_key_access_rule_free                                         *
  *                                                                            *
  * Purpose: frees key access rule and its resources                           *
  *                                                                            *
@@ -344,8 +390,6 @@ static void	zbx_key_access_rule_free(zbx_key_access_rule_t *rule)
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: zbx_key_access_rule_create                                       *
  *                                                                            *
  * Purpose: creates key access rule                                           *
  *                                                                            *
@@ -373,8 +417,6 @@ static zbx_key_access_rule_t	*zbx_key_access_rule_create(char *pattern, zbx_key_
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: finalize_key_access_rules_configuration                          *
  *                                                                            *
  * Purpose: validates key access rules configuration                          *
  *                                                                            *
@@ -385,7 +427,6 @@ void	finalize_key_access_rules_configuration(void)
 	zbx_key_access_rule_t	*rule, *sysrun_deny;
 	char			sysrun_pattern[] = "system.run[*]";
 
-
 	rules_num = key_access_rules.values_num;
 
 	/* prepare default system.run[*] deny rule to be added at the end */
@@ -471,8 +512,6 @@ void	finalize_key_access_rules_configuration(void)
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: parse_key_access_rule                                            *
  *                                                                            *
  * Purpose: parses key access rule expression from AllowKey and DenyKey       *
  *                                                                            *
@@ -549,8 +588,6 @@ static int	parse_key_access_rule(char *pattern, zbx_key_access_rule_t *rule)
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: compare_key_access_rules                                         *
  *                                                                            *
  * Purpose: Compares two zbx_key_access_rule_t values to perform search       *
  *          within vector. Rule type (allow/deny) is not checked here.        *
@@ -583,8 +620,6 @@ static int	compare_key_access_rules(const void *rule_a, const void *rule_b)
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: add_key_access_rule                                              *
  *                                                                            *
  * Purpose: adds new key access rule from AllowKey and DenyKey parameters     *
  *                                                                            *
@@ -626,8 +661,6 @@ int	add_key_access_rule(const char *parameter, char *pattern, zbx_key_access_rul
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: check_request_access_rules                                       *
  *                                                                            *
  * Purpose: checks agent metric request against configured access rules       *
  *                                                                            *
@@ -712,8 +745,6 @@ int	check_request_access_rules(AGENT_REQUEST *request)
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: check_key_access_rules                                           *
  *                                                                            *
  * Purpose: checks agent metric request against configured access rules       *
  *                                                                            *
@@ -741,8 +772,6 @@ int	check_key_access_rules(const char *metric)
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: free_key_access_rules                                            *
  *                                                                            *
  * Purpose: cleanup key access rule list                                      *
  *                                                                            *
@@ -794,8 +823,6 @@ void	free_result(AGENT_RESULT *result)
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: init_request                                                     *
  *                                                                            *
  * Purpose: initialize the request structure                                  *
  *                                                                            *
@@ -813,8 +840,6 @@ void	init_request(AGENT_REQUEST *request)
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: free_request_params                                              *
  *                                                                            *
  * Purpose: free memory used by the request parameters                        *
  *                                                                            *
@@ -834,8 +859,6 @@ static void	free_request_params(AGENT_REQUEST *request)
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: free_request                                                     *
  *                                                                            *
  * Purpose: free memory used by the request                                   *
  *                                                                            *
@@ -849,8 +872,6 @@ void	free_request(AGENT_REQUEST *request)
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: add_request_param                                                *
  *                                                                            *
  * Purpose: add a new parameter                                               *
  *                                                                            *
@@ -870,8 +891,6 @@ static void	add_request_param(AGENT_REQUEST *request, char *pvalue, zbx_request_
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: parse_item_key                                                   *
  *                                                                            *
  * Purpose: parse item command (key) and fill AGENT_REQUEST structure         *
  *                                                                            *
@@ -1080,8 +1099,6 @@ static int	replace_param(const char *cmd, const AGENT_REQUEST *request, char **o
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: process                                                          *
  *                                                                            *
  * Purpose: execute agent check                                               *
  *                                                                            *
@@ -1219,12 +1236,13 @@ int	set_result_type(AGENT_RESULT *result, int value_type, char *c)
 {
 	zbx_uint64_t	value_uint64;
 	int		ret = FAIL;
-	double		dbl_tmp;
 
 	assert(result);
 
 	switch (value_type)
 	{
+		double	dbl_tmp;
+
 		case ITEM_VALUE_TYPE_UINT64:
 			zbx_trim_integer(c);
 			del_zeros(c);
@@ -1368,7 +1386,7 @@ static char	**get_result_str_value(AGENT_RESULT *result)
 		/* NOTE: copy only line */
 		for (p = result->text; '\0' != *p && '\r' != *p && '\n' != *p; p++);
 		tmp = *p; /* remember result->text character */
-		*p = '\0'; /* replace to NUL */
+		*p = '\0'; /* temporary replace */
 		SET_STR_RESULT(result, zbx_strdup(NULL, result->text)); /* copy line */
 		*p = tmp; /* restore result->text character */
 	}
@@ -1445,8 +1463,6 @@ static zbx_log_t	*get_result_log_value(AGENT_RESULT *result)
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: get_result_value_by_type                                         *
  *                                                                            *
  * Purpose: return value of result in special type                            *
  *          if value missing, convert existing value to requested type        *
@@ -1454,8 +1470,6 @@ static zbx_log_t	*get_result_log_value(AGENT_RESULT *result)
  * Return value:                                                              *
  *         NULL - if value is missing or can't be converted                   *
  *                                                                            *
- * Author: Eugene Grigorjev                                                   *
- *                                                                            *
  * Comments:  better use definitions                                          *
  *                GET_UI64_RESULT                                             *
  *                GET_DBL_RESULT                                              *
@@ -1495,8 +1509,6 @@ void	*get_result_value_by_type(AGENT_RESULT *result, int require_type)
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: unquote_key_param                                                *
  *                                                                            *
  * Purpose: unquotes special symbols in item key parameter                    *
  *                                                                            *
@@ -1525,8 +1537,6 @@ void	unquote_key_param(char *param)
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: quote_key_param                                                  *
  *                                                                            *
  * Purpose: quotes special symbols in item key parameter                      *
  *                                                                            *
@@ -1605,8 +1615,6 @@ int	zbx_execute_threaded_metric(zbx_metric_func_t metric_func, AGENT_REQUEST *re
 }
 #else
 /******************************************************************************
- *                                                                            *
- * Function: serialize_agent_result                                           *
  *                                                                            *
  * Purpose: serialize agent result to transfer over pipe/socket               *
  *                                                                            *
@@ -1692,8 +1700,6 @@ static void	serialize_agent_result(char **data, size_t *data_alloc, size_t *data
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: deserialize_agent_result                                         *
  *                                                                            *
  * Purpose: deserialize agent result                                          *
  *                                                                            *
@@ -1742,40 +1748,6 @@ static int	deserialize_agent_result(char *data, AGENT_RESULT *result)
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: write_all                                                        *
- *                                                                            *
- * Purpose: call write in a loop, iterating until all the data is written.    *
- *                                                                            *
- * Parameters: fd      - [IN] descriptor                                      *
- *             buf     - [IN] buffer to write                                 *
- *             n       - [IN] bytes count to write                            *
- *                                                                            *
- * Return value: SUCCEED - n bytes successfully written                       *
- *               FAIL    - less than n bytes are written                      *
- *                                                                            *
- ******************************************************************************/
-static int	write_all(int fd, const char *buf, size_t n)
-{
-	ssize_t	ret;
-
-	while (0 < n)
-	{
-		if (-1 != (ret = write(fd, buf, n)))
-		{
-			buf += ret;
-			n -= ret;
-		}
-		else if (EINTR != errno)
-			return FAIL;
-	}
-
-	return SUCCEED;
-}
-
-/******************************************************************************
- *                                                                            *
- * Function: zbx_execute_threaded_metric                                      *
  *                                                                            *
  * Purpose: execute metric in a separate process/thread so it can be          *
  *          killed/terminated when timeout is detected                        *
@@ -1827,7 +1799,7 @@ int	zbx_execute_threaded_metric(zbx_metric_func_t metric_func, AGENT_REQUEST *re
 		ret = metric_func(request, result);
 		serialize_agent_result(&data, &data_alloc, &data_offset, ret, result);
 
-		ret = write_all(fds[1], data, data_offset);
+		ret = zbx_write_all(fds[1], data, data_offset);
 
 		zbx_free(data);
 		free_result(result);
@@ -1912,34 +1884,6 @@ out:
 	return ret;
 }
 #endif
-
-/******************************************************************************
- *                                                                            *
- * Function: zbx_mpoints_free                                                 *
- *                                                                            *
- * Purpose: frees previously allocated mount-point structure                  *
- *                                                                            *
- * Parameters: mpoint - [IN] pointer to structure from vector                 *
- *                                                                            *
- * Return value:                                                              *
- *                                                                            *
- ******************************************************************************/
-void	zbx_mpoints_free(zbx_mpoint_t *mpoint)
-{
-	zbx_free(mpoint);
-}
-
-int	zbx_fsname_compare(const void *fs1, const void *fs2)
-{
-	int			res;
-	const zbx_mpoint_t	*f1 = *((const zbx_mpoint_t * const *)fs1);
-	const zbx_fsname_t	*f2 = *((const zbx_fsname_t * const *)fs2);
-
-	if (0 != (res = strcmp(f1->fsname, f2->mpoint)))
-		return res;
-
-	return strcmp(f1->fstype, f2->type);
-}
 #else
 
 static ZBX_THREAD_LOCAL zbx_uint32_t	mutex_flag = ZBX_MUTEX_ALL_ALLOW;
@@ -1977,8 +1921,6 @@ ZBX_THREAD_ENTRY(agent_metric_thread, data)
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: zbx_execute_threaded_metric                                      *
  *                                                                            *
  * Purpose: execute metric in a separate process/thread so it can be          *
  *          killed/terminated when timeout is detected                        *
@@ -2087,6 +2029,20 @@ int	zbx_execute_threaded_metric(zbx_metric_func_t metric_func, AGENT_REQUEST *re
 }
 #endif
 
+/******************************************************************************
+ *                                                                            *
+ * Purpose: frees previously allocated mount-point structure                  *
+ *                                                                            *
+ * Parameters: mpoint - [IN] pointer to structure from vector                 *
+ *                                                                            *
+ * Return value:                                                              *
+ *                                                                            *
+ ******************************************************************************/
+void	zbx_mpoints_free(zbx_mpoint_t *mpoint)
+{
+	zbx_free(mpoint);
+}
+
 #ifndef _WINDOWS
 int	hostname_handle_params(AGENT_REQUEST *request, AGENT_RESULT *result, char *hostname)
 {
