@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2025 Zabbix SIA
+** Copyright (C) 2001-2022 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -17,9 +17,9 @@
 ** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 **/
 
-#include "common.h"
 #include "service.h"
 
+#include "common.h"
 #include "cfg.h"
 #include "log.h"
 #include "alias.h"
@@ -59,19 +59,6 @@ static VOID WINAPI	ServiceCtrlHandler(DWORD ctrlCode)
 	serviceStatus.dwCheckPoint		= 0;
 	serviceStatus.dwWaitHint		= 0;
 
-	switch (ctrlCode)
-	{
-		case SERVICE_CONTROL_STOP:
-			zabbix_log(LOG_LEVEL_INFORMATION, "Zabbix Agent received stop request.");
-			break;
-		case SERVICE_CONTROL_SHUTDOWN:
-			zabbix_log(LOG_LEVEL_INFORMATION, "Zabbix Agent received shutdown request.");
-			break;
-		default:
-			zabbix_log(LOG_LEVEL_DEBUG, "Zabbix Agent received request:%u.", ctrlCode);
-			break;
-	}
-
 	switch (ctrlCode)
 	{
 		case SERVICE_CONTROL_STOP:
@@ -413,4 +400,3 @@ void	set_parent_signal_handler(void)
 	signal(SIGINT, parent_signal_handler);
 	signal(SIGTERM, parent_signal_handler);
 }
-
