@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2025 Zabbix SIA
+** Copyright (C) 2001-2022 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -20,8 +20,13 @@
 #ifndef ZABBIX_PROCSTAT_H
 #define ZABBIX_PROCSTAT_H
 
+#include "config.h"
+
 #ifdef ZBX_PROCSTAT_COLLECTOR
 
+#include "zbxalgo.h"
+#include "zbxtypes.h"
+
 #define ZBX_PROCSTAT_CPU_USER			0x01
 #define ZBX_PROCSTAT_CPU_SYSTEM			0x02
 #define ZBX_PROCSTAT_CPU_TOTAL			(ZBX_PROCSTAT_CPU_USER | ZBX_PROCSTAT_CPU_SYSTEM)
