@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2025 Zabbix SIA
+** Copyright (C) 2001-2022 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -17,27 +17,24 @@
 ** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 **/
 
-#include "common.h"
+#include "alert_syncer.h"
+
 #include "daemon.h"
 #include "zbxself.h"
 #include "log.h"
-#include "db.h"
-#include "dbcache.h"
-#include "zbxipcservice.h"
-#include "zbxjson.h"
-#include "alert_manager.h"
-#include "alert_syncer.h"
 #include "alerter_protocol.h"
-
+#include "service_protocol.h"
 #include "../../libs/zbxalgo/vectorimpl.h"
+#include "dbcache.h"
 
 #define ZBX_POLL_INTERVAL	1
 
 #define ZBX_ALERT_BATCH_SIZE		1000
 #define ZBX_MEDIATYPE_CACHE_TTL		SEC_PER_DAY
 
-extern unsigned char	process_type, program_type;
-extern int		server_num, process_num;
+extern ZBX_THREAD_LOCAL unsigned char	process_type;
+extern unsigned char			program_type;
+extern ZBX_THREAD_LOCAL int		server_num, process_num;
 
 extern int	CONFIG_CONFSYNCER_FREQUENCY;
 
@@ -49,8 +46,6 @@ typedef struct
 zbx_am_db_t;
 
 /******************************************************************************
- *                                                                            *
- * Function: am_db_create_alert                                               *
  *                                                                            *
  * Purpose: creates new alert object                                          *
  *                                                                            *
@@ -85,11 +80,6 @@ static zbx_am_db_alert_t	*am_db_create_alert(zbx_uint64_t alertid, zbx_uint64_t
 	return alert;
 }
 
-/******************************************************************************
- *                                                                            *
- * Function: am_db_init                                                       *
- *                                                                            *
- ******************************************************************************/
 static int 	am_db_init(zbx_am_db_t *amdb, char **error)
 {
 	zbx_hashset_create(&amdb->mediatypes, 5, ZBX_DEFAULT_UINT64_HASH_FUNC, ZBX_DEFAULT_UINT64_COMPARE_FUNC);
@@ -100,11 +90,6 @@ static int 	am_db_init(zbx_am_db_t *amdb, char **error)
 	return SUCCEED;
 }
 
-/******************************************************************************
- *                                                                            *
- * Function: am_db_clear                                                      *
- *                                                                            *
- ******************************************************************************/
 static void	am_db_clear(zbx_am_db_t *amdb)
 {
 	zbx_hashset_iter_t	iter;
@@ -118,8 +103,6 @@ static void	am_db_clear(zbx_am_db_t *amdb)
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: am_db_get_alerts                                                 *
  *                                                                            *
  * Purpose: reads the new alerts from database                                *
  *                                                                            *
@@ -250,8 +233,6 @@ static int	am_db_get_alerts(zbx_vector_ptr_t *alerts)
 	}
 
 /******************************************************************************
- *                                                                            *
- * Function: am_db_update_mediatype                                           *
  *                                                                            *
  * Purpose: updates media type object, creating one if necessary              *
  *                                                                            *
@@ -311,8 +292,6 @@ static zbx_am_db_mediatype_t	*am_db_update_mediatype(zbx_am_db_t *amdb, time_t n
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: am_db_update_mediatypes                                          *
  *                                                                            *
  * Purpose: updates alert manager media types                                 *
  *                                                                            *
@@ -384,8 +363,6 @@ static void	am_db_update_mediatypes(zbx_am_db_t *amdb, const zbx_uint64_t *media
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: am_db_queue_alerts                                               *
  *                                                                            *
  * Purpose: reads alerts/mediatypes from database and queues them in alert    *
  *          manager                                                           *
@@ -464,9 +441,6 @@ static int	am_db_compare_tags(const void *d1, const void *d2)
 	return strcmp(tag1->value, tag2->value);
 }
 
-ZBX_PTR_VECTOR_DECL(tags, zbx_tag_t*)
-ZBX_PTR_VECTOR_IMPL(tags, zbx_tag_t*)
-
 static void	tag_free(zbx_tag_t *tag)
 {
 	zbx_free(tag->tag);
@@ -503,8 +477,6 @@ static void	event_tags_free(zbx_event_tags_t *event_tags)
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: am_db_update_event_tags                                          *
  *                                                                            *
  * Purpose: adds event tags to sql query                                      *
  *                                                                            *
@@ -603,8 +575,6 @@ out:
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: am_db_validate_tags_for_update                                   *
  *                                                                            *
  * Purpose: removes duplicate event tags and checks if problem tags need to   *
  *          be updated                                                        *
@@ -669,9 +639,28 @@ static void	am_db_validate_tags_for_update(zbx_vector_events_tags_t *update_even
 	zabbix_log(LOG_LEVEL_DEBUG, "End of %s()", __func__);
 }
 
+static void	am_service_add_event_tags(zbx_vector_events_tags_t *events_tags)
+{
+	unsigned char	*data = NULL;
+	size_t		data_alloc = 0, data_offset = 0;
+	int		i;
+
+	for (i = 0; i < events_tags->values_num; i++)
+	{
+		zbx_event_tags_t	*event_tag = events_tags->values[i];
+
+		zbx_service_serialize_problem_tags(&data, &data_alloc, &data_offset, event_tag->eventid,
+				&event_tag->tags);
+	}
+
+	if (NULL == data)
+		return;
+
+	zbx_service_flush(ZBX_IPC_SERVICE_SERVICE_PROBLEMS_TAGS, data, data_offset);
+	zbx_free(data);
+}
+
 /******************************************************************************
- *                                                                            *
- * Function: am_db_flush_results                                              *
  *                                                                            *
  * Purpose: retrieves alert updates from alert manager and flushes them into  *
  *          database                                                          *
@@ -695,18 +684,22 @@ static int	am_db_flush_results(zbx_am_db_t *amdb)
 		return 0;
 	}
 
+	zbx_vector_events_tags_create(&update_events_tags);
+
 	zbx_alerter_deserialize_results(message.data, &results, &results_num);
 
 	if (0 != results_num)
 	{
-		int 		i;
+		int 		i, ret;
 		char		*sql;
 		size_t		sql_alloc = results_num * 128, sql_offset;
 		zbx_db_insert_t	db_event, db_problem;
 
 		sql = (char *)zbx_malloc(NULL, sql_alloc);
 
-		do {
+		do
+		{
+			zbx_vector_events_tags_clear_ext(&update_events_tags, event_tags_free);
 			sql_offset = 0;
 
 			DBbegin();
@@ -715,8 +708,6 @@ static int	am_db_flush_results(zbx_am_db_t *amdb)
 			zbx_db_insert_prepare(&db_problem, "problem_tag", "problemtagid", "eventid", "tag", "value",
 					NULL);
 
-			zbx_vector_events_tags_create(&update_events_tags);
-
 			for (i = 0; i < results_num; i++)
 			{
 				zbx_am_db_mediatype_t	*mediatype;
@@ -764,11 +755,11 @@ static int	am_db_flush_results(zbx_am_db_t *amdb)
 			zbx_db_insert_autoincrement(&db_problem, "problemtagid");
 			zbx_db_insert_execute(&db_problem);
 			zbx_db_insert_clean(&db_problem);
-
-			zbx_vector_events_tags_clear_ext(&update_events_tags, event_tags_free);
-			zbx_vector_events_tags_destroy(&update_events_tags);
 		}
-		while (ZBX_DB_DOWN == DBcommit());
+		while (ZBX_DB_DOWN == (ret = DBcommit()));
+
+		if (ZBX_DB_OK == ret)
+			am_service_add_event_tags(&update_events_tags);
 
 		for (i = 0; i < results_num; i++)
 		{
@@ -782,6 +773,8 @@ static int	am_db_flush_results(zbx_am_db_t *amdb)
 		zbx_free(sql);
 	}
 
+	zbx_vector_events_tags_clear_ext(&update_events_tags, event_tags_free);
+	zbx_vector_events_tags_destroy(&update_events_tags);
 	zbx_free(results);
 	zbx_ipc_message_clean(&message);
 
@@ -790,8 +783,6 @@ static int	am_db_flush_results(zbx_am_db_t *amdb)
 	return results_num;
 }
 /******************************************************************************
- *                                                                            *
- * Function: am_db_remove_expired_mediatypes                                  *
  *                                                                            *
  * Purpose: removes cached media types used more than a day ago               *
  *                                                                            *
@@ -838,8 +829,6 @@ static void	am_db_remove_expired_mediatypes(zbx_am_db_t *amdb)
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: am_db_update_watchdog                                            *
  *                                                                            *
  * Purpose: updates watchdog recipients                                       *
  *                                                                            *
@@ -888,7 +877,6 @@ static void	am_db_update_watchdog(zbx_am_db_t *amdb)
 	}
 	DBfree_result(result);
 
-
 	/* update media types used for watchdog alerts */
 
 	if (0 != mediatypeids.values_num)
