@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2025 Zabbix SIA
+** Copyright (C) 2001-2022 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -17,26 +17,20 @@
 ** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 **/
 
-#include "common.h"
-#include "db.h"
-#include "dbcache.h"
+#include "housekeeper.h"
 #include "log.h"
 #include "daemon.h"
 #include "zbxself.h"
-#include "zbxalgo.h"
 #include "zbxserver.h"
+#include "zbxrtc.h"
 
-#include "zbxhistory.h"
 #include "history_compress.h"
-#include "housekeeper.h"
 #include "../../libs/zbxdbcache/valuecache.h"
 
-extern unsigned char	process_type, program_type;
-extern int		server_num, process_num;
 
-#if defined(HAVE_POSTGRESQL)
-extern int	ZBX_TSDB_VERSION;
-#endif
+extern ZBX_THREAD_LOCAL unsigned char	process_type;
+extern unsigned char			program_type;
+extern ZBX_THREAD_LOCAL int		server_num, process_num;
 
 static int	hk_period;
 
@@ -90,7 +84,7 @@ typedef struct
 }
 zbx_hk_cleanup_table_t;
 
-static unsigned char poption_mode_regular 	= ZBX_HK_MODE_REGULAR;
+static unsigned char poption_mode_regular	= ZBX_HK_MODE_REGULAR;
 static unsigned char poption_global_disabled	= ZBX_HK_OPTION_DISABLED;
 
 /* Housekeeper table mapping to housekeeping configuration values.    */
@@ -189,23 +183,7 @@ static zbx_hk_history_rule_t	hk_history_rules[] = {
 	{NULL}
 };
 
-static void	zbx_housekeeper_sigusr_handler(int flags)
-{
-	if (ZBX_RTC_HOUSEKEEPER_EXECUTE == ZBX_RTC_GET_MSG(flags))
-	{
-		if (0 < zbx_sleep_get_remainder())
-		{
-			zabbix_log(LOG_LEVEL_WARNING, "forced execution of the housekeeper");
-			zbx_wakeup();
-		}
-		else
-			zabbix_log(LOG_LEVEL_WARNING, "housekeeping procedure is already in progress");
-	}
-}
-
 /******************************************************************************
- *                                                                            *
- * Function: hk_item_update_cache_compare                                     *
  *                                                                            *
  * Purpose: compare two delete queue items by their itemid                    *
  *                                                                            *
@@ -216,8 +194,6 @@ static void	zbx_housekeeper_sigusr_handler(int flags)
  *               >0 - the first item is greater than the second               *
  *               =0 - the items are the same                                  *
  *                                                                            *
- * Author: Andris Zeila                                                       *
- *                                                                            *
  * Comments: this function is used to sort delete queue by itemids            *
  *                                                                            *
  ******************************************************************************/
@@ -232,8 +208,6 @@ static int	hk_item_update_cache_compare(const void *d1, const void *d2)
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: hk_history_delete_queue_append                                   *
  *                                                                            *
  * Purpose: add item to the delete queue if necessary                         *
  *                                                                            *
@@ -244,8 +218,6 @@ static int	hk_item_update_cache_compare(const void *d1, const void *d2)
  *             history     - [IN] a number of seconds the history data for    *
  *                           item_record must be kept.                        *
  *                                                                            *
- * Author: Andris Zeila                                                       *
- *                                                                            *
  * Comments: If item is added to delete queue, its oldest record timestamp    *
  *           (min_clock) is updated to the calculated 'cutoff' value.         *
  *                                                                            *
@@ -275,15 +247,11 @@ static void	hk_history_delete_queue_append(zbx_hk_history_rule_t *rule, int now,
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: hk_history_prepare                                               *
  *                                                                            *
  * Purpose: prepares history housekeeping rule                                *
  *                                                                            *
  * Parameters: rule        - [IN/OUT] the history housekeeping rule           *
  *                                                                            *
- * Author: Andris Zeila                                                       *
- *                                                                            *
  * Comments: This function is called to initialize history rule data either   *
  *           at start or when housekeeping is enabled for this rule.          *
  *           It caches item history data and also prepares delete queue to be *
@@ -321,15 +289,11 @@ static void	hk_history_prepare(zbx_hk_history_rule_t *rule)
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: hk_history_release                                               *
  *                                                                            *
  * Purpose: releases history housekeeping rule                                *
  *                                                                            *
  * Parameters: rule  - [IN/OUT] the history housekeeping rule                 *
  *                                                                            *
- * Author: Andris Zeila                                                       *
- *                                                                            *
  * Comments: This function is called to release resources allocated by        *
  *           history housekeeping rule after housekeeping was disabled        *
  *           for the table referred by this rule.                             *
@@ -345,8 +309,6 @@ static void	hk_history_release(zbx_hk_history_rule_t *rule)
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: hk_history_item_update                                           *
  *                                                                            *
  * Purpose: updates history housekeeping rule with item history setting and   *
  *          adds item to the delete queue if necessary                        *
@@ -357,8 +319,6 @@ static void	hk_history_release(zbx_hk_history_rule_t *rule)
  *             history - [IN] the number of seconds the item data             *
  *                       should be kept in history                            *
  *                                                                            *
- * Author: Andris Zeila                                                       *
- *                                                                            *
  ******************************************************************************/
 static void	hk_history_item_update(zbx_hk_history_rule_t *rules, zbx_hk_history_rule_t *rule_add, int count,
 		int now, zbx_uint64_t itemid, int history)
@@ -392,8 +352,6 @@ static void	hk_history_item_update(zbx_hk_history_rule_t *rules, zbx_hk_history_
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: hk_history_update                                                *
  *                                                                            *
  * Purpose: updates history housekeeping rule with the latest item history    *
  *          settings and prepares delete queue                                *
@@ -431,8 +389,8 @@ static void	hk_history_update(zbx_hk_history_rule_t *rules, int now)
 				ZBX_HK_MODE_REGULAR == *(rule = rules + value_type)->poption_mode)
 		{
 			tmp = zbx_strdup(tmp, row[2]);
-			substitute_simple_macros(NULL, NULL, NULL, NULL, &hostid, NULL, NULL, NULL, NULL, &tmp,
-					MACRO_TYPE_COMMON, NULL, 0);
+			substitute_simple_macros(NULL, NULL, NULL, NULL, &hostid, NULL, NULL, NULL, NULL, NULL, NULL,
+					NULL, &tmp, MACRO_TYPE_COMMON, NULL, 0);
 
 			if (SUCCEED != is_time_suffix(tmp, &history, ZBX_LENGTH_UNLIMITED))
 			{
@@ -462,8 +420,8 @@ static void	hk_history_update(zbx_hk_history_rule_t *rules, int now)
 				continue;
 
 			tmp = zbx_strdup(tmp, row[3]);
-			substitute_simple_macros(NULL, NULL, NULL, NULL, &hostid, NULL, NULL, NULL, NULL, &tmp,
-					MACRO_TYPE_COMMON, NULL, 0);
+			substitute_simple_macros(NULL, NULL, NULL, NULL, &hostid, NULL, NULL, NULL, NULL, NULL, NULL,
+					NULL, &tmp, MACRO_TYPE_COMMON, NULL, 0);
 
 			if (SUCCEED != is_time_suffix(tmp, &trends, ZBX_LENGTH_UNLIMITED))
 			{
@@ -490,8 +448,6 @@ static void	hk_history_update(zbx_hk_history_rule_t *rules, int now)
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: hk_history_delete_queue_prepare_all                              *
  *                                                                            *
  * Purpose: prepares history housekeeping delete queues for all defined       *
  *          history rules.                                                    *
@@ -499,8 +455,6 @@ static void	hk_history_update(zbx_hk_history_rule_t *rules, int now)
  * Parameters: rules  - [IN/OUT] the history housekeeping rules               *
  *             now    - [IN] the current timestamp                            *
  *                                                                            *
- * Author: Andris Zeila                                                       *
- *                                                                            *
  * Comments: This function also handles history rule initializing/releasing   *
  *           when the rule just became enabled/disabled.                      *
  *                                                                            *
@@ -536,16 +490,12 @@ static void	hk_history_delete_queue_prepare_all(zbx_hk_history_rule_t *rules, in
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: hk_history_delete_queue_clear                                    *
  *                                                                            *
  * Purpose: clears the history housekeeping delete queue                      *
  *                                                                            *
  * Parameters: rule   - [IN/OUT] the history housekeeping rule                *
  *             now    - [IN] the current timestamp                            *
  *                                                                            *
- * Author: Andris Zeila                                                       *
- *                                                                            *
  ******************************************************************************/
 static void	hk_history_delete_queue_clear(zbx_hk_history_rule_t *rule)
 {
@@ -553,21 +503,17 @@ static void	hk_history_delete_queue_clear(zbx_hk_history_rule_t *rule)
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: hk_drop_partition_for_rule                                       *
  *                                                                            *
  * Purpose: drop appropriate partitions from the history and trends tables    *
  *                                                                            *
  * Parameters: rules - [IN/OUT] history housekeeping rules                    *
  *             now   - [IN] the current timestamp                             *
  *                                                                            *
- * Return value: the number of tables processed                               *
- *                                                                            *
  ******************************************************************************/
 static void	hk_drop_partition_for_rule(zbx_hk_history_rule_t *rule, int now)
 {
 #if defined(HAVE_POSTGRESQL)
-	int		keep_from, history_seconds;
+	int		history_seconds;
 	DB_RESULT	result;
 
 	zabbix_log(LOG_LEVEL_DEBUG, "In %s() now:%d", __func__, now);
@@ -576,31 +522,38 @@ static void	hk_drop_partition_for_rule(zbx_hk_history_rule_t *rule, int now)
 
 	if (0 == history_seconds)
 	{
-		keep_from = INT_MAX;
+		zabbix_log(LOG_LEVEL_TRACE, "%s: table=%s delete all", __func__, rule->table);
+
+		result = DBselect(1 == ZBX_DB_TSDB_V1 ?
+				"select drop_chunks(table_name=>'%s',newer_than=>0)" :
+				"select drop_chunks(relation=>'%s',newer_than=>0)",
+				rule->table);
 	}
 	else
 	{
+		int	keep_from;
+
 		if (ZBX_HK_HISTORY_MIN > history_seconds || ZBX_HK_PERIOD_MAX < history_seconds)
 		{
 			zabbix_log(LOG_LEVEL_WARNING, "invalid history storage period for table '%s'", rule->table);
-			return;
+			goto out;
 		}
 
 		keep_from = now - history_seconds;
-	}
 
-	zabbix_log(LOG_LEVEL_TRACE, "%s: table=%s keep_from=%d", __func__, rule->table, keep_from);
+		zabbix_log(LOG_LEVEL_TRACE, "%s: table=%s keep_from=%d", __func__, rule->table, keep_from);
 
-	result = DBselect(1 == ZBX_DB_TSDB_V1 ?
+		result = DBselect(1 == ZBX_DB_TSDB_V1 ?
 				"select drop_chunks(table_name=>'%s',older_than=>%d)" :
 				"select drop_chunks(relation=>'%s',older_than=>%d)",
 				rule->table, keep_from);
+	}
 
 	if (NULL == result)
 		zabbix_log(LOG_LEVEL_ERR, "cannot drop chunks for %s", rule->table);
 	else
 		DBfree_result(result);
-
+out:
 	zabbix_log(LOG_LEVEL_DEBUG, "End of %s()", __func__);
 
 	return;
@@ -610,68 +563,23 @@ static void	hk_drop_partition_for_rule(zbx_hk_history_rule_t *rule, int now)
 #endif
 }
 
-#if defined(HAVE_POSTGRESQL)
-static int hk_history_has_compressed_chunks(void)
-{
-	const char	*table_list;
-
-	table_list = (1 == ZBX_DB_TSDB_V1 ? ZBX_TSDB1_HISTORY_TABLES : ZBX_TSDB2_HISTORY_TABLES);
-
-	return zbx_tsdb_table_has_compressed_chunks(table_list);
-}
-
-static int hk_trends_has_compressed_chunks(void)
-{
-	const char	*table_list;
-
-	table_list = (1 == ZBX_DB_TSDB_V1 ? ZBX_TSDB1_TRENDS_TABLES : ZBX_TSDB2_TRENDS_TABLES);
-
-	return zbx_tsdb_table_has_compressed_chunks(table_list);
-}
-
-static void	hk_tsdb_check_config()
-{
-	if (cfg.hk.history_global == ZBX_HK_OPTION_DISABLED && cfg.hk.history_mode == ZBX_HK_OPTION_ENABLED &&
-		SUCCEED == hk_history_has_compressed_chunks())
-	{
-		zabbix_log(LOG_LEVEL_WARNING, "Incorrect configuration. Override item history period is disabled, but "
-				"historical data is compressed. Housekeeper may skip deleting this data.");
-	}
-
-	if (cfg.hk.trends_global == ZBX_HK_OPTION_DISABLED && cfg.hk.trends_mode == ZBX_HK_OPTION_ENABLED &&
-			SUCCEED == hk_trends_has_compressed_chunks())
-	{
-		zabbix_log(LOG_LEVEL_WARNING, "Incorrect configuration. Override item trends period is disabled, but "
-				"trends data is compressed. Housekeeper may skip deleting this data.");
-	}
-}
-#endif
-
 /******************************************************************************
- *                                                                            *
- * Function: housekeeping_history_and_trends                                  *
  *                                                                            *
  * Purpose: performs housekeeping for history and trends tables               *
  *                                                                            *
  * Parameters: now    - [IN] the current timestamp                            *
  *                                                                            *
- * Author: Andris Zeila                                                       *
- *                                                                            *
  ******************************************************************************/
 static int	housekeeping_history_and_trends(int now)
 {
 	int			deleted = 0, i, rc;
 	zbx_hk_history_rule_t	*rule;
-#if defined(HAVE_POSTGRESQL)
-	int			ignore_history = 0, ignore_trends = 0;
-#endif
 
 	zabbix_log(LOG_LEVEL_DEBUG, "In %s() now:%d", __func__, now);
 
 	/* prepare delete queues for all history housekeeping rules */
 	hk_history_delete_queue_prepare_all(hk_history_rules, now);
 
-
 	/* Loop through the history rules. Each rule is a history table (such as history_log, trends_uint, etc) */
 	/* we need to clear records from */
 	for (rule = hk_history_rules; NULL != rule->table; rule++)
@@ -689,47 +597,6 @@ static int	housekeeping_history_and_trends(int now)
 			continue;
 		}
 
-#if defined(HAVE_POSTGRESQL)
-		if (ZBX_TSDB_VERSION > 0)
-		{
-			if (0 == strcmp(rule->history, "history"))
-			{
-				if (1 == ignore_history)
-				{
-					hk_history_release(rule);
-					continue;
-				}
-
-				if (SUCCEED == hk_history_has_compressed_chunks())
-				{
-					zabbix_log(LOG_LEVEL_WARNING, "Unable to perform housekeeping for history "
-							"tables due to having compressed chunks and disabled item history period override.");
-
-					ignore_history = 1;
-					hk_history_release(rule);
-					continue;
-				}
-			}
-			else if (0 == strcmp(rule->history, "trends"))
-			{
-				if (1 == ignore_trends)
-				{
-					hk_history_release(rule);
-					continue;
-				}
-
-				if (SUCCEED == hk_trends_has_compressed_chunks())
-				{
-					zabbix_log(LOG_LEVEL_WARNING, "Unable to perform housekeeping for trends "
-							"tables due to having compressed chunks and disabled item trends period override.");
-
-					ignore_trends = 1;
-					hk_history_release(rule);
-					continue;
-				}
-			}
-		}
-#endif
 		/* process delete queue for the housekeeping rule */
 
 		zbx_vector_ptr_sort(&rule->delete_queue, hk_item_update_cache_compare);
@@ -754,8 +621,6 @@ static int	housekeeping_history_and_trends(int now)
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: housekeeping_process_rule                                        *
  *                                                                            *
  * Purpose: removes old records from a table according to the specified rule  *
  *                                                                            *
@@ -765,18 +630,22 @@ static int	housekeeping_history_and_trends(int now)
  *                                                                            *
  * Return value: the number of deleted records                                *
  *                                                                            *
- * Author: Andris Zeila                                                       *
- *                                                                            *
  ******************************************************************************/
 static int	housekeeping_process_rule(int now, zbx_hk_rule_t *rule)
 {
 	DB_RESULT	result;
 	DB_ROW		row;
-	int		keep_from, deleted = 0;
+	int		keep_from, id_field_str_type, deleted = 0;
 
 	zabbix_log(LOG_LEVEL_DEBUG, "In %s() table:'%s' field_name:'%s' filter:'%s' min_clock:%d now:%d",
 			__func__, rule->table, rule->field_name, rule->filter, rule->min_clock, now);
 
+	/* NOTE: Do not forget to add here tables whose id column is string-type.                    */
+	/* Now only audit field has string id, if in the future this list of exceptions is increased */
+	/* DBget_table() and DBget_field() functions with cache could be used to determine if string */
+	/* or int version is required.                                                               */
+	id_field_str_type = (0 == strcmp("auditid", rule->field_name)) ? 1 : 0;
+
 	/* initialize min_clock with the oldest record timestamp from database */
 	if (0 == rule->min_clock)
 	{
@@ -798,10 +667,14 @@ static int	housekeeping_process_rule(int now, zbx_hk_rule_t *rule)
 		char			buffer[MAX_STRING_LEN];
 		char			*sql = NULL;
 		size_t			sql_alloc = 0, sql_offset;
-		zbx_vector_uint64_t	ids;
+		zbx_vector_uint64_t	ids_uint64;
+		zbx_vector_str_t	ids_str;
 		int			ret;
 
-		zbx_vector_uint64_create(&ids);
+		if (0 == id_field_str_type)
+			zbx_vector_uint64_create(&ids_uint64);
+		else
+			zbx_vector_str_create(&ids_str);
 
 		rule->min_clock = MIN(keep_from, rule->min_clock + HK_MAX_DELETE_PERIODS * hk_period);
 
@@ -824,30 +697,63 @@ static int	housekeeping_process_rule(int now, zbx_hk_rule_t *rule)
 
 			while (NULL != (row = DBfetch(result)))
 			{
-				zbx_uint64_t	id;
+				if (0 == id_field_str_type)
+				{
+					zbx_uint64_t	id;
 
-				ZBX_STR2UINT64(id, row[0]);
-				zbx_vector_uint64_append(&ids, id);
+					ZBX_STR2UINT64(id, row[0]);
+					zbx_vector_uint64_append(&ids_uint64, id);
+				}
+				else
+					zbx_vector_str_append(&ids_str, zbx_strdup(NULL, row[0]));
 			}
+
 			DBfree_result(result);
 
-			if (0 == ids.values_num)
-				break;
+			if (0 == id_field_str_type)
+			{
+				if (0 == ids_uint64.values_num)
+					break;
+			}
+			else
+			{
+				if (0 == ids_str.values_num)
+					break;
+			}
 
 			sql_offset = 0;
 			zbx_snprintf_alloc(&sql, &sql_alloc, &sql_offset, "delete from %s where", rule->table);
-			DBadd_condition_alloc(&sql, &sql_alloc, &sql_offset, rule->field_name, ids.values,
-					ids.values_num);
 
-			if (ZBX_DB_OK > (ret = DBexecute("%s", sql)))
+			if (0 == id_field_str_type)
+			{
+				DBadd_condition_alloc(&sql, &sql_alloc, &sql_offset, rule->field_name,
+						ids_uint64.values, ids_uint64.values_num);
+			}
+			else
+			{
+				DBadd_str_condition_alloc(&sql, &sql_alloc, &sql_offset, rule->field_name,
+						(const char**)ids_str.values, ids_str.values_num);
+			}
+
+			ret = DBexecute("%s", sql);
+
+			if (0 == id_field_str_type)
+				zbx_vector_uint64_clear(&ids_uint64);
+			else
+				zbx_vector_str_clear_ext(&ids_str, zbx_str_free);
+
+			if (ZBX_DB_OK > ret)
 				break;
 
 			deleted += ret;
-			zbx_vector_uint64_clear(&ids);
 		}
 
 		zbx_free(sql);
-		zbx_vector_uint64_destroy(&ids);
+
+		if (0 == id_field_str_type)
+			zbx_vector_uint64_destroy(&ids_uint64);
+		else
+			zbx_vector_str_destroy(&ids_str);
 	}
 
 	zabbix_log(LOG_LEVEL_DEBUG, "End of %s():%d", __func__, deleted);
@@ -856,8 +762,6 @@ static int	housekeeping_process_rule(int now, zbx_hk_rule_t *rule)
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: DBdelete_from_table                                              *
  *                                                                            *
  * Purpose: delete limited count of rows from table                           *
  *                                                                            *
@@ -914,8 +818,6 @@ static int	DBdelete_from_table(const char *tablename, const char *filter, int li
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: hk_problem_cleanup                                               *
  *                                                                            *
  * Purpose: perform problem table cleanup                                     *
  *                                                                            *
@@ -946,8 +848,6 @@ static int	hk_problem_cleanup(const char *table, int source, int object, zbx_uin
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: hk_table_cleanup                                                 *
  *                                                                            *
  * Purpose: perform generic table cleanup                                     *
  *                                                                            *
@@ -976,15 +876,11 @@ static int	hk_table_cleanup(const char *table, const char *field, zbx_uint64_t i
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: housekeeping_cleanup                                             *
  *                                                                            *
  * Purpose: remove deleted items/triggers data                                *
  *                                                                            *
  * Return value: number of rows deleted                                       *
  *                                                                            *
- * Author: Alexei Vladishev, Dmitry Borovikov                                 *
- *                                                                            *
  * Comments: sqlite3 does not use CONFIG_MAX_HOUSEKEEPER_DELETE, deletes all  *
  *                                                                            *
  ******************************************************************************/
@@ -1042,8 +938,6 @@ static int	housekeeping_cleanup(void)
 
 			if (0 == strcmp(row[2], "triggerid"))
 			{
-				deleted += hk_problem_cleanup(table_name, EVENT_SOURCE_TRIGGERS, EVENT_OBJECT_TRIGGER,
-						objectid, &more);
 				deleted += hk_problem_cleanup(table_name, EVENT_SOURCE_INTERNAL, EVENT_OBJECT_TRIGGER,
 						objectid, &more);
 			}
@@ -1057,6 +951,11 @@ static int	housekeeping_cleanup(void)
 				deleted += hk_problem_cleanup(table_name, EVENT_SOURCE_INTERNAL, EVENT_OBJECT_LLDRULE,
 						objectid, &more);
 			}
+			else if (0 == strcmp(row[2], "serviceid"))
+			{
+				deleted += hk_problem_cleanup(table_name, EVENT_SOURCE_SERVICE, EVENT_OBJECT_SERVICE,
+						objectid, &more);
+			}
 		}
 		else
 			deleted += hk_table_cleanup(row[1], row[2], objectid, &more);
@@ -1149,6 +1048,9 @@ static int	housekeeping_events(int now)
 			" and events.object=" ZBX_STR(EVENT_OBJECT_DSERVICE), 0, &cfg.hk.events_discovery},
 		{"events", "eventid", "events.source=" ZBX_STR(EVENT_SOURCE_AUTOREGISTRATION)
 			" and events.object=" ZBX_STR(EVENT_OBJECT_ZABBIX_ACTIVE), 0, &cfg.hk.events_autoreg},
+		{"events", "eventid", "events.source=" ZBX_STR(EVENT_SOURCE_SERVICE)
+			" and events.object=" ZBX_STR(EVENT_OBJECT_SERVICE)
+			ZBX_HK_EVENT_RULE, 0, &cfg.hk.events_service},
 		{NULL}
 	};
 
@@ -1197,7 +1099,6 @@ static int	housekeeping_proxy_dhistory(int now)
 	return deleted;
 }
 
-
 static int	get_housekeeping_period(double time_slept)
 {
 	if (SEC_PER_HOUR > time_slept)
@@ -1210,10 +1111,11 @@ static int	get_housekeeping_period(double time_slept)
 
 ZBX_THREAD_ENTRY(housekeeper_thread, args)
 {
-	int	now, d_history_and_trends, d_cleanup, d_events, d_problems, d_sessions, d_services, d_audit, sleeptime,
-		records;
-	double	sec, time_slept, time_now;
-	char	sleeptext[25];
+	int			now, d_history_and_trends, d_cleanup, d_events, d_problems, d_sessions, d_services,
+				d_audit, sleeptime, records;
+	double			sec, time_slept, time_now;
+	char			sleeptext[25];
+	zbx_ipc_async_socket_t	rtc;
 
 	process_type = ((zbx_thread_args_t *)args)->process_type;
 	server_num = ((zbx_thread_args_t *)args)->server_num;
@@ -1226,6 +1128,7 @@ ZBX_THREAD_ENTRY(housekeeper_thread, args)
 
 	if (0 == CONFIG_HOUSEKEEPING_FREQUENCY)
 	{
+		sleeptime = ZBX_IPC_WAIT_FOREVER;
 		zbx_setproctitle("%s [waiting for user command]", get_process_type_string(process_type));
 		zbx_snprintf(sleeptext, sizeof(sleeptext), "waiting for user command");
 	}
@@ -1239,30 +1142,47 @@ ZBX_THREAD_ENTRY(housekeeper_thread, args)
 
 	hk_history_compression_init();
 
-	zbx_set_sigusr_handler(zbx_housekeeper_sigusr_handler);
-
-#if defined(HAVE_POSTGRESQL)
-	if (ZBX_TSDB_VERSION > 0)
-	{
-		zbx_config_get(&cfg, ZBX_CONFIG_FLAGS_HOUSEKEEPER);
-		DBconnect(ZBX_DB_CONNECT_NORMAL);
-		hk_tsdb_check_config();
-		DBclose();
-	}
-#endif
+	zbx_rtc_subscribe(&rtc, process_type, process_num);
 
 	while (ZBX_IS_RUNNING())
 	{
+		zbx_uint32_t	rtc_cmd;
+		unsigned char	*rtc_data;
+		int		hk_execute = 0;
+
 		sec = zbx_time();
 
-		if (0 == CONFIG_HOUSEKEEPING_FREQUENCY)
-			zbx_sleep_forever();
-		else
-			zbx_sleep_loop(sleeptime);
+		while (SUCCEED == zbx_rtc_wait(&rtc, &rtc_cmd, &rtc_data, sleeptime) && 0 != rtc_cmd)
+		{
+			switch (rtc_cmd)
+			{
+				case ZBX_RTC_HOUSEKEEPER_EXECUTE:
+					if (0 == hk_execute)
+					{
+						zabbix_log(LOG_LEVEL_WARNING, "forced execution of the housekeeper");
+						hk_execute = 1;
+					}
+					else
+						zabbix_log(LOG_LEVEL_WARNING, "housekeeping procedure is already in"
+								" progress");
+					break;
+				case ZBX_RTC_SHUTDOWN:
+					goto out;
+				default:
+					continue;
+			}
+
+			sleeptime = 0;
+		}
 
 		if (!ZBX_IS_RUNNING())
 			break;
 
+		if (0 == CONFIG_HOUSEKEEPING_FREQUENCY)
+			sleeptime = ZBX_IPC_WAIT_FOREVER;
+		else
+			sleeptime = CONFIG_HOUSEKEEPING_FREQUENCY * SEC_PER_HOUR;
+
 		time_now = zbx_time();
 		time_slept = time_now - sec;
 		zbx_update_env(time_now);
@@ -1278,7 +1198,7 @@ ZBX_THREAD_ENTRY(housekeeper_thread, args)
 
 		zbx_config_get(&cfg, ZBX_CONFIG_FLAGS_HOUSEKEEPER | ZBX_CONFIG_FLAGS_DB_EXTENSION);
 
-		if (0 == strcmp(cfg.db.extension, ZBX_CONFIG_DB_EXTENSION_TIMESCALE))
+		if (0 == strcmp(cfg.db.extension, ZBX_DB_EXTENSION_TIMESCALEDB))
 		{
 			zbx_setproctitle("%s [synchronizing history and trends compression settings]",
 					get_process_type_string(process_type));
@@ -1328,11 +1248,8 @@ ZBX_THREAD_ENTRY(housekeeper_thread, args)
 				" %d audit items, %d records in " ZBX_FS_DBL " sec, %s]",
 				get_process_type_string(process_type), d_history_and_trends, d_cleanup, d_events,
 				d_sessions, d_services, d_audit, records, sec, sleeptext);
-
-		if (0 != CONFIG_HOUSEKEEPING_FREQUENCY)
-			sleeptime = CONFIG_HOUSEKEEPING_FREQUENCY * SEC_PER_HOUR;
 	}
-
+out:
 	zbx_setproctitle("%s #%d [terminated]", get_process_type_string(process_type), process_num);
 
 	while (1)
