@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2025 Zabbix SIA
+** Copyright (C) 2001-2022 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -17,19 +17,14 @@
 ** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 **/
 
-#include "common.h"
+#include "httptest.h"
 
-#include "db.h"
 #include "log.h"
-#include "dbcache.h"
 #include "preproc.h"
 #include "daemon.h"
-
 #include "zbxserver.h"
 #include "zbxregexp.h"
 #include "zbxhttp.h"
-
-#include "httptest.h"
 #include "httpmacro.h"
 
 typedef struct
@@ -84,15 +79,11 @@ static size_t	curl_ignore_cb(void *ptr, size_t size, size_t nmemb, void *userdat
 #endif	/* HAVE_LIBCURL */
 
 /******************************************************************************
- *                                                                            *
- * Function: httptest_remove_macros                                           *
  *                                                                            *
  * Purpose: remove all macro variables cached during http test execution      *
  *                                                                            *
  * Parameters: httptest - [IN] the http test data                             *
  *                                                                            *
- * Author: Andris Zeila                                                       *
- *                                                                            *
  ******************************************************************************/
 static void	httptest_remove_macros(zbx_httptest_t *httptest)
 {
@@ -202,8 +193,6 @@ static void	process_test_data(zbx_uint64_t httptestid, int lastfailedstep, doubl
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: httpstep_pairs_join                                              *
  *                                                                            *
  * Purpose: performs concatenation of vector of pairs into delimited string   *
  *                                                                            *
@@ -237,8 +226,6 @@ static void	httpstep_pairs_join(char **str, size_t *alloc_len, size_t *offset, c
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: httppairs_free                                                   *
  *                                                                            *
  * Purpose: frees memory allocated for vector of pairs                        *
  *                                                                            *
@@ -345,8 +332,6 @@ static void	process_step_data(zbx_uint64_t httpstepid, zbx_httpstat_t *stat, zbx
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: httpstep_load_pairs                                              *
  *                                                                            *
  * Purpose: loads http fields of web scenario step                            *
  *                                                                            *
@@ -391,7 +376,7 @@ static int	httpstep_load_pairs(DC_HOST *host, zbx_httpstep_t *httpstep)
 
 		/* from now on variable values can contain macros so proper URL encoding can be performed */
 		if (SUCCEED != (ret = substitute_simple_macros_unmasked(NULL, NULL, NULL, NULL, NULL, host, NULL, NULL,
-				NULL, &value, MACRO_TYPE_HTTPTEST_FIELD, NULL, 0)))
+				NULL, NULL, NULL, NULL, &value, MACRO_TYPE_HTTPTEST_FIELD, NULL, 0)))
 		{
 			zbx_free(value);
 			goto out;
@@ -402,7 +387,8 @@ static int	httpstep_load_pairs(DC_HOST *host, zbx_httpstep_t *httpstep)
 		/* variable names cannot contain macros, and both variable names and variable values cannot contain */
 		/* another variables */
 		if (ZBX_HTTPFIELD_VARIABLE != type && (SUCCEED != (ret = substitute_simple_macros(NULL, NULL, NULL,
-				NULL, NULL, host, NULL, NULL, NULL, &key, MACRO_TYPE_HTTPTEST_FIELD, NULL, 0)) ||
+				NULL, NULL, host, NULL, NULL, NULL, NULL, NULL, NULL, &key, MACRO_TYPE_HTTPTEST_FIELD,
+				NULL, 0)) ||
 				SUCCEED != (ret = http_substitute_variables(httpstep->httptest, &key)) ||
 				SUCCEED != (ret = http_substitute_variables(httpstep->httptest, &value))))
 		{
@@ -498,8 +484,6 @@ out:
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: add_http_headers                                                 *
  *                                                                            *
  * Purpose: adds HTTP headers to curl_slist and prepares cookie header string *
  *                                                                            *
@@ -515,7 +499,7 @@ static void	add_http_headers(char *headers, struct curl_slist **headers_slist, c
 
 	char	*line;
 
-	while (NULL != (line = zbx_http_get_header(&headers)))
+	while (NULL != (line = zbx_http_parse_header(&headers)))
 	{
 		if (0 == strncmp(COOKIE_HEADER_STR, line, COOKIE_HEADER_STR_LEN))
 			*header_cookie = zbx_strdup(*header_cookie, line + COOKIE_HEADER_STR_LEN);
@@ -531,8 +515,6 @@ static void	add_http_headers(char *headers, struct curl_slist **headers_slist, c
 #endif
 
 /******************************************************************************
- *                                                                            *
- * Function: httptest_load_pairs                                              *
  *                                                                            *
  * Purpose: loads http fields of web scenario                                 *
  *                                                                            *
@@ -571,7 +553,7 @@ static int	httptest_load_pairs(DC_HOST *host, zbx_httptest_t *httptest)
 
 		/* from now on variable values can contain macros so proper URL encoding can be performed */
 		if (SUCCEED != (ret = substitute_simple_macros_unmasked(NULL, NULL, NULL, NULL, NULL, host, NULL, NULL,
-				NULL, &value, MACRO_TYPE_HTTPTEST_FIELD, NULL, 0)))
+				NULL, NULL, NULL, NULL, &value, MACRO_TYPE_HTTPTEST_FIELD, NULL, 0)))
 		{
 			zbx_free(value);
 			goto out;
@@ -582,7 +564,8 @@ static int	httptest_load_pairs(DC_HOST *host, zbx_httptest_t *httptest)
 		/* variable names cannot contain macros, and both variable names and variable values cannot contain */
 		/* another variables */
 		if (ZBX_HTTPFIELD_VARIABLE != type && SUCCEED != (ret = substitute_simple_macros(NULL, NULL, NULL,
-				NULL, NULL, host, NULL, NULL, NULL, &key, MACRO_TYPE_HTTPTEST_FIELD, NULL, 0)))
+				NULL, NULL, host, NULL, NULL, NULL, NULL, NULL, NULL, &key, MACRO_TYPE_HTTPTEST_FIELD,
+				NULL, 0)))
 		{
 			httppairs_free(&httptest->variables);
 			zbx_free(key);
@@ -620,19 +603,9 @@ out:
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: process_httptest                                                 *
  *                                                                            *
  * Purpose: process single scenario of http test                              *
  *                                                                            *
- * Parameters:                                                                *
- *                                                                            *
- * Return value:                                                              *
- *                                                                            *
- * Author: Alexei Vladishev                                                   *
- *                                                                            *
- * Comments:                                                                  *
- *                                                                            *
  ******************************************************************************/
 static void	process_httptest(DC_HOST *host, zbx_httptest_t *httptest)
 {
@@ -665,8 +638,8 @@ static void	process_httptest(DC_HOST *host, zbx_httptest_t *httptest)
 			httptest->httptest.httptestid);
 
 	buffer = zbx_strdup(buffer, httptest->httptest.delay);
-	substitute_simple_macros(NULL, NULL, NULL, NULL, &host->hostid, NULL, NULL, NULL, NULL, &buffer,
-			MACRO_TYPE_COMMON, NULL, 0);
+	substitute_simple_macros(NULL, NULL, NULL, NULL, &host->hostid, NULL, NULL, NULL, NULL, NULL, NULL, NULL,
+			&buffer, MACRO_TYPE_COMMON, NULL, 0);
 
 	/* Avoid the potential usage of uninitialized values when: */
 	/* 1) compile without libCURL support */
@@ -697,15 +670,6 @@ static void	process_httptest(DC_HOST *host, zbx_httptest_t *httptest)
 		goto clean;
 	}
 
-#if LIBCURL_VERSION_NUM >= 0x071304
-	/* CURLOPT_PROTOCOLS is supported starting with version 7.19.4 (0x071304) */
-	if (CURLE_OK != (err = curl_easy_setopt(easyhandle, CURLOPT_PROTOCOLS, CURLPROTO_HTTP | CURLPROTO_HTTPS)))
-	{
-		err_str = zbx_strdup(err_str, curl_easy_strerror(err));
-		goto clean;
-	}
-#endif
-
 	if (SUCCEED != zbx_http_prepare_ssl(easyhandle, httptest->httptest.ssl_cert_file,
 			httptest->httptest.ssl_key_file, httptest->httptest.ssl_key_password,
 			httptest->httptest.verify_peer, httptest->httptest.verify_host, &err_str))
@@ -732,25 +696,25 @@ static void	process_httptest(DC_HOST *host, zbx_httptest_t *httptest)
 		db_httpstep.name = row[2];
 
 		db_httpstep.url = zbx_strdup(NULL, row[3]);
-		substitute_simple_macros_unmasked(NULL, NULL, NULL, NULL, NULL, host, NULL, NULL, NULL,
-				&db_httpstep.url, MACRO_TYPE_HTTPTEST_FIELD, NULL, 0);
+		substitute_simple_macros_unmasked(NULL, NULL, NULL, NULL, NULL, host, NULL, NULL, NULL, NULL, NULL,
+				NULL, &db_httpstep.url, MACRO_TYPE_HTTPTEST_FIELD, NULL, 0);
 		http_substitute_variables(httptest, &db_httpstep.url);
 
 		db_httpstep.required = zbx_strdup(NULL, row[6]);
-		substitute_simple_macros(NULL, NULL, NULL, NULL, NULL, host, NULL, NULL, NULL,
+		substitute_simple_macros(NULL, NULL, NULL, NULL, NULL, host, NULL, NULL, NULL, NULL, NULL, NULL,
 				&db_httpstep.required, MACRO_TYPE_HTTPTEST_FIELD, NULL, 0);
 
 		db_httpstep.status_codes = zbx_strdup(NULL, row[7]);
-		substitute_simple_macros(NULL, NULL, NULL, NULL, &host->hostid, NULL, NULL, NULL, NULL,
-				&db_httpstep.status_codes, MACRO_TYPE_COMMON, NULL, 0);
+		substitute_simple_macros(NULL, NULL, NULL, NULL, &host->hostid, NULL, NULL, NULL, NULL, NULL, NULL,
+				NULL, &db_httpstep.status_codes, MACRO_TYPE_COMMON, NULL, 0);
 
 		db_httpstep.post_type = atoi(row[8]);
 
 		if (ZBX_POSTTYPE_RAW == db_httpstep.post_type)
 		{
 			db_httpstep.posts = zbx_strdup(NULL, row[5]);
-			substitute_simple_macros_unmasked(NULL, NULL, NULL, NULL, NULL, host, NULL, NULL, NULL,
-					&db_httpstep.posts, MACRO_TYPE_HTTPTEST_FIELD, NULL, 0);
+			substitute_simple_macros_unmasked(NULL, NULL, NULL, NULL, NULL, host, NULL, NULL, NULL, NULL,
+					NULL, NULL, &db_httpstep.posts, MACRO_TYPE_HTTPTEST_FIELD, NULL, 0);
 			http_substitute_variables(httptest, &db_httpstep.posts);
 		}
 		else
@@ -763,8 +727,8 @@ static void	process_httptest(DC_HOST *host, zbx_httptest_t *httptest)
 		}
 
 		buffer = zbx_strdup(buffer, row[4]);
-		substitute_simple_macros(NULL, NULL, NULL, NULL, &host->hostid, NULL, NULL, NULL, NULL, &buffer,
-				MACRO_TYPE_COMMON, NULL, 0);
+		substitute_simple_macros(NULL, NULL, NULL, NULL, &host->hostid, NULL, NULL, NULL, NULL, NULL, NULL,
+				NULL, &buffer, MACRO_TYPE_COMMON, NULL, 0);
 
 		if (SUCCEED != is_time_suffix(buffer, &db_httpstep.timeout, ZBX_LENGTH_UNLIMITED))
 		{
@@ -1014,13 +978,8 @@ httptest_error:
 
 	if (0 > lastfailedstep)	/* update interval is invalid, delay is uninitialized */
 	{
-		zbx_config_t	cfg;
-
-		zbx_config_get(&cfg, ZBX_CONFIG_FLAGS_REFRESH_UNSUPPORTED);
 		DBexecute("update httptest set nextcheck=%d where httptestid=" ZBX_FS_UI64,
-				(0 == cfg.refresh_unsupported || 0 > ts.sec + cfg.refresh_unsupported ?
-				ZBX_JAN_2038 : ts.sec + cfg.refresh_unsupported), httptest->httptest.httptestid);
-		zbx_config_clean(&cfg);
+				0 > ts.sec ? ZBX_JAN_2038 : ts.sec, httptest->httptest.httptestid);
 	}
 	else if (0 > ts.sec + delay)
 	{
@@ -1066,8 +1025,6 @@ httptest_error:
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: process_httptests                                                *
  *                                                                            *
  * Purpose: process httptests                                                 *
  *                                                                            *
@@ -1075,8 +1032,6 @@ httptest_error:
  *                                                                            *
  * Return value: number of processed httptests                                *
  *                                                                            *
- * Author: Alexei Vladishev                                                   *
- *                                                                            *
  * Comments: always SUCCEED                                                   *
  *                                                                            *
  ******************************************************************************/
@@ -1129,25 +1084,25 @@ int	process_httptests(int httppoller_num, int now)
 		}
 
 		httptest.httptest.agent = zbx_strdup(NULL, row[5]);
-		substitute_simple_macros(NULL, NULL, NULL, NULL, &host.hostid, NULL, NULL, NULL, NULL,
-				&httptest.httptest.agent, MACRO_TYPE_COMMON, NULL, 0);
+		substitute_simple_macros(NULL, NULL, NULL, NULL, &host.hostid, NULL, NULL, NULL, NULL, NULL, NULL,
+				NULL, &httptest.httptest.agent, MACRO_TYPE_COMMON, NULL, 0);
 
 		if (HTTPTEST_AUTH_NONE != (httptest.httptest.authentication = atoi(row[6])))
 		{
 			httptest.httptest.http_user = zbx_strdup(NULL, row[7]);
 			substitute_simple_macros_unmasked(NULL, NULL, NULL, NULL, &host.hostid, NULL, NULL, NULL, NULL,
-					&httptest.httptest.http_user, MACRO_TYPE_COMMON, NULL, 0);
+					NULL, NULL, NULL, &httptest.httptest.http_user, MACRO_TYPE_COMMON, NULL, 0);
 
 			httptest.httptest.http_password = zbx_strdup(NULL, row[8]);
 			substitute_simple_macros_unmasked(NULL, NULL, NULL, NULL, &host.hostid, NULL, NULL, NULL, NULL,
-					&httptest.httptest.http_password, MACRO_TYPE_COMMON, NULL, 0);
+					NULL, NULL, NULL, &httptest.httptest.http_password, MACRO_TYPE_COMMON, NULL, 0);
 		}
 
 		if ('\0' != *row[9])
 		{
 			httptest.httptest.http_proxy = zbx_strdup(NULL, row[9]);
-			substitute_simple_macros(NULL, NULL, NULL, NULL, &host.hostid, NULL, NULL, NULL, NULL,
-					&httptest.httptest.http_proxy, MACRO_TYPE_COMMON, NULL, 0);
+			substitute_simple_macros(NULL, NULL, NULL, NULL, &host.hostid, NULL, NULL, NULL, NULL, NULL,
+					NULL, NULL, &httptest.httptest.http_proxy, MACRO_TYPE_COMMON, NULL, 0);
 		}
 		else
 			httptest.httptest.http_proxy = NULL;
@@ -1155,16 +1110,16 @@ int	process_httptests(int httppoller_num, int now)
 		httptest.httptest.retries = atoi(row[10]);
 
 		httptest.httptest.ssl_cert_file = zbx_strdup(NULL, row[11]);
-		substitute_simple_macros(NULL, NULL, NULL, NULL, NULL, &host, NULL, NULL, NULL,
+		substitute_simple_macros(NULL, NULL, NULL, NULL, NULL, &host, NULL, NULL, NULL, NULL, NULL, NULL,
 				&httptest.httptest.ssl_cert_file, MACRO_TYPE_HTTPTEST_FIELD, NULL, 0);
 
 		httptest.httptest.ssl_key_file = zbx_strdup(NULL, row[12]);
-		substitute_simple_macros(NULL, NULL, NULL, NULL, NULL, &host, NULL, NULL, NULL,
+		substitute_simple_macros(NULL, NULL, NULL, NULL, NULL, &host, NULL, NULL, NULL, NULL, NULL, NULL,
 				&httptest.httptest.ssl_key_file, MACRO_TYPE_HTTPTEST_FIELD, NULL, 0);
 
 		httptest.httptest.ssl_key_password = zbx_strdup(NULL, row[13]);
-		substitute_simple_macros_unmasked(NULL, NULL, NULL, NULL, &host.hostid, NULL, NULL, NULL, NULL,
-				&httptest.httptest.ssl_key_password, MACRO_TYPE_COMMON, NULL, 0);
+		substitute_simple_macros_unmasked(NULL, NULL, NULL, NULL, &host.hostid, NULL, NULL, NULL, NULL, NULL,
+				NULL, NULL, &httptest.httptest.ssl_key_password, MACRO_TYPE_COMMON, NULL, 0);
 
 		httptest.httptest.verify_peer = atoi(row[14]);
 		httptest.httptest.verify_host = atoi(row[15]);
