@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2025 Zabbix SIA
+** Copyright (C) 2001-2022 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -17,10 +17,12 @@
 ** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 **/
 
-#include "checks_ipmi.h"
+#include "common.h"
 
 #ifdef HAVE_OPENIPMI
 
+#include "checks_ipmi.h"
+
 /* Theoretically it should be enough max 16 bytes for sensor ID and terminating '\0' (see SDR record format in IPMI */
 /* v2 spec). OpenIPMI author Corey Minyard explained at	*/
 /* www.mail-archive.com/openipmi-developer@lists.sourceforge.net/msg02013.html: */
@@ -188,8 +190,6 @@ static char	*zbx_sensor_id_to_str(char *str, size_t str_sz, const char *id, enum
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: zbx_get_ipmi_host                                                *
  *                                                                            *
  * Purpose: Find element in the global list 'hosts' using parameters as       *
  *          search criteria                                                   *
@@ -224,8 +224,6 @@ static zbx_ipmi_host_t	*zbx_get_ipmi_host(const char *ip, const int port, int au
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: zbx_allocate_ipmi_host                                           *
  *                                                                            *
  * Purpose: create a new element in the global list 'hosts'                   *
  *                                                                            *
@@ -329,8 +327,6 @@ static zbx_ipmi_sensor_t	*zbx_get_ipmi_sensor_by_full_name(const zbx_ipmi_host_t
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: get_domain_offset                                                *
  *                                                                            *
  * Purpose: Check if an item name starts from domain name and find the domain *
  *          name length                                                       *
@@ -355,8 +351,6 @@ static size_t	get_domain_offset(const zbx_ipmi_host_t *h, const char *full_name)
 	return offset;
 }
 /******************************************************************************
- *                                                                            *
- * Function: zbx_get_sensor_id                                                *
  *                                                                            *
  * Purpose:  Converts sensor id to printable string and return id_type        *
  *                                                                            *
@@ -847,8 +841,6 @@ out:
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: zbx_perform_openipmi_ops                                         *
  *                                                                            *
  * Purpose: Pass control to OpenIPMI library to process events                *
  *                                                                            *
@@ -884,8 +876,6 @@ static int	zbx_perform_openipmi_ops(zbx_ipmi_host_t *h, const char *func_name)
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: zbx_perform_all_openipmi_ops                                     *
  *                                                                            *
  * Purpose: Pass control to OpenIPMI library to process all internal events   *
  *                                                                            *
@@ -1682,8 +1672,6 @@ void	zbx_delete_inactive_ipmi_hosts(time_t last_check)
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: has_name_prefix                                                  *
  *                                                                            *
  * Purpose: Check if a string starts with one of predefined prefixes and      *
  *          set prefix length                                                 *
