@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2025 Zabbix SIA
+** Copyright (C) 2001-2022 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -21,25 +21,23 @@
 
 #ifdef HAVE_OPENIPMI
 
-#include "dbcache.h"
+#include "ipmi_poller.h"
+
 #include "daemon.h"
 #include "zbxself.h"
 #include "log.h"
 #include "zbxipcservice.h"
-
-#include "ipmi_manager.h"
 #include "ipmi_protocol.h"
 #include "checks_ipmi.h"
-#include "ipmi_poller.h"
+
 
 #define ZBX_IPMI_MANAGER_CLEANUP_DELAY		SEC_PER_DAY
 
-extern unsigned char	process_type, program_type;
-extern int		server_num, process_num;
+extern ZBX_THREAD_LOCAL unsigned char	process_type;
+extern unsigned char			program_type;
+extern ZBX_THREAD_LOCAL int		server_num, process_num;
 
 /******************************************************************************
- *                                                                            *
- * Function: ipmi_poller_register                                             *
  *                                                                            *
  * Purpose: registers IPMI poller with IPMI manager                           *
  *                                                                            *
@@ -56,8 +54,6 @@ static void	ipmi_poller_register(zbx_ipc_async_socket_t *socket)
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: ipmi_poller_send_result                                          *
  *                                                                            *
  * Purpose: sends IPMI poll result to manager                                 *
  *                                                                            *
@@ -82,8 +78,6 @@ static void	ipmi_poller_send_result(zbx_ipc_async_socket_t *socket, zbx_uint32_t
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: ipmi_poller_process_value_request                                *
  *                                                                            *
  * Purpose: gets IPMI sensor value from the specified host                    *
  *                                                                            *
@@ -133,8 +127,6 @@ static void	ipmi_poller_process_value_request(zbx_ipc_async_socket_t *socket, zb
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: ipmi_poller_process_command_request                              *
  *                                                                            *
  * Purpose:sets IPMI sensor value                                             *
  *                                                                            *
@@ -279,6 +271,10 @@ ZBX_THREAD_ENTRY(ipmi_poller_thread, args)
 
 	while (1)
 		zbx_sleep(SEC_PER_MIN);
+
+	zbx_ipc_async_socket_close(&ipmi_socket);
+
+	zbx_free_ipmi_handler();
 #undef STAT_INTERVAL
 }
 
