@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2025 Zabbix SIA
+** Copyright (C) 2001-2022 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -9,7 +9,7 @@
 **
 ** This program is distributed in the hope that it will be useful,
 ** but WITHOUT ANY WARRANTY; without even the implied warranty of
-** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 ** GNU General Public License for more details.
 **
 ** You should have received a copy of the GNU General Public License
@@ -17,17 +17,14 @@
 ** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 **/
 
-#include "lld.h"
 #include "log.h"
 #include "db.h"
 
-/******************************************************************************
- *                                                                            *
- * Function: lld_field_str_rollback                                           *
- *                                                                            *
- * Author: Alexander Vladishev                                                *
- *                                                                            *
- ******************************************************************************/
+#include "../../libs/zbxaudit/audit.h"
+#include "../../libs/zbxaudit/audit_item.h"
+#include "../../libs/zbxaudit/audit_graph.h"
+#include "../../libs/zbxaudit/audit_trigger.h"
+
 void	lld_field_str_rollback(char **field, char **field_orig, zbx_uint64_t *flags, zbx_uint64_t flag)
 {
 	if (0 == (*flags & flag))
@@ -40,25 +37,6 @@ void	lld_field_str_rollback(char **field, char **field_orig, zbx_uint64_t *flags
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: lld_field_uint64_rollback                                        *
- *                                                                            *
- * Author: Alexander Vladishev                                                *
- *                                                                            *
- ******************************************************************************/
-void	lld_field_uint64_rollback(zbx_uint64_t *field, zbx_uint64_t *field_orig, zbx_uint64_t *flags, zbx_uint64_t flag)
-{
-	if (0 == (*flags & flag))
-		return;
-
-	*field = *field_orig;
-	*field_orig = 0;
-	*flags &= ~flag;
-}
-
-/******************************************************************************
- *                                                                            *
- * Function: lld_end_of_life                                                  *
  *                                                                            *
  * Purpose: calculate when to delete lost resources in an overflow-safe way   *
  *                                                                            *
@@ -69,8 +47,6 @@ int	lld_end_of_life(int lastcheck, int lifetime)
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: lld_remove_lost_objects                                          *
  *                                                                            *
  * Purpose: updates lastcheck and ts_delete fields; removes lost resources    *
  *                                                                            *
@@ -98,8 +74,9 @@ void	lld_remove_lost_objects(const char *table, const char *id_name, const zbx_v
 	{
 		zbx_uint64_t	id;
 		int		discovery_flag, object_lastcheck, object_ts_delete;
+		const char	*name;
 
-		cb_info(objects->values[i], &id, &discovery_flag, &object_lastcheck, &object_ts_delete);
+		cb_info(objects->values[i], &id, &discovery_flag, &object_lastcheck, &object_ts_delete, &name);
 
 		if (0 == id)
 			continue;
@@ -111,6 +88,22 @@ void	lld_remove_lost_objects(const char *table, const char *id_name, const zbx_v
 			if (lastcheck > ts_delete)
 			{
 				zbx_vector_uint64_append(&del_ids, id);
+
+				if (0 == strcmp(table, "item_discovery"))
+				{
+					zbx_audit_item_create_entry_for_delete(id, name,
+							(int)ZBX_FLAG_DISCOVERY_CREATED);
+				}
+				else if (0 == strcmp(table, "graph_discovery"))
+				{
+					zbx_audit_graph_create_entry(AUDIT_ACTION_DELETE, id, name,
+							(int)ZBX_FLAG_DISCOVERY_CREATED);
+				}
+				else if (0 == strcmp(table, "trigger_discovery"))
+				{
+					zbx_audit_trigger_create_entry(AUDIT_ACTION_DELETE, id, name,
+							ZBX_FLAG_DISCOVERY_CREATED);
+				}
 			}
 			else if (object_ts_delete != ts_delete)
 			{
@@ -185,6 +178,7 @@ void	lld_remove_lost_objects(const char *table, const char *id_name, const zbx_v
 	if (0 != del_ids.values_num)
 	{
 		zbx_vector_uint64_sort(&del_ids, ZBX_DEFAULT_UINT64_COMPARE_FUNC);
+
 		cb(&del_ids);
 	}
 
