@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2025 Zabbix SIA
+** Copyright (C) 2001-2022 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -18,18 +18,34 @@
 **/
 
 #include "lld.h"
-#include "db.h"
+
 #include "log.h"
-#include "zbxalgo.h"
 #include "zbxserver.h"
+#include "../../libs/zbxaudit/audit.h"
+#include "../../libs/zbxaudit/audit_graph.h"
 
 typedef struct
 {
 	zbx_uint64_t		graphid;
 	char			*name;
 	char			*name_orig;
+	zbx_uint64_t		ymin_itemid_orig;
 	zbx_uint64_t		ymin_itemid;
+	zbx_uint64_t		ymax_itemid_orig;
 	zbx_uint64_t		ymax_itemid;
+	int 			width_orig;
+	int 			height_orig;
+	double 			yaxismin_orig;
+	double 			yaxismax_orig;
+	unsigned char 		show_work_period_orig;
+	unsigned char 		show_triggers_orig;
+	unsigned char 		graphtype_orig;
+	unsigned char 		show_legend_orig;
+	unsigned char 		show_3d_orig;
+	double 			percent_left_orig;
+	double 			percent_right_orig;
+	unsigned char 		ymin_type_orig;
+	unsigned char 		ymax_type_orig;
 	zbx_vector_ptr_t	gitems;
 #define ZBX_FLAG_LLD_GRAPH_UNSET			__UINT64_C(0x00000000)
 #define ZBX_FLAG_LLD_GRAPH_DISCOVERED			__UINT64_C(0x00000001)
@@ -67,12 +83,19 @@ zbx_lld_graph_t;
 typedef struct
 {
 	zbx_uint64_t		gitemid;
+	zbx_uint64_t		itemid_orig;
 	zbx_uint64_t		itemid;
+	char			*color_orig;
 	char			*color;
+	int			sortorder_orig;
 	int			sortorder;
+	unsigned char		drawtype_orig;
 	unsigned char		drawtype;
+	unsigned char		yaxisside_orig;
 	unsigned char		yaxisside;
+	unsigned char		calc_fnc_orig;
 	unsigned char		calc_fnc;
+	unsigned char		type_orig;
 	unsigned char		type;
 #define ZBX_FLAG_LLD_GITEM_UNSET			__UINT64_C(0x0000)
 #define ZBX_FLAG_LLD_GITEM_DISCOVERED			__UINT64_C(0x0001)
@@ -90,6 +113,7 @@ typedef struct
 		ZBX_FLAG_LLD_GITEM_UPDATE_TYPE)
 #define ZBX_FLAG_LLD_GITEM_DELETE			__UINT64_C(0x0100)
 	zbx_uint64_t		flags;
+	zbx_uint64_t		graphid;
 }
 zbx_lld_gitem_t;
 
@@ -114,6 +138,7 @@ static void	lld_items_free(zbx_vector_ptr_t *items)
 static void	lld_gitem_free(zbx_lld_gitem_t *gitem)
 {
 	zbx_free(gitem->color);
+	zbx_free(gitem->color_orig);
 	zbx_free(gitem);
 }
 
@@ -139,13 +164,11 @@ static void	lld_graphs_free(zbx_vector_ptr_t *graphs)
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: lld_graphs_get                                                   *
  *                                                                            *
  * Purpose: retrieve graphs which were created by the specified graph         *
  *          prototype                                                         *
  *                                                                            *
- * Parameters: parent_graphid - [IN] graph prototype identificator            *
+ * Parameters: parent_graphid - [IN] graph prototype identifier               *
  *             graphs         - [OUT] sorted list of graphs                   *
  *                                                                            *
  ******************************************************************************/
@@ -156,7 +179,6 @@ static void	lld_graphs_get(zbx_uint64_t parent_graphid, zbx_vector_ptr_t *graphs
 {
 	DB_RESULT	result;
 	DB_ROW		row;
-	zbx_lld_graph_t	*graph;
 
 	zabbix_log(LOG_LEVEL_DEBUG, "In %s()", __func__);
 
@@ -171,7 +193,7 @@ static void	lld_graphs_get(zbx_uint64_t parent_graphid, zbx_vector_ptr_t *graphs
 
 	while (NULL != (row = DBfetch(result)))
 	{
-		graph = (zbx_lld_graph_t *)zbx_malloc(NULL, sizeof(zbx_lld_graph_t));
+		zbx_lld_graph_t	*graph = (zbx_lld_graph_t *)zbx_malloc(NULL, sizeof(zbx_lld_graph_t));
 
 		ZBX_STR2UINT64(graph->graphid, row[0]);
 		graph->name = zbx_strdup(NULL, row[1]);
@@ -179,48 +201,63 @@ static void	lld_graphs_get(zbx_uint64_t parent_graphid, zbx_vector_ptr_t *graphs
 
 		graph->flags = ZBX_FLAG_LLD_GRAPH_UNSET;
 
-		if (atoi(row[2]) != width)
+		graph->width_orig = atoi(row[2]);
+		if (graph->width_orig != width)
 			graph->flags |= ZBX_FLAG_LLD_GRAPH_UPDATE_WIDTH;
 
-		if (atoi(row[3]) != height)
+		graph->height_orig = atoi(row[3]);
+		if (graph->height_orig != height)
 			graph->flags |= ZBX_FLAG_LLD_GRAPH_UPDATE_HEIGHT;
 
-		if (atof(row[4]) != yaxismin)
+		graph->yaxismin_orig = atof(row[4]);
+		if (FAIL == zbx_double_compare(graph->yaxismin_orig, yaxismin))
 			graph->flags |= ZBX_FLAG_LLD_GRAPH_UPDATE_YAXISMIN;
 
-		if (atof(row[5]) != yaxismax)
+		graph->yaxismax_orig = atof(row[5]);
+		if (FAIL == zbx_double_compare(graph->yaxismax_orig, yaxismax))
 			graph->flags |= ZBX_FLAG_LLD_GRAPH_UPDATE_YAXISMAX;
 
-		if ((unsigned char)atoi(row[6]) != show_work_period)
+		graph->show_work_period_orig = (unsigned char)atoi(row[6]);
+		if (graph->show_work_period_orig != show_work_period)
 			graph->flags |= ZBX_FLAG_LLD_GRAPH_UPDATE_SHOW_WORK_PERIOD;
 
-		if ((unsigned char)atoi(row[7]) != show_triggers)
+		graph->show_triggers_orig = (unsigned char)atoi(row[7]);
+		if (graph->show_triggers_orig != show_triggers)
 			graph->flags |= ZBX_FLAG_LLD_GRAPH_UPDATE_SHOW_TRIGGERS;
 
-		if ((unsigned char)atoi(row[8]) != graphtype)
+		graph->graphtype_orig = (unsigned char)atoi(row[8]);
+		if (graph->graphtype_orig != graphtype)
 			graph->flags |= ZBX_FLAG_LLD_GRAPH_UPDATE_GRAPHTYPE;
 
-		if ((unsigned char)atoi(row[9]) != show_legend)
+		graph->show_legend_orig = (unsigned char)atoi(row[9]);
+		if (graph->show_legend_orig != show_legend)
 			graph->flags |= ZBX_FLAG_LLD_GRAPH_UPDATE_SHOW_LEGEND;
 
-		if ((unsigned char)atoi(row[10]) != show_3d)
+		graph->show_3d_orig = (unsigned char)atoi(row[10]);
+		if (graph->show_3d_orig != show_3d)
 			graph->flags |= ZBX_FLAG_LLD_GRAPH_UPDATE_SHOW_3D;
 
-		if (atof(row[11]) != percent_left)
+		graph->percent_left_orig = atof(row[11]);
+		if (FAIL == zbx_double_compare(graph->percent_left_orig, percent_left))
 			graph->flags |= ZBX_FLAG_LLD_GRAPH_UPDATE_PERCENT_LEFT;
 
-		if (atof(row[12]) != percent_right)
+		graph->percent_right_orig = atof(row[12]);
+		if (FAIL == zbx_double_compare(graph->percent_right_orig, percent_right))
 			graph->flags |= ZBX_FLAG_LLD_GRAPH_UPDATE_PERCENT_RIGHT;
 
-		if ((unsigned char)atoi(row[13]) != ymin_type)
+		graph->ymin_type_orig = (unsigned char)atoi(row[13]);
+		if (graph->ymin_type_orig != ymin_type)
 			graph->flags |= ZBX_FLAG_LLD_GRAPH_UPDATE_YMIN_TYPE;
 
 		ZBX_DBROW2UINT64(graph->ymin_itemid, row[14]);
+		graph->ymin_itemid_orig = graph->ymin_itemid;
 
-		if ((unsigned char)atoi(row[15]) != ymax_type)
+		graph->ymax_type_orig = (unsigned char)atoi(row[15]);
+		if (graph->ymax_type_orig != ymax_type)
 			graph->flags |= ZBX_FLAG_LLD_GRAPH_UPDATE_YMAX_TYPE;
 
 		ZBX_DBROW2UINT64(graph->ymax_itemid, row[16]);
+		graph->ymax_itemid_orig = graph->ymax_itemid;
 
 		graph->lastcheck = atoi(row[17]);
 		graph->ts_delete = atoi(row[18]);
@@ -237,8 +274,6 @@ static void	lld_graphs_get(zbx_uint64_t parent_graphid, zbx_vector_ptr_t *graphs
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: lld_gitems_get                                                   *
  *                                                                            *
  * Purpose: retrieve graphs_items which are used by the graph prototype and   *
  *          by selected graphs                                                *
@@ -247,10 +282,8 @@ static void	lld_graphs_get(zbx_uint64_t parent_graphid, zbx_vector_ptr_t *graphs
 static void	lld_gitems_get(zbx_uint64_t parent_graphid, zbx_vector_ptr_t *gitems_proto,
 		zbx_vector_ptr_t *graphs)
 {
-	int			i, index;
+	int			i;
 	zbx_lld_graph_t		*graph;
-	zbx_lld_gitem_t		*gitem;
-	zbx_uint64_t		graphid;
 	zbx_vector_uint64_t	graphids;
 	DB_RESULT		result;
 	DB_ROW			row;
@@ -286,17 +319,27 @@ static void	lld_gitems_get(zbx_uint64_t parent_graphid, zbx_vector_ptr_t *gitems
 
 	while (NULL != (row = DBfetch(result)))
 	{
-		gitem = (zbx_lld_gitem_t *)zbx_malloc(NULL, sizeof(zbx_lld_gitem_t));
+		int			index;
+		zbx_uint64_t		graphid;
+		zbx_lld_gitem_t		*gitem = (zbx_lld_gitem_t *)zbx_malloc(NULL, sizeof(zbx_lld_gitem_t));
 
 		ZBX_STR2UINT64(gitem->gitemid, row[0]);
 		ZBX_STR2UINT64(graphid, row[1]);
 		ZBX_STR2UINT64(gitem->itemid, row[2]);
+		gitem->itemid_orig = gitem->itemid;
 		ZBX_STR2UCHAR(gitem->drawtype, row[3]);
+		gitem->drawtype_orig = gitem->drawtype;
 		gitem->sortorder = atoi(row[4]);
+		gitem->sortorder_orig = gitem->sortorder;
 		gitem->color = zbx_strdup(NULL, row[5]);
+		gitem->color_orig = NULL;
 		ZBX_STR2UCHAR(gitem->yaxisside, row[6]);
+		gitem->yaxisside_orig = gitem->yaxisside;
 		ZBX_STR2UCHAR(gitem->calc_fnc, row[7]);
+		gitem->calc_fnc_orig = gitem->calc_fnc;
 		ZBX_STR2UCHAR(gitem->type, row[8]);
+		gitem->type_orig = gitem->type;
+		gitem->graphid = graphid;
 
 		gitem->flags = ZBX_FLAG_LLD_GITEM_UNSET;
 
@@ -334,8 +377,6 @@ static void	lld_gitems_get(zbx_uint64_t parent_graphid, zbx_vector_ptr_t *gitems
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: lld_items_get                                                    *
  *                                                                            *
  * Purpose: returns the list of items which are related to the graph          *
  *          prototype                                                         *
@@ -351,8 +392,6 @@ static void	lld_items_get(const zbx_vector_ptr_t *gitems_proto, zbx_uint64_t ymi
 {
 	DB_RESULT		result;
 	DB_ROW			row;
-	const zbx_lld_gitem_t	*gitem;
-	zbx_lld_item_t		*item;
 	zbx_vector_uint64_t	itemids;
 	int			i;
 
@@ -362,7 +401,7 @@ static void	lld_items_get(const zbx_vector_ptr_t *gitems_proto, zbx_uint64_t ymi
 
 	for (i = 0; i < gitems_proto->values_num; i++)
 	{
-		gitem = (zbx_lld_gitem_t *)gitems_proto->values[i];
+		const zbx_lld_gitem_t	*gitem = (const zbx_lld_gitem_t *)gitems_proto->values[i];
 
 		zbx_vector_uint64_append(&itemids, gitem->itemid);
 	}
@@ -394,7 +433,7 @@ static void	lld_items_get(const zbx_vector_ptr_t *gitems_proto, zbx_uint64_t ymi
 
 		while (NULL != (row = DBfetch(result)))
 		{
-			item = (zbx_lld_item_t *)zbx_malloc(NULL, sizeof(zbx_lld_item_t));
+			zbx_lld_item_t	*item = (zbx_lld_item_t *)zbx_malloc(NULL, sizeof(zbx_lld_item_t));
 
 			ZBX_STR2UINT64(item->itemid, row[0]);
 			ZBX_STR2UCHAR(item->flags, row[1]);
@@ -412,8 +451,6 @@ static void	lld_items_get(const zbx_vector_ptr_t *gitems_proto, zbx_uint64_t ymi
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: lld_graph_by_item                                                *
  *                                                                            *
  * Purpose: finds already existing graph, using an item                       *
  *                                                                            *
@@ -446,8 +483,6 @@ static zbx_lld_graph_t	*lld_graph_by_item(zbx_vector_ptr_t *graphs, zbx_uint64_t
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: lld_graph_get                                                    *
  *                                                                            *
  * Purpose: finds already existing graph, using an item prototype and items   *
  *          already created by it                                             *
@@ -462,7 +497,7 @@ static zbx_lld_graph_t	*lld_graph_get(zbx_vector_ptr_t *graphs, const zbx_vector
 
 	for (i = 0; i < item_links->values_num; i++)
 	{
-		const zbx_lld_item_link_t	*item_link = (zbx_lld_item_link_t *)item_links->values[i];
+		const zbx_lld_item_link_t	*item_link = (const zbx_lld_item_link_t *)item_links->values[i];
 
 		if (NULL != (graph = lld_graph_by_item(graphs, item_link->itemid)))
 			return graph;
@@ -472,8 +507,6 @@ static zbx_lld_graph_t	*lld_graph_get(zbx_vector_ptr_t *graphs, const zbx_vector
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: lld_item_get                                                     *
  *                                                                            *
  * Purpose: finds already created item when itemid_proto is an item prototype *
  *          or return itemid_proto as itemid if it's a normal item            *
@@ -511,18 +544,17 @@ static int	lld_item_get(zbx_uint64_t itemid_proto, const zbx_vector_ptr_t *items
 }
 
 static int	lld_gitems_make(const zbx_vector_ptr_t *gitems_proto, zbx_vector_ptr_t *gitems,
-		const zbx_vector_ptr_t *items, const zbx_vector_ptr_t *item_links)
+		const zbx_vector_ptr_t *items, const zbx_vector_ptr_t *item_links, uint64_t grpahid)
 {
 	int			i, ret = FAIL;
-	const zbx_lld_gitem_t	*gitem_proto;
 	zbx_lld_gitem_t		*gitem;
-	zbx_uint64_t		itemid;
 
 	zabbix_log(LOG_LEVEL_DEBUG, "In %s()", __func__);
 
 	for (i = 0; i < gitems_proto->values_num; i++)
 	{
-		gitem_proto = (zbx_lld_gitem_t *)gitems_proto->values[i];
+		zbx_uint64_t		itemid;
+		const zbx_lld_gitem_t	*gitem_proto = (const zbx_lld_gitem_t *)gitems_proto->values[i];
 
 		if (SUCCEED != lld_item_get(gitem_proto->itemid, items, item_links, &itemid))
 			goto out;
@@ -533,12 +565,20 @@ static int	lld_gitems_make(const zbx_vector_ptr_t *gitems_proto, zbx_vector_ptr_
 
 			gitem->gitemid = 0;
 			gitem->itemid = itemid;
+			gitem->itemid_orig = gitem->itemid;
 			gitem->drawtype = gitem_proto->drawtype;
+			gitem->drawtype_orig = gitem->drawtype;
 			gitem->sortorder = gitem_proto->sortorder;
+			gitem->sortorder_orig = gitem->sortorder;
 			gitem->color = zbx_strdup(NULL, gitem_proto->color);
+			gitem->color_orig = NULL;
 			gitem->yaxisside = gitem_proto->yaxisside;
+			gitem->yaxisside_orig = gitem->yaxisside;
 			gitem->calc_fnc = gitem_proto->calc_fnc;
+			gitem->calc_fnc_orig = gitem->calc_fnc;
 			gitem->type = gitem_proto->type;
+			gitem->type_orig = gitem->type;
+			gitem->graphid = grpahid;
 
 			gitem->flags = ZBX_FLAG_LLD_GITEM_DISCOVERED;
 
@@ -550,42 +590,49 @@ static int	lld_gitems_make(const zbx_vector_ptr_t *gitems_proto, zbx_vector_ptr_
 
 			if (gitem->itemid != itemid)
 			{
+				gitem->itemid_orig = gitem->itemid;
 				gitem->itemid = itemid;
 				gitem->flags |= ZBX_FLAG_LLD_GITEM_UPDATE_ITEMID;
 			}
 
 			if (gitem->drawtype != gitem_proto->drawtype)
 			{
+				gitem->drawtype_orig = gitem->drawtype;
 				gitem->drawtype = gitem_proto->drawtype;
 				gitem->flags |= ZBX_FLAG_LLD_GITEM_UPDATE_DRAWTYPE;
 			}
 
 			if (gitem->sortorder != gitem_proto->sortorder)
 			{
+				gitem->sortorder_orig = gitem->sortorder;
 				gitem->sortorder = gitem_proto->sortorder;
 				gitem->flags |= ZBX_FLAG_LLD_GITEM_UPDATE_SORTORDER;
 			}
 
 			if (0 != strcmp(gitem->color, gitem_proto->color))
 			{
-				gitem->color = zbx_strdup(gitem->color, gitem_proto->color);
+				gitem->color_orig = gitem->color;
+				gitem->color = zbx_strdup(NULL, gitem_proto->color);
 				gitem->flags |= ZBX_FLAG_LLD_GITEM_UPDATE_COLOR;
 			}
 
 			if (gitem->yaxisside != gitem_proto->yaxisside)
 			{
+				gitem->yaxisside_orig = gitem->yaxisside;
 				gitem->yaxisside = gitem_proto->yaxisside;
 				gitem->flags |= ZBX_FLAG_LLD_GITEM_UPDATE_YAXISSIDE;
 			}
 
 			if (gitem->calc_fnc != gitem_proto->calc_fnc)
 			{
+				gitem->calc_fnc_orig = gitem->calc_fnc;
 				gitem->calc_fnc = gitem_proto->calc_fnc;
 				gitem->flags |= ZBX_FLAG_LLD_GITEM_UPDATE_CALC_FNC;
 			}
 
 			if (gitem->type != gitem_proto->type)
 			{
+				gitem->type_orig = gitem->type;
 				gitem->type = gitem_proto->type;
 				gitem->flags |= ZBX_FLAG_LLD_GITEM_UPDATE_TYPE;
 			}
@@ -609,8 +656,6 @@ out:
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: lld_graph_make                                                   *
  *                                                                            *
  * Purpose: create a graph based on lld rule and add it to the list           *
  *                                                                            *
@@ -620,7 +665,6 @@ static void 	lld_graph_make(const zbx_vector_ptr_t *gitems_proto, zbx_vector_ptr
 		unsigned char discover_proto, const zbx_lld_row_t *lld_row, const zbx_vector_ptr_t *lld_macro_paths)
 {
 	zbx_lld_graph_t			*graph = NULL;
-	char				*buffer = NULL;
 	const struct zbx_json_parse	*jp_row = &lld_row->jp_row;
 	zbx_uint64_t			ymin_itemid, ymax_itemid;
 
@@ -638,9 +682,11 @@ static void 	lld_graph_make(const zbx_vector_ptr_t *gitems_proto, zbx_vector_ptr
 
 	if (NULL != (graph = lld_graph_get(graphs, &lld_row->item_links)))
 	{
-		buffer = zbx_strdup(buffer, name_proto);
-		substitute_lld_macros(&buffer, jp_row, lld_macro_paths, ZBX_MACRO_SIMPLE, NULL, 0);
+		char	*buffer = zbx_strdup(NULL, name_proto);
+
+		substitute_lld_macros(&buffer, jp_row, lld_macro_paths, ZBX_MACRO_ANY, NULL, 0);
 		zbx_lrtrim(buffer, ZBX_WHITESPACE);
+
 		if (0 != strcmp(graph->name, buffer))
 		{
 			graph->name_orig = graph->name;
@@ -648,6 +694,8 @@ static void 	lld_graph_make(const zbx_vector_ptr_t *gitems_proto, zbx_vector_ptr
 			buffer = NULL;
 			graph->flags |= ZBX_FLAG_LLD_GRAPH_UPDATE_NAME;
 		}
+		else
+			zbx_free(buffer);
 
 		lld_override_graph(&lld_row->overrides, graph->name, &discover_proto);
 
@@ -656,12 +704,14 @@ static void 	lld_graph_make(const zbx_vector_ptr_t *gitems_proto, zbx_vector_ptr
 
 		if (graph->ymin_itemid != ymin_itemid)
 		{
+			graph->ymin_itemid_orig = graph->ymin_itemid;
 			graph->ymin_itemid = ymin_itemid;
 			graph->flags |= ZBX_FLAG_LLD_GRAPH_UPDATE_YMIN_ITEMID;
 		}
 
 		if (graph->ymax_itemid != ymax_itemid)
 		{
+			graph->ymax_itemid_orig = graph->ymax_itemid;
 			graph->ymax_itemid = ymax_itemid;
 			graph->flags |= ZBX_FLAG_LLD_GRAPH_UPDATE_YMAX_ITEMID;
 		}
@@ -676,7 +726,7 @@ static void 	lld_graph_make(const zbx_vector_ptr_t *gitems_proto, zbx_vector_ptr
 
 		graph->name = zbx_strdup(NULL, name_proto);
 		graph->name_orig = NULL;
-		substitute_lld_macros(&graph->name, jp_row, lld_macro_paths, ZBX_MACRO_SIMPLE, NULL, 0);
+		substitute_lld_macros(&graph->name, jp_row, lld_macro_paths, ZBX_MACRO_ANY, NULL, 0);
 		zbx_lrtrim(graph->name, ZBX_WHITESPACE);
 
 		lld_override_graph(&lld_row->overrides, graph->name, &discover_proto);
@@ -698,12 +748,11 @@ static void 	lld_graph_make(const zbx_vector_ptr_t *gitems_proto, zbx_vector_ptr
 		zbx_vector_ptr_append(graphs, graph);
 	}
 
-	if (SUCCEED != lld_gitems_make(gitems_proto, &graph->gitems, items, &lld_row->item_links))
+	if (SUCCEED != lld_gitems_make(gitems_proto, &graph->gitems, items, &lld_row->item_links, graph->graphid))
 		return;
 
 	graph->flags |= ZBX_FLAG_LLD_GRAPH_DISCOVERED;
 out:
-	zbx_free(buffer);
 	zabbix_log(LOG_LEVEL_DEBUG, "End of %s()", __func__);
 }
 
@@ -724,11 +773,6 @@ static void	lld_graphs_make(const zbx_vector_ptr_t *gitems_proto, zbx_vector_ptr
 	zbx_vector_ptr_sort(graphs, ZBX_DEFAULT_UINT64_PTR_COMPARE_FUNC);
 }
 
-/******************************************************************************
- *                                                                            *
- * Function: lld_validate_graph_field                                         *
- *                                                                            *
- ******************************************************************************/
 static void	lld_validate_graph_field(zbx_lld_graph_t *graph, char **field, char **field_orig, zbx_uint64_t flag,
 		size_t field_len, char **error)
 {
@@ -765,8 +809,6 @@ static void	lld_validate_graph_field(zbx_lld_graph_t *graph, char **field, char
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: lld_graphs_validate                                              *
  *                                                                            *
  * Parameters: graphs - [IN] sorted list of graphs                            *
  *                                                                            *
@@ -920,8 +962,6 @@ static void	lld_graphs_validate(zbx_uint64_t hostid, zbx_vector_ptr_t *graphs, c
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: lld_graphs_save                                                  *
  *                                                                            *
  * Purpose: add or update graphs in database based on discovery rule          *
  *                                                                            *
@@ -936,13 +976,11 @@ static int	lld_graphs_save(zbx_uint64_t hostid, zbx_uint64_t parent_graphid, zbx
 		double percent_left, double percent_right, unsigned char ymin_type, unsigned char ymax_type)
 {
 	int			ret = SUCCEED, i, j, new_graphs = 0, upd_graphs = 0, new_gitems = 0;
-	zbx_lld_graph_t		*graph;
-	zbx_lld_gitem_t		*gitem;
 	zbx_vector_ptr_t	upd_gitems; 	/* the ordered list of graphs_items which will be updated */
 	zbx_vector_uint64_t	del_gitemids;
 
 	zbx_uint64_t		graphid = 0, gitemid = 0;
-	char			*sql = NULL, *name_esc, *color_esc;
+	char			*sql = NULL;
 	size_t			sql_alloc = 8 * ZBX_KIBIBYTE, sql_offset = 0;
 	zbx_db_insert_t		db_insert, db_insert_gdiscovery, db_insert_gitems;
 
@@ -953,7 +991,7 @@ static int	lld_graphs_save(zbx_uint64_t hostid, zbx_uint64_t parent_graphid, zbx
 
 	for (i = 0; i < graphs->values_num; i++)
 	{
-		graph = (zbx_lld_graph_t *)graphs->values[i];
+		const zbx_lld_graph_t	*graph = (const zbx_lld_graph_t *)graphs->values[i];
 
 		if (0 == (graph->flags & ZBX_FLAG_LLD_GRAPH_DISCOVERED))
 			continue;
@@ -963,19 +1001,30 @@ static int	lld_graphs_save(zbx_uint64_t hostid, zbx_uint64_t parent_graphid, zbx
 		else if (0 != (graph->flags & ZBX_FLAG_LLD_GRAPH_UPDATE))
 			upd_graphs++;
 
+		if (0 != graph->graphid)
+		{
+			zbx_audit_graph_create_entry(AUDIT_ACTION_UPDATE, graph->graphid, (NULL == graph->name_orig) ?
+					graph->name : graph->name_orig, ZBX_FLAG_DISCOVERY_CREATED);
+		}
+
 		for (j = 0; j < graph->gitems.values_num; j++)
 		{
-			gitem = (zbx_lld_gitem_t *)graph->gitems.values[j];
+			zbx_lld_gitem_t	*gitem = (zbx_lld_gitem_t *)graph->gitems.values[j];
 
 			if (0 != (gitem->flags & ZBX_FLAG_LLD_GITEM_DELETE))
 			{
 				zbx_vector_uint64_append(&del_gitemids, gitem->gitemid);
+
+				zbx_audit_graph_update_json_delete_gitems(graph->graphid,
+						ZBX_FLAG_DISCOVERY_CREATED, gitem->gitemid);
 				continue;
 			}
 
 			if (0 == (gitem->flags & ZBX_FLAG_LLD_GITEM_DISCOVERED))
 				continue;
 
+			gitem->graphid = graph->graphid;
+
 			if (0 == gitem->gitemid)
 				new_gitems++;
 			else if (0 != (gitem->flags & ZBX_FLAG_LLD_GITEM_UPDATE))
@@ -1027,7 +1076,7 @@ static int	lld_graphs_save(zbx_uint64_t hostid, zbx_uint64_t parent_graphid, zbx
 
 	for (i = 0; i < graphs->values_num; i++)
 	{
-		graph = (zbx_lld_graph_t *)graphs->values[i];
+		zbx_lld_graph_t	*graph = (zbx_lld_graph_t *)graphs->values[i];
 
 		if (0 == (graph->flags & ZBX_FLAG_LLD_GRAPH_DISCOVERED))
 			continue;
@@ -1039,6 +1088,14 @@ static int	lld_graphs_save(zbx_uint64_t hostid, zbx_uint64_t parent_graphid, zbx
 					(int)show_3d, percent_left, percent_right, (int)ymin_type, graph->ymin_itemid,
 					(int)ymax_type, graph->ymax_itemid, (int)ZBX_FLAG_DISCOVERY_CREATED);
 
+			zbx_audit_graph_create_entry(AUDIT_ACTION_ADD, graphid, graph->name,
+					ZBX_FLAG_DISCOVERY_CREATED);
+
+			zbx_audit_graph_update_json_add_data(graphid, graph->name, width, height, yaxismin, yaxismax, 0,
+					(int)show_work_period, (int)show_triggers, (int)graphtype, (int)show_legend,
+					(int)show_3d, percent_left, percent_right, (int)ymin_type, (int)ymax_type,
+					graph->ymin_itemid, graph->ymax_itemid,	ZBX_FLAG_DISCOVERY_CREATED, 0);
+
 			zbx_db_insert_add_values(&db_insert_gdiscovery, graphid, parent_graphid);
 
 			graph->graphid = graphid++;
@@ -1051,22 +1108,32 @@ static int	lld_graphs_save(zbx_uint64_t hostid, zbx_uint64_t parent_graphid, zbx
 
 			if (0 != (graph->flags & ZBX_FLAG_LLD_GRAPH_UPDATE_NAME))
 			{
-				name_esc = DBdyn_escape_string(graph->name);
+				char	*name_esc = DBdyn_escape_string(graph->name);
+
 				zbx_snprintf_alloc(&sql, &sql_alloc, &sql_offset, "name='%s'", name_esc);
 				zbx_free(name_esc);
 				d = ",";
+
+				zbx_audit_graph_update_json_update_name(graph->graphid, (int)ZBX_FLAG_DISCOVERY_CREATED,
+						graph->name_orig, graph->name);
 			}
 
 			if (0 != (graph->flags & ZBX_FLAG_LLD_GRAPH_UPDATE_WIDTH))
 			{
 				zbx_snprintf_alloc(&sql, &sql_alloc, &sql_offset, "%swidth=%d", d, width);
 				d = ",";
+
+				zbx_audit_graph_update_json_update_width(graph->graphid,
+						(int)ZBX_FLAG_DISCOVERY_CREATED, graph->width_orig, width);
 			}
 
 			if (0 != (graph->flags & ZBX_FLAG_LLD_GRAPH_UPDATE_HEIGHT))
 			{
 				zbx_snprintf_alloc(&sql, &sql_alloc, &sql_offset, "%sheight=%d", d, height);
 				d = ",";
+
+				zbx_audit_graph_update_json_update_height(graph->graphid,
+						(int)ZBX_FLAG_DISCOVERY_CREATED, graph->height_orig, height);
 			}
 
 			if (0 != (graph->flags & ZBX_FLAG_LLD_GRAPH_UPDATE_YAXISMIN))
@@ -1074,6 +1141,9 @@ static int	lld_graphs_save(zbx_uint64_t hostid, zbx_uint64_t parent_graphid, zbx
 				zbx_snprintf_alloc(&sql, &sql_alloc, &sql_offset, "%syaxismin=" ZBX_FS_DBL64_SQL, d,
 						yaxismin);
 				d = ",";
+
+				zbx_audit_graph_update_json_update_yaxismin(graph->graphid,
+						(int)ZBX_FLAG_DISCOVERY_CREATED, graph->yaxismin_orig, yaxismin);
 			}
 
 			if (0 != (graph->flags & ZBX_FLAG_LLD_GRAPH_UPDATE_YAXISMAX))
@@ -1081,6 +1151,9 @@ static int	lld_graphs_save(zbx_uint64_t hostid, zbx_uint64_t parent_graphid, zbx
 				zbx_snprintf_alloc(&sql, &sql_alloc, &sql_offset, "%syaxismax=" ZBX_FS_DBL64_SQL, d,
 						yaxismax);
 				d = ",";
+
+				zbx_audit_graph_update_json_update_yaxismax(graph->graphid,
+						(int)ZBX_FLAG_DISCOVERY_CREATED, graph->yaxismax_orig, yaxismax);
 			}
 
 			if (0 != (graph->flags & ZBX_FLAG_LLD_GRAPH_UPDATE_SHOW_WORK_PERIOD))
@@ -1088,6 +1161,10 @@ static int	lld_graphs_save(zbx_uint64_t hostid, zbx_uint64_t parent_graphid, zbx
 				zbx_snprintf_alloc(&sql, &sql_alloc, &sql_offset, "%sshow_work_period=%d", d,
 						(int)show_work_period);
 				d = ",";
+
+				zbx_audit_graph_update_json_update_show_work_period(graph->graphid,
+						(int)ZBX_FLAG_DISCOVERY_CREATED, graph->show_work_period_orig,
+						(int)show_work_period);
 			}
 
 			if (0 != (graph->flags & ZBX_FLAG_LLD_GRAPH_UPDATE_SHOW_TRIGGERS))
@@ -1095,6 +1172,10 @@ static int	lld_graphs_save(zbx_uint64_t hostid, zbx_uint64_t parent_graphid, zbx
 				zbx_snprintf_alloc(&sql, &sql_alloc, &sql_offset, "%sshow_triggers=%d", d,
 						(int)show_triggers);
 				d = ",";
+
+				zbx_audit_graph_update_json_update_show_triggers(graph->graphid,
+						(int)ZBX_FLAG_DISCOVERY_CREATED, graph->show_triggers_orig,
+						(int)show_triggers);
 			}
 
 			if (0 != (graph->flags & ZBX_FLAG_LLD_GRAPH_UPDATE_GRAPHTYPE))
@@ -1102,6 +1183,10 @@ static int	lld_graphs_save(zbx_uint64_t hostid, zbx_uint64_t parent_graphid, zbx
 				zbx_snprintf_alloc(&sql, &sql_alloc, &sql_offset, "%sgraphtype=%d", d,
 						(int)graphtype);
 				d = ",";
+
+				zbx_audit_graph_update_json_update_graphtype(graph->graphid,
+						(int)ZBX_FLAG_DISCOVERY_CREATED, (int)graph->graphtype_orig,
+						(int)graphtype);
 			}
 
 			if (0 != (graph->flags & ZBX_FLAG_LLD_GRAPH_UPDATE_SHOW_LEGEND))
@@ -1109,12 +1194,20 @@ static int	lld_graphs_save(zbx_uint64_t hostid, zbx_uint64_t parent_graphid, zbx
 				zbx_snprintf_alloc(&sql, &sql_alloc, &sql_offset, "%sshow_legend=%d", d,
 						(int)show_legend);
 				d = ",";
+
+				zbx_audit_graph_update_json_update_show_legend(graph->graphid,
+						(int)ZBX_FLAG_DISCOVERY_CREATED, (int)graph->show_legend_orig,
+						(int)show_legend);
 			}
 
 			if (0 != (graph->flags & ZBX_FLAG_LLD_GRAPH_UPDATE_SHOW_3D))
 			{
 				zbx_snprintf_alloc(&sql, &sql_alloc, &sql_offset, "%sshow_3d=%d", d, (int)show_3d);
 				d = ",";
+
+				zbx_audit_graph_update_json_update_show_3d(graph->graphid,
+						(int)ZBX_FLAG_DISCOVERY_CREATED, (int)graph->show_3d_orig,
+						(int)show_3d);
 			}
 
 			if (0 != (graph->flags & ZBX_FLAG_LLD_GRAPH_UPDATE_PERCENT_LEFT))
@@ -1122,6 +1215,10 @@ static int	lld_graphs_save(zbx_uint64_t hostid, zbx_uint64_t parent_graphid, zbx
 				zbx_snprintf_alloc(&sql, &sql_alloc, &sql_offset, "%spercent_left=" ZBX_FS_DBL64_SQL, d,
 						percent_left);
 				d = ",";
+
+				zbx_audit_graph_update_json_update_percent_left(graph->graphid,
+						(int)ZBX_FLAG_DISCOVERY_CREATED, graph->percent_left_orig,
+						percent_left);
 			}
 
 			if (0 != (graph->flags & ZBX_FLAG_LLD_GRAPH_UPDATE_PERCENT_RIGHT))
@@ -1129,6 +1226,10 @@ static int	lld_graphs_save(zbx_uint64_t hostid, zbx_uint64_t parent_graphid, zbx
 				zbx_snprintf_alloc(&sql, &sql_alloc, &sql_offset,
 						"%spercent_right=" ZBX_FS_DBL64_SQL, d, percent_right);
 				d = ",";
+
+				zbx_audit_graph_update_json_update_percent_right(graph->graphid,
+						(int)ZBX_FLAG_DISCOVERY_CREATED, graph->percent_right_orig,
+						percent_right);
 			}
 
 			if (0 != (graph->flags & ZBX_FLAG_LLD_GRAPH_UPDATE_YMIN_TYPE))
@@ -1136,6 +1237,10 @@ static int	lld_graphs_save(zbx_uint64_t hostid, zbx_uint64_t parent_graphid, zbx
 				zbx_snprintf_alloc(&sql, &sql_alloc, &sql_offset, "%symin_type=%d", d,
 						(int)ymin_type);
 				d = ",";
+
+				zbx_audit_graph_update_json_update_ymin_type(graph->graphid,
+						(int)ZBX_FLAG_DISCOVERY_CREATED, (int)graph->ymin_type_orig,
+						(int)ymin_type);
 			}
 
 			if (0 != (graph->flags & ZBX_FLAG_LLD_GRAPH_UPDATE_YMIN_ITEMID))
@@ -1143,6 +1248,10 @@ static int	lld_graphs_save(zbx_uint64_t hostid, zbx_uint64_t parent_graphid, zbx
 				zbx_snprintf_alloc(&sql, &sql_alloc, &sql_offset, "%symin_itemid=%s", d,
 						DBsql_id_ins(graph->ymin_itemid));
 				d = ",";
+
+				zbx_audit_graph_update_json_update_ymin_itemid(graph->graphid,
+						(int)ZBX_FLAG_DISCOVERY_CREATED, graph->ymin_itemid_orig,
+						graph->ymin_itemid);
 			}
 
 			if (0 != (graph->flags & ZBX_FLAG_LLD_GRAPH_UPDATE_YMAX_TYPE))
@@ -1150,12 +1259,20 @@ static int	lld_graphs_save(zbx_uint64_t hostid, zbx_uint64_t parent_graphid, zbx
 				zbx_snprintf_alloc(&sql, &sql_alloc, &sql_offset, "%symax_type=%d", d,
 						(int)ymax_type);
 				d = ",";
+
+				zbx_audit_graph_update_json_update_ymax_type(graph->graphid,
+						(int)ZBX_FLAG_DISCOVERY_CREATED, (int)graph->ymax_type_orig,
+						(int)ymax_type);
 			}
 
 			if (0 != (graph->flags & ZBX_FLAG_LLD_GRAPH_UPDATE_YMAX_ITEMID))
 			{
 				zbx_snprintf_alloc(&sql, &sql_alloc, &sql_offset, "%symax_itemid=%s", d,
 						DBsql_id_ins(graph->ymax_itemid));
+
+				zbx_audit_graph_update_json_update_ymax_itemid(graph->graphid,
+						(int)ZBX_FLAG_DISCOVERY_CREATED, graph->ymax_itemid_orig,
+						graph->ymax_itemid);
 			}
 
 			zbx_snprintf_alloc(&sql, &sql_alloc, &sql_offset, " where graphid=" ZBX_FS_UI64 ";\n",
@@ -1164,7 +1281,7 @@ static int	lld_graphs_save(zbx_uint64_t hostid, zbx_uint64_t parent_graphid, zbx
 
 		for (j = 0; j < graph->gitems.values_num; j++)
 		{
-			gitem = (zbx_lld_gitem_t *)graph->gitems.values[j];
+			zbx_lld_gitem_t	*gitem = (zbx_lld_gitem_t *)graph->gitems.values[j];
 
 			if (0 != (gitem->flags & ZBX_FLAG_LLD_GITEM_DELETE))
 				continue;
@@ -1178,6 +1295,11 @@ static int	lld_graphs_save(zbx_uint64_t hostid, zbx_uint64_t parent_graphid, zbx
 						(int)gitem->drawtype, gitem->sortorder, gitem->color,
 						(int)gitem->yaxisside, (int)gitem->calc_fnc, (int)gitem->type);
 
+				zbx_audit_graph_update_json_add_gitems(graph->graphid, (int)ZBX_FLAG_DISCOVERY_CREATED,
+						gitemid, (int)gitem->drawtype, gitem->sortorder, gitem->color,
+						(int)gitem->yaxisside, (int)gitem->calc_fnc,(int)gitem->type,
+						gitem->itemid);
+
 				gitem->gitemid = gitemid++;
 			}
 		}
@@ -1185,9 +1307,8 @@ static int	lld_graphs_save(zbx_uint64_t hostid, zbx_uint64_t parent_graphid, zbx
 
 	for (i = 0; i < upd_gitems.values_num; i++)
 	{
-		const char	*d = "";
-
-		gitem = (zbx_lld_gitem_t *)upd_gitems.values[i];
+		const char		*d = "";
+		const zbx_lld_gitem_t	*gitem = (const zbx_lld_gitem_t *)upd_gitems.values[i];
 
 		zbx_strcpy_alloc(&sql, &sql_alloc, &sql_offset, "update graphs_items set ");
 
@@ -1195,26 +1316,43 @@ static int	lld_graphs_save(zbx_uint64_t hostid, zbx_uint64_t parent_graphid, zbx
 		{
 			zbx_snprintf_alloc(&sql, &sql_alloc, &sql_offset, "itemid=" ZBX_FS_UI64, gitem->itemid);
 			d = ",";
+
+			zbx_audit_graph_update_json_update_gitem_update_itemid(gitem->graphid,
+					(int)ZBX_FLAG_DISCOVERY_CREATED, gitem->gitemid, gitem->itemid_orig,
+					gitem->itemid);
 		}
 
 		if (0 != (gitem->flags & ZBX_FLAG_LLD_GITEM_UPDATE_DRAWTYPE))
 		{
 			zbx_snprintf_alloc(&sql, &sql_alloc, &sql_offset, "%sdrawtype=%d", d, (int)gitem->drawtype);
 			d = ",";
+
+			zbx_audit_graph_update_json_update_gitem_update_drawtype(gitem->graphid,
+					(int)ZBX_FLAG_DISCOVERY_CREATED, gitem->gitemid, (int)gitem->drawtype_orig,
+					(int)gitem->drawtype);
 		}
 
 		if (0 != (gitem->flags & ZBX_FLAG_LLD_GITEM_UPDATE_SORTORDER))
 		{
 			zbx_snprintf_alloc(&sql, &sql_alloc, &sql_offset, "%ssortorder=%d", d, gitem->sortorder);
 			d = ",";
+
+			zbx_audit_graph_update_json_update_gitem_update_sortorder(gitem->graphid,
+					(int)ZBX_FLAG_DISCOVERY_CREATED, gitem->gitemid, gitem->sortorder_orig,
+					gitem->sortorder);
 		}
 
 		if (0 != (gitem->flags & ZBX_FLAG_LLD_GITEM_UPDATE_COLOR))
 		{
-			color_esc = DBdyn_escape_string(gitem->color);
+			char	*color_esc = DBdyn_escape_string(gitem->color);
+
 			zbx_snprintf_alloc(&sql, &sql_alloc, &sql_offset, "%scolor='%s'", d, color_esc);
 			zbx_free(color_esc);
 			d = ",";
+
+			zbx_audit_graph_update_json_update_gitem_update_color(gitem->graphid,
+					(int)ZBX_FLAG_DISCOVERY_CREATED, gitem->gitemid, gitem->color_orig,
+					gitem->color);
 		}
 
 		if (0 != (gitem->flags & ZBX_FLAG_LLD_GITEM_UPDATE_YAXISSIDE))
@@ -1222,17 +1360,31 @@ static int	lld_graphs_save(zbx_uint64_t hostid, zbx_uint64_t parent_graphid, zbx
 			zbx_snprintf_alloc(&sql, &sql_alloc, &sql_offset, "%syaxisside=%d", d,
 					(int)gitem->yaxisside);
 			d = ",";
+
+			zbx_audit_graph_update_json_update_gitem_update_yaxisside(gitem->graphid,
+					(int)ZBX_FLAG_DISCOVERY_CREATED, gitem->gitemid, (int)gitem->yaxisside_orig,
+					(int)gitem->yaxisside);
 		}
 
 		if (0 != (gitem->flags & ZBX_FLAG_LLD_GITEM_UPDATE_CALC_FNC))
 		{
 			zbx_snprintf_alloc(&sql, &sql_alloc, &sql_offset, "%scalc_fnc=%d", d, (int)gitem->calc_fnc);
 			d = ",";
+
+			zbx_audit_graph_update_json_update_gitem_update_calc_fnc(gitem->graphid,
+					(int)ZBX_FLAG_DISCOVERY_CREATED, gitem->gitemid, (int)gitem->calc_fnc_orig,
+					(int)gitem->calc_fnc);
 		}
 
 		if (0 != (gitem->flags & ZBX_FLAG_LLD_GITEM_UPDATE_TYPE))
+		{
 			zbx_snprintf_alloc(&sql, &sql_alloc, &sql_offset, "%stype=%d", d, (int)gitem->type);
 
+			zbx_audit_graph_update_json_update_gitem_update_type(gitem->graphid,
+					(int)ZBX_FLAG_DISCOVERY_CREATED, gitem->gitemid, (int)gitem->type_orig,
+					(int)gitem->type);
+		}
+
 		zbx_snprintf_alloc(&sql, &sql_alloc, &sql_offset, " where gitemid=" ZBX_FS_UI64 ";\n",
 				gitem->gitemid);
 	}
@@ -1280,34 +1432,31 @@ out:
 }
 
 static	void	get_graph_info(const void *object, zbx_uint64_t *id, int *discovery_flag, int *lastcheck,
-		int *ts_delete)
+		int *ts_delete, const char **name)
 {
-	zbx_lld_graph_t	*graph;
+	const zbx_lld_graph_t	*graph;
 
-	graph = (zbx_lld_graph_t *)object;
+	graph = (const zbx_lld_graph_t *)object;
 
 	*id = graph->graphid;
 	*discovery_flag = graph->flags & ZBX_FLAG_LLD_GRAPH_DISCOVERED;
 	*lastcheck = graph->lastcheck;
 	*ts_delete = graph->ts_delete;
+	*name = graph->name;
 }
 
 /******************************************************************************
- *                                                                            *
- * Function: lld_update_graphs                                                *
  *                                                                            *
  * Purpose: add or update graphs for discovery item                           *
  *                                                                            *
- * Parameters: hostid  - [IN] host identificator from database                *
- *             agent   - [IN] discovery item identificator from database      *
+ * Parameters: hostid  - [IN] host identifier from database                   *
+ *             agent   - [IN] discovery item identifier from database         *
  *             jp_data - [IN] received data                                   *
  *                                                                            *
  * Return value: SUCCEED - if graphs were successfully added/updated or       *
  *                         adding/updating was not necessary                  *
  *               FAIL    - graphs cannot be added/updated                     *
  *                                                                            *
- * Author: Alexander Vladishev                                                *
- *                                                                            *
  ******************************************************************************/
 int	lld_update_graphs(zbx_uint64_t hostid, zbx_uint64_t lld_ruleid, const zbx_vector_ptr_t *lld_rows,
 		const zbx_vector_ptr_t *lld_macro_paths, char **error, int lifetime, int lastcheck)
