@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2025 Zabbix SIA
+** Copyright (C) 2001-2022 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -17,20 +17,15 @@
 ** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 **/
 
-#include "common.h"
-#include "comms.h"
-#include "log.h"
-#include "../../libs/zbxcrypto/tls_tcp_active.h"
-
 #include "checks_agent.h"
 
+#include "log.h"
+
 #if !(defined(HAVE_GNUTLS) || defined(HAVE_OPENSSL))
 extern unsigned char	program_type;
 #endif
 
 /******************************************************************************
- *                                                                            *
- * Function: get_value_agent                                                  *
  *                                                                            *
  * Purpose: retrieve data from Zabbix agent                                   *
  *                                                                            *
@@ -43,8 +38,6 @@ extern unsigned char	program_type;
  *               AGENT_ERROR - uncritical error on agent side occurred        *
  *               FAIL - otherwise                                             *
  *                                                                            *
- * Author: Alexei Vladishev                                                   *
- *                                                                            *
  * Comments: error will contain error message                                 *
  *                                                                            *
  ******************************************************************************/
