@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2025 Zabbix SIA
+** Copyright (C) 2001-2022 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -20,10 +20,7 @@
 #ifndef ZABBIX_CHECKS_DB_H
 #define ZABBIX_CHECKS_DB_H
 
-#include "common.h"
-
 #include "dbcache.h"
-#include "sysinfo.h"
 
 #ifdef HAVE_UNIXODBC
 int	get_value_db(const DC_ITEM *item, AGENT_RESULT *result);
