@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2025 Zabbix SIA
+** Copyright (C) 2001-2022 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -35,7 +35,7 @@ class CControllerAuthenticationUpdate extends CController {
 
 	protected function checkInput() {
 		$fields = [
-			'form_refresh' =>				'int32',
+			'form_refresh' =>				'string',
 			'ldap_test_user' =>				'string',
 			'ldap_test_password' =>			'string',
 			'ldap_test' =>					'in 1',
@@ -68,7 +68,9 @@ class CControllerAuthenticationUpdate extends CController {
 			'saml_sign_logout_responses' =>	'in 0,1',
 			'saml_encrypt_nameid' =>		'in 0,1',
 			'saml_encrypt_assertions' =>	'in 0,1',
-			'saml_case_sensitive' =>		'in '.ZBX_AUTH_CASE_INSENSITIVE.','.ZBX_AUTH_CASE_SENSITIVE
+			'saml_case_sensitive' =>		'in '.ZBX_AUTH_CASE_INSENSITIVE.','.ZBX_AUTH_CASE_SENSITIVE,
+			'passwd_min_length' =>			'int32',
+			'passwd_check_rules' =>			'array'
 		];
 
 		$ret = $this->validateInput($fields);
@@ -98,7 +100,7 @@ class CControllerAuthenticationUpdate extends CController {
 				|| $data['ldap_configured'] == ZBX_AUTH_LDAP_ENABLED);
 
 		if (!$is_valid) {
-			$this->response->setMessageError(_s('Incorrect value for field "%1$s": %2$s.', 'authentication_type',
+			CMessageHelper::setErrorTitle(_s('Incorrect value for field "%1$s": %2$s.', 'authentication_type',
 				_('LDAP is not configured')
 			));
 		}
@@ -115,11 +117,20 @@ class CControllerAuthenticationUpdate extends CController {
 		$is_valid = true;
 		$ldap_status = (new CFrontendSetup())->checkPhpLdapModule();
 		$ldap_fields = ['ldap_host', 'ldap_port', 'ldap_base_dn', 'ldap_search_attribute', 'ldap_configured'];
-		$config = select_config();
-		$this->getInputs($config, array_merge($ldap_fields, ['ldap_bind_dn', 'ldap_bind_password']));
-		$ldap_settings_changed = array_diff_assoc($config, select_config());
+		$ldap_auth_original = [
+			'ldap_host' => CAuthenticationHelper::get(CAuthenticationHelper::LDAP_HOST),
+			'ldap_port' => CAuthenticationHelper::get(CAuthenticationHelper::LDAP_PORT),
+			'ldap_base_dn' => CAuthenticationHelper::get(CAuthenticationHelper::LDAP_BASE_DN),
+			'ldap_search_attribute' => CAuthenticationHelper::get(CAuthenticationHelper::LDAP_SEARCH_ATTRIBUTE),
+			'ldap_configured' => CAuthenticationHelper::get(CAuthenticationHelper::LDAP_CONFIGURED),
+			'ldap_bind_dn' => CAuthenticationHelper::get(CAuthenticationHelper::LDAP_BIND_DN),
+			'ldap_bind_password' => CAuthenticationHelper::get(CAuthenticationHelper::LDAP_BIND_PASSWORD)
+		];
+		$ldap_auth = $ldap_auth_original;
+		$this->getInputs($ldap_auth, array_merge($ldap_fields, ['ldap_bind_dn', 'ldap_bind_password']));
+		$ldap_auth_changed = array_diff_assoc($ldap_auth, $ldap_auth_original);
 
-		if (!$ldap_settings_changed && !$this->hasInput('ldap_test')) {
+		if (!$ldap_auth_changed && !$this->hasInput('ldap_test')) {
 			return $is_valid;
 		}
 
@@ -128,17 +139,17 @@ class CControllerAuthenticationUpdate extends CController {
 		}
 
 		foreach ($ldap_fields as $field) {
-			if (trim($config[$field]) === '') {
-				$this->response->setMessageError(
-					_s('Incorrect value for field "%1$s": %2$s.', $field, _('cannot be empty'))
-				);
+			if (trim($ldap_auth[$field]) === '') {
+				CMessageHelper::setErrorTitle(_s('Incorrect value for field "%1$s": %2$s.', $field, _('cannot be empty')));
 				$is_valid = false;
 				break;
 			}
 		}
 
-		if ($is_valid && ($config['ldap_port'] < ZBX_MIN_PORT_NUMBER || $config['ldap_port'] > ZBX_MAX_PORT_NUMBER)) {
-			$this->response->setMessageError(_s(
+		if ($is_valid
+				&& ($ldap_auth['ldap_port'] < ZBX_MIN_PORT_NUMBER
+					|| $ldap_auth['ldap_port'] > ZBX_MAX_PORT_NUMBER)) {
+			CMessageHelper::setErrorTitle(_s(
 				'Incorrect value "%1$s" for "%2$s" field: must be between %3$s and %4$s.', $this->getInput('ldap_port'),
 				'ldap_port', ZBX_MIN_PORT_NUMBER, ZBX_MAX_PORT_NUMBER
 			));
@@ -146,28 +157,29 @@ class CControllerAuthenticationUpdate extends CController {
 		}
 
 		if ($ldap_status['result'] != CFrontendSetup::CHECK_OK) {
-			$this->response->setMessageError($ldap_status['error']);
+			CMessageHelper::setErrorTitle($ldap_status['error']);
 			$is_valid = false;
 		}
 		elseif ($is_valid) {
 			$ldap_validator = new CLdapAuthValidator([
 				'conf' => [
-					'host' => $config['ldap_host'],
-					'port' => $config['ldap_port'],
-					'base_dn' => $config['ldap_base_dn'],
-					'bind_dn' => $config['ldap_bind_dn'],
-					'bind_password' => $config['ldap_bind_password'],
-					'search_attribute' => $config['ldap_search_attribute']
-				]
+					'host' => $ldap_auth['ldap_host'],
+					'port' => $ldap_auth['ldap_port'],
+					'base_dn' => $ldap_auth['ldap_base_dn'],
+					'bind_dn' => $ldap_auth['ldap_bind_dn'],
+					'bind_password' => $ldap_auth['ldap_bind_password'],
+					'search_attribute' => $ldap_auth['ldap_search_attribute']
+				],
+				'detailed_errors' => true
 			]);
 
 			$login = $ldap_validator->validate([
-				'user' => $this->getInput('ldap_test_user', CWebUser::$data['alias']),
+				'username' => $this->getInput('ldap_test_user', CWebUser::$data['username']),
 				'password' => $this->getInput('ldap_test_password', '')
 			]);
 
 			if (!$login) {
-				$this->response->setMessageError($ldap_validator->getError());
+				CMessageHelper::setErrorTitle($ldap_validator->getError());
 				$is_valid = false;
 			}
 		}
@@ -184,20 +196,23 @@ class CControllerAuthenticationUpdate extends CController {
 		$openssl_status = (new CFrontendSetup())->checkPhpOpenSsl();
 
 		if ($openssl_status['result'] != CFrontendSetup::CHECK_OK) {
-			$this->response->setMessageError($openssl_status['error']);
+			CMessageHelper::setErrorTitle($openssl_status['error']);
 
 			return false;
 		}
 
 		$saml_fields = ['saml_idp_entityid', 'saml_sso_url', 'saml_sp_entityid', 'saml_username_attribute'];
-		$config = select_config();
-		$this->getInputs($config, $saml_fields);
+		$saml_auth = [
+			'saml_idp_entityid' => CAuthenticationHelper::get(CAuthenticationHelper::SAML_IDP_ENTITYID),
+			'saml_sso_url' => CAuthenticationHelper::get(CAuthenticationHelper::SAML_SSO_URL),
+			'saml_sp_entityid' => CAuthenticationHelper::get(CAuthenticationHelper::SAML_SP_ENTITYID),
+			'saml_username_attribute' => CAuthenticationHelper::get(CAuthenticationHelper::SAML_USERNAME_ATTRIBUTE)
+		];
+		$this->getInputs($saml_auth, $saml_fields);
 
 		foreach ($saml_fields as $field) {
-			if (trim($config[$field]) === '') {
-				$this->response->setMessageError(
-					_s('Incorrect value for field "%1$s": %2$s.', $field, _('cannot be empty'))
-				);
+			if (trim($saml_auth[$field]) === '') {
+				CMessageHelper::setErrorTitle(_s('Incorrect value for field "%1$s": %2$s.', $field, _('cannot be empty')));
 
 				return false;
 			}
@@ -212,7 +227,27 @@ class CControllerAuthenticationUpdate extends CController {
 	 * @return bool
 	 */
 	protected function checkPermissions() {
-		return $this->getUserType() == USER_TYPE_SUPER_ADMIN;
+		return $this->checkAccess(CRoleHelper::UI_ADMINISTRATION_AUTHENTICATION);
+	}
+
+	/**
+	 * In case of error, convert array back to integer (string) so edit form does not fail.
+	 *
+	 * @return array
+	 */
+	public function getInputAll() {
+		$input = parent::getInputAll();
+		$rules = $input['passwd_check_rules'];
+		$input['passwd_check_rules'] = 0x00;
+
+		foreach ($rules as $rule) {
+			$input['passwd_check_rules'] |= $rule;
+		}
+
+		// CNewValidator thinks int32 must be a string type integer.
+		$input['passwd_check_rules'] = (string) $input['passwd_check_rules'];
+
+		return $input;
 	}
 
 	protected function doAction() {
@@ -221,7 +256,9 @@ class CControllerAuthenticationUpdate extends CController {
 			: $this->validateDefaultAuth();
 
 		if ($auth_valid && $this->getInput('saml_auth_enabled', ZBX_AUTH_SAML_DISABLED) == ZBX_AUTH_SAML_ENABLED) {
-			$auth_valid &= $this->validateSamlAuth();
+			if (!$this->validateSamlAuth()) {
+				$auth_valid = false;
+			}
 		}
 
 		if (!$auth_valid) {
@@ -233,19 +270,57 @@ class CControllerAuthenticationUpdate extends CController {
 
 		// Only ZBX_AUTH_LDAP have 'Test' option.
 		if ($this->hasInput('ldap_test')) {
-			$this->response->setMessageOk(_('LDAP login successful'));
+			CMessageHelper::setSuccessTitle(_('LDAP login successful'));
 			$this->response->setFormData($this->getInputAll());
 			$this->setResponse($this->response);
 
 			return;
 		}
 
-		$config = select_config();
+		$auth_params = [
+			CAuthenticationHelper::AUTHENTICATION_TYPE,
+			CAuthenticationHelper::HTTP_AUTH_ENABLED,
+			CAuthenticationHelper::HTTP_LOGIN_FORM,
+			CAuthenticationHelper::HTTP_STRIP_DOMAINS,
+			CAuthenticationHelper::HTTP_CASE_SENSITIVE,
+			CAuthenticationHelper::LDAP_CASE_SENSITIVE,
+			CAuthenticationHelper::LDAP_CONFIGURED,
+			CAuthenticationHelper::LDAP_HOST,
+			CAuthenticationHelper::LDAP_PORT,
+			CAuthenticationHelper::LDAP_BASE_DN,
+			CAuthenticationHelper::LDAP_BIND_DN,
+			CAuthenticationHelper::LDAP_SEARCH_ATTRIBUTE,
+			CAuthenticationHelper::LDAP_BIND_PASSWORD,
+			CAuthenticationHelper::SAML_AUTH_ENABLED,
+			CAuthenticationHelper::SAML_IDP_ENTITYID,
+			CAuthenticationHelper::SAML_SSO_URL,
+			CAuthenticationHelper::SAML_SLO_URL,
+			CAuthenticationHelper::SAML_USERNAME_ATTRIBUTE,
+			CAuthenticationHelper::SAML_SP_ENTITYID,
+			CAuthenticationHelper::SAML_NAMEID_FORMAT,
+			CAuthenticationHelper::SAML_SIGN_MESSAGES,
+			CAuthenticationHelper::SAML_SIGN_ASSERTIONS,
+			CAuthenticationHelper::SAML_SIGN_AUTHN_REQUESTS,
+			CAuthenticationHelper::SAML_SIGN_LOGOUT_REQUESTS,
+			CAuthenticationHelper::SAML_SIGN_LOGOUT_RESPONSES,
+			CAuthenticationHelper::SAML_ENCRYPT_NAMEID,
+			CAuthenticationHelper::SAML_ENCRYPT_ASSERTIONS,
+			CAuthenticationHelper::SAML_CASE_SENSITIVE,
+			CAuthenticationHelper::PASSWD_MIN_LENGTH,
+			CAuthenticationHelper::PASSWD_CHECK_RULES
+		];
+		$auth = [];
+		foreach ($auth_params as $param) {
+			$auth[$param] = CAuthenticationHelper::get($param);
+		}
+
 		$fields = [
 			'authentication_type' => ZBX_AUTH_INTERNAL,
 			'ldap_configured' => ZBX_AUTH_LDAP_DISABLED,
 			'http_auth_enabled' => ZBX_AUTH_HTTP_DISABLED,
-			'saml_auth_enabled' => ZBX_AUTH_SAML_DISABLED
+			'saml_auth_enabled' => ZBX_AUTH_SAML_DISABLED,
+			'passwd_min_length' => DB::getDefault('config', 'passwd_min_length'),
+			'passwd_check_rules' => DB::getDefault('config', 'passwd_check_rules')
 		];
 
 		if ($this->getInput('http_auth_enabled', ZBX_AUTH_HTTP_DISABLED) == ZBX_AUTH_HTTP_ENABLED) {
@@ -270,7 +345,7 @@ class CControllerAuthenticationUpdate extends CController {
 				$fields['ldap_bind_password'] = '';
 			}
 			else {
-				unset($config['ldap_bind_password']);
+				unset($auth[CAuthenticationHelper::LDAP_BIND_PASSWORD]);
 			}
 		}
 
@@ -293,32 +368,39 @@ class CControllerAuthenticationUpdate extends CController {
 			];
 		}
 
-		$data = array_merge($config, $fields);
+		$data = $fields + $auth;
 		$this->getInputs($data, array_keys($fields));
-		$data = array_diff_assoc($data, $config);
+
+		$rules = $data['passwd_check_rules'];
+		$data['passwd_check_rules'] = 0x00;
+
+		foreach ($rules as $rule) {
+			$data['passwd_check_rules'] |= $rule;
+		}
+
+		$data = array_diff_assoc($data, $auth);
 
 		if (array_key_exists('ldap_bind_dn', $data) && trim($data['ldap_bind_dn']) === '') {
 			$data['ldap_bind_password'] = '';
 		}
 
 		if ($data) {
-			$result = update_config($data);
+			$result = API::Authentication()->update($data);
 
 			if ($result) {
 				if (array_key_exists('authentication_type', $data)) {
 					$this->invalidateSessions();
 				}
 
-				$this->response->setMessageOk(_('Authentication settings updated'));
-				add_audit(AUDIT_ACTION_UPDATE, AUDIT_RESOURCE_ZABBIX_CONFIG, _('Authentication method changed'));
+				CMessageHelper::setSuccessTitle(_('Authentication settings updated'));
 			}
 			else {
 				$this->response->setFormData($this->getInputAll());
-				$this->response->setMessageError(_('Cannot update authentication'));
+				CMessageHelper::setErrorTitle(_('Cannot update authentication'));
 			}
 		}
 		else {
-			$this->response->setMessageOk(_('Authentication settings updated'));
+			CMessageHelper::setSuccessTitle(_('Authentication settings updated'));
 		}
 
 		$this->setResponse($this->response);
