@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2025 Zabbix SIA
+** Copyright (C) 2001-2022 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -36,7 +36,7 @@ class CControllerMacrosUpdate extends CController {
 	}
 
 	protected function checkPermissions() {
-		return ($this->getUserType() == USER_TYPE_SUPER_ADMIN);
+		return $this->checkAccess(CRoleHelper::UI_ADMINISTRATION_GENERAL);
 	}
 
 	protected function doAction() {
@@ -126,10 +126,10 @@ class CControllerMacrosUpdate extends CController {
 
 		$response = new CControllerResponseRedirect((new CUrl('zabbix.php'))->setArgument('action', 'macros.edit'));
 		if ($result) {
-			$response->setMessageOk(_('Macros updated'));
+			CMessageHelper::setSuccessTitle(_('Macros updated'));
 		}
 		else {
-			$response->setMessageError(_('Cannot update macros'));
+			CMessageHelper::setErrorTitle(_('Cannot update macros'));
 			$form_data = $this->getInputAll();
 			$form_data['macros'] = array_values($form_data['macros']);
 			$response->setFormData($form_data);
