@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2025 Zabbix SIA
+** Copyright (C) 2001-2022 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -50,7 +50,7 @@ class CControllerModuleUpdate extends CController {
 	}
 
 	protected function checkPermissions() {
-		if ($this->getUserType() != USER_TYPE_SUPER_ADMIN) {
+		if (!$this->checkAccess(CRoleHelper::UI_ADMINISTRATION_GENERAL)) {
 			return false;
 		}
 
@@ -70,12 +70,15 @@ class CControllerModuleUpdate extends CController {
 			? ($this->hasInput('status') ? MODULE_STATUS_ENABLED : MODULE_STATUS_DISABLED)
 			: ($this->getAction() === 'module.enable' ? MODULE_STATUS_ENABLED : MODULE_STATUS_DISABLED);
 
+		$db_modules_update_names = [];
+
 		$db_modules = API::Module()->get([
 			'output' => ['relative_path', 'status'],
 			'sortfield' => 'relative_path',
 			'preservekeys' => true
 		]);
 
+		$module_manager = new CModuleManager(APP::ModuleManager()->getModulesDir());
 		$module_manager_enabled = new CModuleManager(APP::ModuleManager()->getModulesDir());
 
 		foreach ($db_modules as $moduleid => $db_module) {
@@ -84,6 +87,13 @@ class CControllerModuleUpdate extends CController {
 			if ($new_status == MODULE_STATUS_ENABLED) {
 				$manifest = $module_manager_enabled->addModule($db_module['relative_path']);
 			}
+			else {
+				$manifest = $module_manager->addModule($db_module['relative_path']);
+			}
+
+			if (array_key_exists($moduleid, $this->modules) && $manifest) {
+				$db_modules_update_names[] = $manifest['name'];
+			}
 		}
 
 		$errors = $module_manager_enabled->checkConflicts()['conflicts'];
@@ -125,26 +135,32 @@ class CControllerModuleUpdate extends CController {
 
 		if ($result) {
 			if ($this->getAction() === 'module.update') {
-				$response->setMessageOk(_s('Module updated'));
+				CMessageHelper::setSuccessTitle(_s('Module updated: %1$s.', $db_modules_update_names[0]));
 			}
 			elseif ($set_status == MODULE_STATUS_ENABLED) {
-				$response->setMessageOk(_n('Module enabled', 'Modules enabled', count($this->modules)));
+				CMessageHelper::setSuccessTitle(_n('Module enabled: %1$s.', 'Modules enabled: %1$s.',
+					implode(', ', $db_modules_update_names), count($this->modules)
+				));
 			}
 			else {
-				$response->setMessageOk(_n('Module disabled', 'Modules disabled', count($this->modules)));
+				CMessageHelper::setSuccessTitle(_n('Module disabled: %1$s.', 'Modules disabled: %1$s.',
+					implode(', ', $db_modules_update_names), count($this->modules)
+				));
 			}
 		}
 		else {
 			if ($this->getAction() === 'module.update') {
-				$response->setMessageError(_s('Cannot update module'));
+				CMessageHelper::setErrorTitle(_s('Cannot update module: %1$s.', $db_modules_update_names[0]));
 			}
 			elseif ($set_status == MODULE_STATUS_ENABLED) {
-				$response->setMessageError(_n('Cannot enable module', 'Cannot enable modules', count($this->modules)));
+				CMessageHelper::setErrorTitle(_n('Cannot enable module: %1$s.', 'Cannot enable modules: %1$s.',
+					implode(', ', $db_modules_update_names), count($this->modules)
+				));
 			}
 			else {
-				$response->setMessageError(
-					_n('Cannot disable module', 'Cannot disable modules', count($this->modules))
-				);
+				CMessageHelper::setErrorTitle(_n('Cannot disable module: %1$s.', 'Cannot disable modules: %1$s.',
+					implode(', ', $db_modules_update_names), count($this->modules)
+				));
 			}
 		}
 
