@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2025 Zabbix SIA
+** Copyright (C) 2001-2022 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -32,7 +32,8 @@ class CControllerScriptList extends CController {
 			'uncheck' =>		'in 1',
 			'filter_set' =>		'in 1',
 			'filter_rst' =>		'in 1',
-			'filter_name' =>	'string'
+			'filter_name' =>	'string',
+			'filter_scope' =>	'in '.implode(',', [-1, ZBX_SCRIPT_SCOPE_ACTION, ZBX_SCRIPT_SCOPE_HOST, ZBX_SCRIPT_SCOPE_EVENT])
 		];
 
 		$ret = $this->validateInput($fields);
@@ -45,7 +46,7 @@ class CControllerScriptList extends CController {
 	}
 
 	protected function checkPermissions() {
-		return ($this->getUserType() == USER_TYPE_SUPER_ADMIN);
+		return $this->checkAccess(CRoleHelper::UI_ADMINISTRATION_SCRIPTS);
 	}
 
 	protected function doAction() {
@@ -58,17 +59,18 @@ class CControllerScriptList extends CController {
 		// filter
 		if ($this->hasInput('filter_set')) {
 			CProfile::update('web.scripts.filter_name', $this->getInput('filter_name', ''), PROFILE_TYPE_STR);
+			CProfile::update('web.scripts.filter_scope', $this->getInput('filter_scope', -1), PROFILE_TYPE_INT);
 		}
 		elseif ($this->hasInput('filter_rst')) {
 			CProfile::delete('web.scripts.filter_name');
+			CProfile::delete('web.scripts.filter_scope');
 		}
 
 		$filter = [
-			'name' => CProfile::get('web.scripts.filter_name', '')
+			'name' => CProfile::get('web.scripts.filter_name', ''),
+			'scope' => CProfile::get('web.scripts.filter_scope', -1)
 		];
 
-		$config = select_config();
-
 		$data = [
 			'uncheck' => $this->hasInput('uncheck'),
 			'sort' => $sortField,
@@ -79,16 +81,23 @@ class CControllerScriptList extends CController {
 		];
 
 		// list of scripts
+		$limit = CSettingsHelper::get(CSettingsHelper::SEARCH_LIMIT) + 1;
 		$data['scripts'] = API::Script()->get([
-			'output' => ['scriptid', 'name', 'command', 'host_access', 'usrgrpid', 'groupid', 'type', 'execute_on'],
+			'output' => ['scriptid', 'name', 'command', 'host_access', 'usrgrpid', 'groupid', 'type', 'execute_on',
+				'scope'
+			],
 			'search' => [
 				'name' => ($filter['name'] === '') ? null : $filter['name']
 			],
+			'filter' => [
+				'scope' => ($filter['scope'] == -1) ? null : $filter['scope']
+			],
 			'editable' => true,
-			'limit' => $config['search_limit'] + 1
+			'limit' => $limit,
+			'preservekeys' => true
 		]);
 
-		// data sort and pager
+		// Data sort and pager.
 		order_result($data['scripts'], $sortField, $sortOrder);
 
 		$page_num = getRequest('page', 1);
@@ -97,14 +106,25 @@ class CControllerScriptList extends CController {
 			(new CUrl('zabbix.php'))->setArgument('action', $this->getAction())
 		);
 
-		// find script host group name and user group name. set to '' if all host/user groups used.
 
+
+		/*
+		 * Find script host group name and user group name. Set to NULL if all host/user groups used. Find associated
+		 * actions in any of operations. Collect scriptids for action scope scripts.
+		 */
+		$action_scriptids = [];
 		$usrgrpids = [];
 		$groupids = [];
 
 		foreach ($data['scripts'] as &$script) {
-			$script['userGroupName'] = null; // all user groups
-			$script['hostGroupName'] = null; // all host groups
+			$script['actions'] = [];
+
+			if ($script['type'] == ZBX_SCRIPT_TYPE_WEBHOOK) {
+				$script['command'] = '';
+			}
+
+			$script['userGroupName'] = null;
+			$script['hostGroupName'] = null;
 
 			if ($script['usrgrpid'] != 0) {
 				$usrgrpids[] = $script['usrgrpid'];
@@ -113,9 +133,30 @@ class CControllerScriptList extends CController {
 			if ($script['groupid'] != 0) {
 				$groupids[] = $script['groupid'];
 			}
+
+			if ($script['scope'] == ZBX_SCRIPT_SCOPE_ACTION) {
+				$action_scriptids[$script['scriptid']] = true;
+			}
 		}
 		unset($script);
 
+		if ($action_scriptids) {
+			$script_actions = API::Script()->get([
+				'output' => [],
+				'scriptids' => array_keys($action_scriptids),
+				'selectActions' => ['actionid', 'name', 'eventsource'],
+				'preservekeys' => true
+			]);
+
+			foreach ($data['scripts'] as $scriptid => &$script) {
+				if (array_key_exists($scriptid, $script_actions)) {
+					$script['actions'] = $script_actions[$scriptid]['actions'];
+					CArrayHelper::sort($script['actions'], ['name']);
+				}
+			}
+			unset($script);
+		}
+
 		if ($usrgrpids) {
 			$userGroups = API::UserGroup()->get([
 				'output' => ['name'],
@@ -148,6 +189,10 @@ class CControllerScriptList extends CController {
 			unset($script);
 		}
 
+		$data['config'] = [
+			'max_in_table' => CSettingsHelper::get(CSettingsHelper::MAX_IN_TABLE)
+		];
+
 		$response = new CControllerResponseData($data);
 		$response->setTitle(_('Configuration of scripts'));
 		$this->setResponse($response);
