@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2025 Zabbix SIA
+** Copyright (C) 2001-2022 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -32,7 +32,7 @@
 	jQuery(function() {
 		let tags_initialized = false;
 
-		$('#tabs').on('tabscreate tabsactivate', function(event, ui) {
+		$('#<?= $data['tabs_id'] ?>').on('tabscreate tabsactivate', function(event, ui) {
 			const $panel = (event.type === 'tabscreate') ? ui.panel : ui.newPanel;
 
 			if ($panel.attr('id') === 'tags-tab') {
