@@ -1,7 +1,7 @@
-<?php declare(strict_types=1);
+<?php declare(strict_types = 0);
 /*
 ** Zabbix
-** Copyright (C) 2001-2025 Zabbix SIA
+** Copyright (C) 2001-2022 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -144,6 +144,17 @@ class CSelect extends CTag {
 		return $this;
 	}
 
+	/**
+	 * @param string|null $name
+	 *
+	 * @return self
+	 */
+	public function setName($name): self {
+		$this->name = $name;
+
+		return $this;
+	}
+
 	/**
 	 * @param int $width
 	 *
@@ -164,6 +175,17 @@ class CSelect extends CTag {
 		return $this;
 	}
 
+	/**
+	 * @param int $value
+	 *
+	 * @return self
+	 */
+	public function setAdaptiveWidth(int $value): self {
+		$this->addStyle('max-width: '.$value.'px;');
+
+		return $this->setWidthAuto();
+	}
+
 	/**
 	 * Set custom template for options.
 	 *
@@ -177,6 +199,19 @@ class CSelect extends CTag {
 		return $this;
 	}
 
+	/**
+	 * Set custom template for selected option.
+	 *
+	 * @param string $template
+	 *
+	 * @return self
+	 */
+	public function setSelectedOptionTemplate(string $template) {
+		$this->setAttribute('selected-option-template', $template);
+
+		return $this;
+	}
+
 	/**
 	 * @deprecated
 	 *
@@ -220,13 +255,25 @@ class CSelect extends CTag {
 		return $options;
 	}
 
+	protected function startToString() {
+		$attributes = '';
+
+		foreach ($this->attributes as $key => $value) {
+			if ($value !== null) {
+				$attributes .= ' '.$key.'="'.$this->encode($value, $this->attrEncStrategy).'"';
+			}
+		}
+
+		return '<'.$this->tagname.$attributes.'>';
+	}
+
 	public function toString($destroy = true) {
 		$this->setAttribute('name', $this->name);
 		$this->setAttribute('data-options', json_encode($this->toArray()));
 
 		/*
-		 * This attribute makes element "focusable", it match by jQuery(':focusable') queries and also browser would be
-		 * able to evaluate "autofocus" attribute correctly.
+		 * This attribute makes element "focusable", it is matched by jQuery(':focusable') queries and also browser
+		 * would be able to evaluate "autofocus" attribute correctly.
 		 */
 		$this->setAttribute('tabindex', '-1');
 
