@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2025 Zabbix SIA
+** Copyright (C) 2001-2022 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -24,8 +24,8 @@
  */
 class CWidgetFormActionLog extends CWidgetForm {
 
-	public function __construct($data) {
-		parent::__construct($data, WIDGET_ACTION_LOG);
+	public function __construct($data, $templateid) {
+		parent::__construct($data, $templateid, WIDGET_ACTION_LOG);
 
 		$field_sort = (new CWidgetFieldSelect('sort_triggers', _('Sort entries by'), [
 			SCREEN_SORT_TRIGGERS_TIME_DESC => _('Time').' ('._('descending').')',
