@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2025 Zabbix SIA
+** Copyright (C) 2001-2022 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -32,7 +32,7 @@ $shape_border_types = [
 
 $horizontal_align_types = [
 	SYSMAP_SHAPE_LABEL_HALIGN_LEFT		=> _('Left'),
-	SYSMAP_SHAPE_LABEL_HALIGN_CENTER	=> _('Centre'),
+	SYSMAP_SHAPE_LABEL_HALIGN_CENTER	=> _('Center'),
 	SYSMAP_SHAPE_LABEL_HALIGN_RIGHT		=> _('Right')
 ];
 
@@ -75,7 +75,7 @@ function createFontSelect(string $name): CSelect {
 ?>
 <script type="text/x-jquery-tmpl" id="mapElementFormTpl">
 	<?= (new CDiv(new CTag('h4', true, _('Map element'))))
-			->addClass(ZBX_STYLE_DASHBRD_WIDGET_HEAD)
+			->addClass(ZBX_STYLE_DASHBOARD_WIDGET_HEAD)
 			->setId('formDragHandler')
 			->toString()
 	?>
@@ -127,7 +127,7 @@ function createFontSelect(string $name): CSelect {
 							->setId('areaSizeHeight')
 					], 'areaSizeRow')
 					->addRow(_('Placing algorithm'),
-						(new CRadioButtonList(null, SYSMAP_ELEMENT_AREA_VIEWTYPE_GRID))
+						(new CRadioButtonList('viewtype', SYSMAP_ELEMENT_AREA_VIEWTYPE_GRID))
 							->addValue(_('Grid'), SYSMAP_ELEMENT_AREA_VIEWTYPE_GRID)
 							->setModern(true),
 						'areaPlacingRow'
@@ -215,27 +215,42 @@ function createFontSelect(string $name): CSelect {
 						(new CDiv())->addClass(ZBX_STYLE_FORM_INPUT_MARGIN),
 						(new CButton(null, _('Select')))
 							->addClass(ZBX_STYLE_BTN_GREY)
-							->onClick('return PopUp("popup.generic",jQuery.extend('.
-								json_encode([
+							->onClick(
+								'return PopUp("popup.generic", jQuery.extend('.json_encode([
 									'srctbl' => 'sysmaps',
 									'srcfld1' => 'sysmapid',
 									'srcfld2' => 'name',
 									'dstfrm' => 'selementForm',
 									'dstfld1' => 'sysmapid',
 									'dstfld2' => 'elementNameMap'
-								]).
-									',{excludeids: [#{sysmapid}]}), null, this);'
+								]).', {excludeids: [#{sysmapid}]}), {dialogue_class: "modal-popup-generic"});'
 							)
 					], 'mapSelectRow')
-					->addRow(_('Application'), [
-						(new CTextBox('application'))
-							->setId('application')
-							->setWidth(ZBX_TEXTAREA_STANDARD_WIDTH),
-						(new CDiv())->addClass(ZBX_STYLE_FORM_INPUT_MARGIN),
-						(new CButton(null, _('Select')))
-							->setId('application-select')
-							->addClass(ZBX_STYLE_BTN_GREY)
-					], 'application-select-row')
+					->addRow(_('Tags'),
+						(new CDiv([
+							(new CTable())
+								->setId('selement-tags')
+								->addRow(
+									(new CCol(
+										(new CRadioButtonList('evaltype', TAG_EVAL_TYPE_AND_OR))
+											->addValue(_('And/Or'), TAG_EVAL_TYPE_AND_OR)
+											->addValue(_('Or'), TAG_EVAL_TYPE_OR)
+											->setModern(true)
+									))->setColSpan(4)
+								)
+								->addRow(
+									(new CCol(
+										(new CButton('tags_add', _('Add')))
+											->addClass(ZBX_STYLE_BTN_LINK)
+											->addClass('element-table-add')
+											->removeId()
+									))->setColSpan(3)
+								)
+						]))
+							->addClass(ZBX_STYLE_TABLE_FORMS_SEPARATOR)
+							->setAttribute('style', 'min-width: '.ZBX_TEXTAREA_BIG_WIDTH.'px;'),
+						'tags-select-row'
+					)
 					->addRow(_('Automatic icon selection'),
 						new CCheckBox('use_iconmap'),
 						'useIconMapRow'
@@ -329,7 +344,7 @@ function createFontSelect(string $name): CSelect {
 
 <script type="text/x-jquery-tmpl" id="mapShapeFormTpl">
 	<?= (new CDiv(new CTag('h4', true, _('Map shape'))))
-			->addClass(ZBX_STYLE_DASHBRD_WIDGET_HEAD)
+			->addClass(ZBX_STYLE_DASHBOARD_WIDGET_HEAD)
 			->setId('shapeDragHandler')
 			->toString().
 		(new CForm())
@@ -362,7 +377,7 @@ function createFontSelect(string $name): CSelect {
 							(new CDiv())->addClass(ZBX_STYLE_FORM_INPUT_MARGIN),
 							(new CTextBox('font_size'))->setWidth(ZBX_TEXTAREA_NUMERIC_STANDARD_WIDTH),
 							(new CDiv())->addClass(ZBX_STYLE_FORM_INPUT_MARGIN),
-							_('Colour'),
+							_('Color'),
 							(new CDiv())->addClass(ZBX_STYLE_FORM_INPUT_MARGIN),
 							(new CColor('font_color', '#{color}'))->appendColorPickerJs(false),
 							BR(),
@@ -383,7 +398,7 @@ function createFontSelect(string $name): CSelect {
 					)
 					->addRow(_('Background'),
 						(new CDiv([
-							_('Colour'),
+							_('Color'),
 							(new CDiv())->addClass(ZBX_STYLE_FORM_INPUT_MARGIN),
 							(new CColor('background_color', '#{color}'))->appendColorPickerJs(false)
 						]))->addClass(ZBX_STYLE_TABLE_FORMS_SEPARATOR),
@@ -403,7 +418,7 @@ function createFontSelect(string $name): CSelect {
 							(new CDiv())->addClass(ZBX_STYLE_FORM_INPUT_MARGIN),
 							(new CTextBox('border_width'))->setWidth(ZBX_TEXTAREA_NUMERIC_STANDARD_WIDTH),
 							(new CDiv())->addClass(ZBX_STYLE_FORM_INPUT_MARGIN),
-							_('Colour'),
+							_('Color'),
 							(new CDiv())->addClass(ZBX_STYLE_FORM_INPUT_MARGIN),
 							(new CColor('border_color', '#{color}'))->appendColorPickerJs(false)
 						]))
@@ -482,7 +497,7 @@ function createFontSelect(string $name): CSelect {
 
 <script type="text/x-jquery-tmpl" id="mapMassShapeFormTpl">
 	<?= (new CDiv(new CTag('h4', true, _('Mass update shapes'))))
-			->addClass(ZBX_STYLE_DASHBRD_WIDGET_HEAD)
+			->addClass(ZBX_STYLE_DASHBOARD_WIDGET_HEAD)
 			->setId('massShapeDragHandler')
 			->toString().
 		(new CForm())
@@ -522,7 +537,7 @@ function createFontSelect(string $name): CSelect {
 					)
 					->addRow((new CCheckBox('chkbox_font_color'))
 							->setId('chkboxFontColor')
-							->setLabel(_('Font colour')),
+							->setLabel(_('Font color')),
 						(new CColor('mass_font_color', '#{color}'))->appendColorPickerJs(false),
 						null, 'shape_figure_row'
 					)
@@ -546,7 +561,7 @@ function createFontSelect(string $name): CSelect {
 					)
 					->addRow((new CCheckBox('chkbox_background'))
 							->setId('chkboxBackground')
-							->setLabel(_('Background colour')),
+							->setLabel(_('Background color')),
 						(new CColor('mass_background_color', '#{color}'))->appendColorPickerJs(false),
 						null, 'shape_figure_row'
 					)
@@ -577,8 +592,8 @@ function createFontSelect(string $name): CSelect {
 							->setLabel((new CDiv())
 								->addClass('form-input-margin')
 								->addClass('switchable-content')
-								->setAttribute('data-value', _('Border colour'))
-								->setAttribute('data-value-2', _('Line colour'))
+								->setAttribute('data-value', _('Border color'))
+								->setAttribute('data-value-2', _('Line color'))
 							),
 						(new CColor('mass_border_color', '#{color}'))->appendColorPickerJs(false)
 					)
@@ -606,7 +621,7 @@ function createFontSelect(string $name): CSelect {
 
 <script type="text/x-jquery-tmpl" id="mapMassFormTpl">
 	<?= (new CDiv(new CTag('h4', true, _('Mass update elements'))))
-			->addClass(ZBX_STYLE_DASHBRD_WIDGET_HEAD)
+			->addClass(ZBX_STYLE_DASHBOARD_WIDGET_HEAD)
 			->setId('massDragHandler')
 			->toString()
 	?>
@@ -767,19 +782,19 @@ function createFontSelect(string $name): CSelect {
 								GRAPH_ITEM_DRAWTYPE_DASHED_LINE => _('Dashed line')
 							]))
 					)
-					->addRow(_('Colour (OK)'),
+					->addRow(_('Color (OK)'),
 						(new CColor('color', '#{color}'))->appendColorPickerJs(false)
 					)
 					->addRow(_('Link indicators'),
 						(new CDiv([
 							(new CTable())
-								->setHeader([_('Trigger'), _('Type'), _('Colour'), _('Action')])
+								->setHeader([_('Trigger'), _('Type'), _('Color'), _('Action')])
 								->setAttribute('style', 'width: 100%;')
 								->setId('linkTriggerscontainer'),
 							(new CButton(null, _('Add')))
 								->addClass(ZBX_STYLE_BTN_LINK)
-								->onClick('return PopUp("popup.generic",'.
-									json_encode([
+								->onClick(
+									'return PopUp("popup.generic", '.json_encode([
 										'srctbl' => 'triggers',
 										'srcfld1' => 'triggerid',
 										'reference' => 'linktrigger',
@@ -787,7 +802,7 @@ function createFontSelect(string $name): CSelect {
 										'real_hosts' => '1',
 										'with_triggers' => '1',
 										'noempty' => '1'
-									]).', null, this);'
+									]).', {dialogue_class: "modal-popup-generic"});'
 								)
 						]))
 							->addClass(ZBX_STYLE_TABLE_FORMS_SEPARATOR)
@@ -885,13 +900,20 @@ function createFontSelect(string $name): CSelect {
 	?>
 </script>
 
+<script type="text/x-jquery-tmpl" id="tag-row-tmpl">
+	<?= CTagFilterFieldHelper::getTemplate(['tag_field_name' => 'tags']); ?>
+</script>
+
 <script type="text/x-jquery-tmpl" id="selementFormTriggers">
 	<?= (new CRow([
 			(new CCol([
-				(new CDiv())->addClass(ZBX_STYLE_DRAG_ICON),
+				(new CDiv())
+					->addClass(ZBX_STYLE_DRAG_ICON)
+					->addStyle('top: 0px;'),
 				(new CSpan())->addClass('ui-icon ui-icon-arrowthick-2-n-s move '.ZBX_STYLE_TD_DRAG_ICON)
 			]))->addClass(ZBX_STYLE_TD_DRAG_ICON),
 			(new CCol([(new CDiv('#{name}'))->setWidth(ZBX_TEXTAREA_STANDARD_WIDTH)]))
+				->addStyle('padding: 0 5px;')
 				->addClass('#{class_name}'),
 			(new CCol([
 				(new CVar('element_id[#{triggerid}]', '#{triggerid}')),
@@ -914,10 +936,7 @@ function createFontSelect(string $name): CSelect {
 	 * @see init.js add.popup event
 	 */
 	function addPopupValues(data) {
-		if (data.object === 'name') {
-			jQuery('#application').val(data.values[0].name);
-		}
-		else if (data.object === 'linktrigger') {
+		if (data.object === 'linktrigger') {
 			ZABBIX.apps.map.object.linkForm.addNewTriggers(data.values);
 		}
 	}
