@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2025 Zabbix SIA
+** Copyright (C) 2001-2022 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -47,7 +47,7 @@ ZBX_NotificationCollection.prototype.map = function(callback) {
 	var len = this._list_sequence.length;
 
 	while (--len > -1) {
-		var ret = callback(this.getById(this._list_sequence[len]), len);
+		callback(this.getById(this._list_sequence[len]), len);
 	}
 };
 
@@ -135,7 +135,7 @@ ZBX_NotificationCollection.prototype.makeNodes = function() {
 
 	this.node.appendChild(this.btn_close);
 
-	header.className = 'dashbrd-widget-head cursor-move';
+	header.className = 'dashboard-widget-head cursor-move';
 	this.node.appendChild(header);
 
 	header.appendChild(controls);
@@ -181,7 +181,7 @@ ZBX_NotificationCollection.prototype.makeToggleBtn = function(attrs_inactive, at
 
 /**
  * Iterator property will be updated and reference to DOM node kept to be gracefully removed at render. No reference
- * to notification object would exists after this call - notification is removed and will not cycle back into LS.
+ * to notification object would exist after this call - notification is removed and will not cycle back into LS.
  *
  * @param {string} id
  */
@@ -247,12 +247,12 @@ ZBX_NotificationCollection.prototype.removeDanglingNodes = function() {
 			.then(function(node) {
 				node.parentNode && node.remove();
 			});
-		first &= false;
+		first = false;
 	}
 };
 
 /**
- * Notification sequecnce is maintained in DOM, in server response notifications must be ordered.
+ * Notification sequence is maintained in DOM, in server response notifications must be ordered.
  * Shows or hides list node, updates and appends notification nodes, then deligates to remove dangling nodes.
  *
  * @param {object} severity_styles
