@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2025 Zabbix SIA
+** Copyright (C) 2001-2022 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -38,8 +38,8 @@ ZBX_Notifications.ALARM_ONCE_SERVER = 1;
  * these "actions" by passing the new received state value through a method prefixed with <consume> that will adjust
  * instance's internal state, that in turn can be dispatched as "action". Other methods prefixed with <handle> responds
  * to other events than localStorage change event - (poll, focus, timeout..) and still they would reuse <consume>
- * domain methods and issue an anction via <push> if needed and call to render method explicitly. The <handlePushed> is
- * not reused on the instance that produces the action. This is so to reduce complexity and increase maintainebility,
+ * domain methods and issue an action via <push> if needed and call to render method explicitly. The <handlePushed> is
+ * not reused on the instance that produces the action. This is so to reduce complexity and increase maintainability,
  * because when an action produces an action, logic diverges deep, instead <consume> various domain within logic
  * and call `render` once, then <push> into localStorage once.
  *
@@ -522,7 +522,7 @@ ZBX_Notifications.prototype.renderAudio = function() {
 
 /**
  * @param {string} resource  A value for 'action' parameter.
- * @param {object} params    Form data to be send.
+ * @param {object} params    Form data to be sent.
  *
  * @return {Promise}
  */
@@ -938,9 +938,7 @@ $(function() {
 		pos_side = 10,
 		side = 'right';
 
-	if (main !== null) {
-		main.appendChild(ntf_node);
-	}
+	main.appendChild(ntf_node);
 
 	if (ntf_pos !== null && 'top' in ntf_pos) {
 		side = ('right' in ntf_pos ? 'right' : ('left' in ntf_pos ? 'left' : null));
@@ -953,7 +951,7 @@ $(function() {
 	ntf_node.style.top = pos_top + 'px';
 	ntf_node.style[side] = pos_side + 'px';
 
-	$(ntf_node).draggable({handle: '>.dashbrd-widget-head',
+	$(ntf_node).draggable({handle: '>.dashboard-widget-head',
 		start: function(event, ui) {
 			ui.helper.data('containment', {
 				min_top: -main.offsetTop,
