@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2025 Zabbix SIA
+** Copyright (C) 2001-2022 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -25,26 +25,34 @@ require_once dirname(__FILE__).'/include/forms.inc.php';
 
 $page['title'] = _('Configuration of network maps');
 $page['file'] = 'sysmap.php';
-$page['scripts'] = ['class.svg.canvas.js', 'class.svg.map.js', 'class.cmap.js', 'class.cviewswitcher.js',
-	'multiselect.js', 'colorpicker.js'
+$page['scripts'] = ['class.svg.canvas.js', 'class.svg.map.js', 'class.cmap.js',
+	'colorpicker.js', 'class.tagfilteritem.js'
 ];
 $page['type'] = detect_page_type();
 
 require_once dirname(__FILE__).'/include/page_header.php';
 
+if (!CWebUser::checkAccess(CRoleHelper::ACTIONS_EDIT_MAPS)) {
+	access_deny(ACCESS_DENY_PAGE);
+}
+
 // VAR	TYPE	OPTIONAL	FLAGS	VALIDATION	EXCEPTION
 $fields = [
 	'sysmapid' =>	[T_ZBX_INT, O_MAND, P_SYS,	DB_ID,		null],
 	'selementid' =>	[T_ZBX_INT, O_OPT, P_SYS,	DB_ID,		null],
 	'sysmap' =>		[T_ZBX_STR, O_OPT, null,	NOT_EMPTY,	'isset({action}) && {action} == "update"'],
+	'selements' =>	[T_ZBX_STR, O_OPT, P_SYS,	null,		null],
+	'links' =>		[T_ZBX_STR, O_OPT, P_SYS,	null,		null],
 	// actions
 	'action' =>		[T_ZBX_STR, O_OPT, P_ACT,	IN('"update","expand"'),	null],
 	'delete' =>		[T_ZBX_STR, O_OPT, P_SYS|P_ACT, null,	null],
 	'cancel' =>		[T_ZBX_STR, O_OPT, P_SYS,	null,		null],
 	'form' =>		[T_ZBX_STR, O_OPT, P_SYS,	null,		null],
+	'form_refresh' => [T_ZBX_INT, O_OPT, null,	null,		null],
 	// ajax
 	'favobj' =>		[T_ZBX_STR, O_OPT, P_ACT,	null,		null],
 	'favid' =>		[T_ZBX_STR, O_OPT, P_ACT,	null,		null],
+	'name' =>		[T_ZBX_STR, O_OPT, null,	NOT_EMPTY,	'isset({action}) && {action} == "expand"'],
 	'source' =>		[T_ZBX_STR, O_OPT, null,	NOT_EMPTY,	'isset({action}) && {action} == "expand"']
 ];
 check_fields($fields);
@@ -77,6 +85,27 @@ if (isset($_REQUEST['favobj'])) {
 				$sysmapUpdate['sysmapid'] = $sysmapid;
 				$sysmapUpdate['lines'] = [];
 
+				if (array_key_exists('selements', $sysmapUpdate)) {
+					foreach ($sysmapUpdate['selements'] as $element) {
+						if (!array_key_exists('tags', $element)) {
+							continue;
+						}
+
+						if (array_key_exists('elementtype', $element)
+								&& ($element['elementtype'] == SYSMAP_ELEMENT_TYPE_HOST
+									|| $element['elementtype'] == SYSMAP_ELEMENT_TYPE_HOST_GROUP)) {
+							foreach ($element['tags'] as $key => $tag) {
+								if ($tag['tag'] === '' && $tag['value'] === '') {
+									unset($element['tags'][$key]);
+								}
+							}
+						}
+						else {
+							unset($element['tags']);
+						}
+					}
+				}
+
 				if (array_key_exists('shapes', $sysmapUpdate)) {
 					foreach ($sysmapUpdate['shapes'] as $key => &$shape) {
 						if (array_key_exists('sysmap_shapeid', $shape) && !is_numeric($shape['sysmap_shapeid'])) {
@@ -113,7 +142,7 @@ if (isset($_REQUEST['favobj'])) {
 				DBend(false);
 				$msg = [$e->getMessage()];
 
-				foreach (clear_messages() as $errMsg) {
+				foreach (get_and_clear_messages() as $errMsg) {
 					$msg[] = $errMsg['type'].': '.$errMsg['message'];
 				}
 
@@ -123,11 +152,13 @@ if (isset($_REQUEST['favobj'])) {
 			}
 
 			@ob_flush();
-			exit;
+			session_write_close();
+			exit();
 		}
 		elseif (getRequest('action') === 'expand') {
-			$values = [];
+			$values = ['selements' => [], 'links' => [], 'shapes' => []];
 			$return = [];
+			$name = getRequest('name');
 			$sources = json_decode(getRequest('source'), true);
 
 			foreach ($sources as $num => $source) {
@@ -138,38 +169,46 @@ if (isset($_REQUEST['favobj'])) {
 
 					if (array_key_exists('elementtype', $source) && array_key_exists('elements', $source)
 							&& is_array($source['elements']) && CMapHelper::checkSelementPermissions([$source])) {
-						$values[$num] = $source;
+						$element_type = 'selements';
 					}
 					else {
-						$label = array_key_exists('label', $source) ? $source['label'] : $source['text'];
-						$return[$num] = CMacrosResolverHelper::resolveMapLabelMacros($label);
+						$element_type = array_key_exists('label', $source) ? 'links' : 'shapes';
 					}
+
+					$values[$element_type][$num] = $source;
 				}
 				else {
 					$return[$num] = null;
 				}
 			}
 
-			if ($values) {
-				// Resolve macros in map element labels.
-				$values = CMacrosResolverHelper::resolveMacrosInMapElements($values, ['resolve_element_label' => true]);
+			$values['links'] = CMacrosResolverHelper::resolveMapLinkLabelMacros($values['links'], ['label' => 'label']);
+			$values['shapes'] = CMacrosResolverHelper::resolveMapShapeLabelMacros($name, $values['shapes'],
+				['text' => 'label']
+			);
 
-				foreach ($values as $num => $value) {
-					$return[$num] = $value['label'];
-				}
+			if ($values['selements']) {
+				// Resolve macros in map element labels.
+				$values['selements'] = CMacrosResolverHelper::resolveMacrosInMapElements($values['selements'],
+					['resolve_element_label' => true]
+				);
+			}
+
+			foreach ($values['selements'] + $values['links'] + $values['shapes'] as $num => $value) {
+				$return[$num] = $value['label'];
 			}
 
 			ksort($return);
 
 			echo json_encode($return);
-			exit;
+			session_write_close();
+			exit();
 		}
 	}
 }
 
 if ($page['type'] != PAGE_TYPE_HTML) {
 	require_once dirname(__FILE__).'/include/page_footer.php';
-	exit;
 }
 
 /*
@@ -204,6 +243,11 @@ if (isset($_REQUEST['sysmapid'])) {
 /*
  * Display
  */
+$sysmap['links'] = CMacrosResolverHelper::resolveMapLinkLabelMacros($sysmap['links'], ['label' => 'expanded']);
+$sysmap['shapes'] = CMacrosResolverHelper::resolveMapShapeLabelMacros($sysmap['name'], $sysmap['shapes'],
+	['text' => 'expanded']
+);
+
 $data = [
 	'sysmap' => $sysmap,
 	'iconList' => [],
@@ -218,11 +262,6 @@ $data['sysmap'] = CMapHelper::applyMapElementLabelProperties($data['sysmap']);
 // get selements
 addElementNames($data['sysmap']['selements']);
 
-foreach ($data['sysmap']['shapes'] as &$shape) {
-	$shape['expanded'] = CMacrosResolverHelper::resolveMapLabelMacros($shape['text']);
-}
-unset($shape);
-
 foreach ($data['sysmap']['lines'] as $line) {
 	$data['sysmap']['shapes'][] = CMapHelper::convertLineToShape($line);
 }
@@ -258,7 +297,6 @@ foreach ($data['sysmap']['links'] as &$link) {
 		$link['linktriggers'][$lnum]['desc_exp'] = $host['name'].NAME_DELIMITER.$dbTrigger['description'];
 	}
 
-	$link['expanded'] = CMacrosResolverHelper::resolveMapLabelMacros($link['label']);
 	order_result($link['linktriggers'], 'desc_exp');
 }
 unset($link);
